# Programa en Python - Sistema Estadistico de Costos industria del Calzado


# MÓDULO I - CARGA DE VARIABLES MONETARiAS

import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import seaborn as sns

# importar base de datos de series de tiempo con variables monetarias:

vm = pd.read_excel('Calzado variables monetarias.xlsx')


# Convertir columna mes en variable indexadora temporal:

vm.mes = pd.to_datetime(vm.mes)
vm.set_index('mes', inplace=True)       


# MÓDULO II - DEFINICIÓN DE PARÁMETROS

# Parámetros generales
prod_mens = 4400
meses_prod = 8
prod_anual_potencial = prod_mens * meses_prod
ocupacion = 80
prod_anual_efectiva = prod_anual_potencial * ocupacion / 100
prod_anual_exportada = 20
prod_anual_exportada_efectiva = prod_anual_efectiva * prod_anual_exportada / 100

# Parámetros etapa diseño
temporadas = 2
modelos_hombres = 5
modelos_mujeres = 25
tasaexito_hombres = 80
tasaexito_mujeres = 60
modelos_por_horma = 5
colores_hombres = 2
colores_mujeres = 5

# Materiales prototipos
pttp_cuero = 1.5
pttp_forro = 1
pttp_contrafuerte = 1
pttp_puntera = 1
pttp_ojalillos = 24
pttp_cordones = 1
pttp_plantilla_armado = 1
pttp_plantilla_vista = 1
pttp_base = 1
pttp_adhesivos = 20    # pares por litro
pttp_hilo = 14
pttp_cajas_indiv = 1
pttp_cajas_embalar = 12  # pares por caja

# Horas hombre operarios prototipos
pttp_cortadoyrebajado = 1
pttp_aparado = 2
pttp_armadoyempaque = 1.5

# Prueba de producto, presentación y escalas de numeración
stands = 1   # stands por temporada
exposiciones = 1  # exposiciones por temporada
escalas_numeracion = 6   # números por modelo

# Parámetros de producción
# Operarios
operarios_cortadoyrebajado = 3
operarios_aparado = 6
operarios_armadoyempaque = 6

# Materiales en producción
cuero = 4             # pares por m2
forro = 4             # pares por m2
contrafuerte = 40     # pares por m2
puntera = 40          # pares por m2
ojalillos = 24        # cantidad por par
cordones = 1
plantilla_armado = 1
plantilla_vista = 1
base = 1
adhesivos = 20         # pares por litro
hilo = 14
cajas_indiv = 1
cajas_embalar = 12  # pares por caja

# Mano de obra indirecta
encargado_deposito = 1
expedicion = 1
supervisor = 1
programacion_prod = 1
administrativos = 2
vendedores = 2
gerente_gral = 1

# Maquinaria
maq_matrices_cant = 38
maq_troqueladora_cant = 2
maq_rebajar_cant = 1
maq_coser_cant = 6
maq_mesa_preparado_cant = 6
maq_ojalillar_cant = 1
maq_cambrar_talon_cant = 1
maq_humectadora_cant = 1
maq_centraryarmar_cant = 1
maq_kamburian_cant = 1
maq_cerrar_base_cant = 1
maq_asentar_cant = 1
maq_raspar_cant = 1
maq_conformador_cant = 1
maq_raspar_contorno_cant = 1
maq_flash_cant = 1
maq_pegar_cant = 1
maq_sacardehorma_cant = 1
maq_lustrar_cant = 1
maq_marcar_suela_cant = 1
maq_compresor_cant = 2
maq_camioneta_cant = 1
maq_computadoras_cant = 2

maq_troqueladora_years = 10
maq_rebajar_years = 10
maq_coser_years = 5
maq_mesa_preparado_years = 10
maq_ojalillar_years = 10
maq_cambrar_talon_years = 10
maq_humectadora_years = 10
maq_centraryarmar_years = 10
maq_kamburian_years = 10
maq_cerrar_base_years = 10
maq_asentar_years = 10
maq_raspar_years = 10
maq_conformador_years = 10
maq_raspar_contorno_years = 10
maq_flash_years = 10
maq_pegar_years = 10
maq_sacardehorma_years = 10
maq_lustrar_years = 10
maq_marcar_suela_years = 10
maq_compresor_years = 10
maq_camioneta_years = 10
maq_computadoras_years = 5
maq_escritorios_years = 10

maq_troqueladora_vresid = 20
maq_rebajar_vresid = 20
maq_coser_vresid = 20
maq_mesa_preparado_vresid = 20
maq_ojalillar_vresid = 20
maq_cambrar_talon_vresid = 20
maq_humectadora_vresid = 20
maq_centraryarmar_vresid = 20
maq_kamburian_vresid = 20
maq_cerrar_base_vresid = 20
maq_asentar_vresid = 20
maq_raspar_vresid = 20
maq_conformador_vresid = 20
maq_raspar_contorno_vresid = 20
maq_flash_vresid = 20
maq_pegar_vresid = 20
maq_sacardehorma_vresid = 20
maq_lustrar_vresid = 20
maq_marcar_suela_vresid = 20
maq_compresor_vresid = 20
maq_camioneta_vresid = 30


# Consumibles y mantenimiento
uso_camioneta = 1000      # km por mes
consumo_gasoil = 0.1      # litros por km
mantenim_camioneta = 5    # anual del valor de mercado
mantenim_gral = 12        # horas al mes
limpieza = 24             # horas al mes
potencia = 150            # kw
consumo_energia = 1200    # kw/h mensuales
horas_pico_potencia = 5
horas_nopico_potencia = 19
horas_pico_consumo = 5
horas_valle_consumo = 6
horas_resto_consumo = 13
galpon = 400              # m2 de alquiler

# Parámetros laborales
antiguedad_cant = 20           # promedio de años
antiguedad_coef = 0.75
vestimenta_prendas = 4         # cantidad por año
vestimenta_casco = 2           # cantidad por año
vestimenta_guantes = 2         # cantidad por año
sac_coef = 8.33
vacaciones_dias = 35
prevision_despido_coef = 4
ausentismo = 7.5

# Parámetros financieros y tributarios
costo_oportunidad = 4     # % anual
plazo_pago_insumos = 60
plazo_cobro = 90
plazo_pago_salarios = 30
mark_up = 5
tamaño_envios_exterior = 900  #pares por envio
volumen_caja_envio_ext = 0.00504  #m3
parametro_volumen = 198.4  #pares por m3
viajes_año = 6  # por persona
alojamientos_viaticos = 3  #dias por viaje
reinversion_utilidades = 50


# MÓDULO III - ESTiMACiONES DE COSTOS

# Bloque I.- Diseño, prototipos y pruebas de producto

i01_honorarios_diseño = ( vm['honorarios_diseno'] * vm['dolar']
            * ( modelos_hombres + modelos_mujeres ) * temporadas
            / prod_anual_efectiva )

i02_mat_hormas = (( modelos_hombres + modelos_mujeres ) * temporadas
            / modelos_por_horma * vm['pmat_horma_prototipo'] * vm['dolar']
            / prod_anual_efectiva )

i03_mat_cuero = (( modelos_hombres * colores_hombres + modelos_mujeres
            * colores_mujeres ) * temporadas * pttp_cuero * vm['pmat_cuero']
            * vm['dolar'] / prod_anual_efectiva )

i04_mat_forro = (( modelos_hombres * colores_hombres + modelos_mujeres
            * colores_mujeres ) * temporadas * pttp_forro * vm['pmat_forro']
            * vm['dolar'] / prod_anual_efectiva )

i05_mat_contrafuerte = (( modelos_hombres * colores_hombres + modelos_mujeres
            * colores_mujeres ) * temporadas * pttp_contrafuerte
            * vm['pmat_contrafuerte']
            * vm['dolar'] / prod_anual_efectiva )

i06_mat_puntera = (( modelos_hombres * colores_hombres + modelos_mujeres
            * colores_mujeres ) * temporadas * pttp_puntera * vm['pmat_puntera']
            * vm['dolar'] / prod_anual_efectiva )

i07_mat_ojalillos = (( modelos_hombres * colores_hombres + modelos_mujeres
            * colores_mujeres ) * temporadas * pttp_ojalillos
            * vm['pmat_ojalillos'] / 1000 
            * vm['dolar'] / prod_anual_efectiva )

i08_mat_cordones = (( modelos_hombres * colores_hombres + modelos_mujeres
            * colores_mujeres ) * temporadas * pttp_cordones
            * vm['pmat_cordones'] / 72
            * vm['dolar'] / prod_anual_efectiva )

i09_mat_plantilla_armado = (( modelos_hombres * colores_hombres + modelos_mujeres
            * colores_mujeres ) * temporadas * pttp_plantilla_armado * vm['pmat_plantilla_armado']
            * vm['dolar'] / prod_anual_efectiva )

i10_mat_plantilla_vista = (( modelos_hombres * colores_hombres + modelos_mujeres
            * colores_mujeres ) * temporadas * pttp_plantilla_vista * vm['pmat_plantilla_vista']
            * vm['dolar'] / prod_anual_efectiva )

i11_mat_base = (( modelos_hombres * colores_hombres + modelos_mujeres
            * colores_mujeres ) * temporadas * pttp_base * vm['pmat_base']
            * vm['dolar'] / prod_anual_efectiva )

i12_mat_adhesivos = (( modelos_hombres * colores_hombres + modelos_mujeres
            * colores_mujeres ) * temporadas / pttp_adhesivos * vm['pmat_adhesivos']
            * vm['dolar'] / prod_anual_efectiva )

i13_mat_hilo = (( modelos_hombres * colores_hombres + modelos_mujeres
            * colores_mujeres ) * temporadas * pttp_hilo * vm['pmat_hilo']
            / 4000 * vm['dolar'] / prod_anual_efectiva )

i14_mat_cajas_individuales = (( modelos_hombres * colores_hombres + modelos_mujeres
            * colores_mujeres ) * temporadas * pttp_cajas_indiv
            * vm['pmat_cajas_indiv'] / prod_anual_efectiva )

i15_mat_cajas_embalar = (( modelos_hombres * colores_hombres + modelos_mujeres
            * colores_mujeres ) * temporadas / pttp_cajas_embalar
            * vm['pmat_cajas_embalar'] / prod_anual_efectiva )

i16_horas_cortado_rebajado = (( modelos_hombres * colores_hombres + modelos_mujeres
            * colores_mujeres ) * temporadas * pttp_cortadoyrebajado
            * vm['sal_especializado'] / prod_anual_efectiva )

i17_horas_aparado = (( modelos_hombres * colores_hombres + modelos_mujeres
            * colores_mujeres ) * temporadas * pttp_aparado
            * vm['sal_especializado'] / prod_anual_efectiva )

i18_horas_armado_empaque = (( modelos_hombres * colores_hombres + modelos_mujeres
            * colores_mujeres ) * temporadas * pttp_armadoyempaque
            * vm['sal_especializado'] / prod_anual_efectiva )

i19_muestra = ( stands * temporadas * vm['pstand'] / prod_anual_efectiva )

i20_presentacion_venta = ( exposiciones * temporadas * vm['pexposicion']
            / prod_anual_efectiva )

i21_viajes_chile = (( viajes_año * vm['pasaje_chile'] + viajes_año
            * alojamientos_viaticos * ( vm['alojamiento_chile']
            + vm['viaticos_chile'] )) * vm['dolar']
            / prod_anual_exportada_efectiva )

i22_escalas_numeracion = (( i16_horas_cortado_rebajado + i17_horas_aparado
            + i18_horas_armado_empaque ) * escalas_numeracion )

i23_antig = (( i16_horas_cortado_rebajado + i17_horas_aparado
            + i18_horas_armado_empaque + i22_escalas_numeracion )
            * antiguedad_cant * antiguedad_coef / 100 )

i24_sac = (( i16_horas_cortado_rebajado + i17_horas_aparado
            + i18_horas_armado_empaque + i22_escalas_numeracion + i23_antig )
            * sac_coef / 100 )
          
i25_vac = (( i16_horas_cortado_rebajado + i17_horas_aparado
            + i18_horas_armado_empaque + i22_escalas_numeracion + i23_antig )
            / 30 * vacaciones_dias / 12 )

i26_cont_pat = (( i16_horas_cortado_rebajado + i17_horas_aparado
            + i18_horas_armado_empaque + i22_escalas_numeracion + i23_antig
            + i24_sac + i25_vac - vm['contribuciones_mni']
            * ( operarios_cortadoyrebajado + operarios_aparado
            + operarios_armadoyempaque ) * 12 / prod_anual_efectiva )
            * vm['contribuciones_alic'] / 100 )

i27_cont_pat_iva = (-( i16_horas_cortado_rebajado + i17_horas_aparado
            + i18_horas_armado_empaque + i22_escalas_numeracion + i23_antig
            + i24_sac + i25_vac - vm['contribuciones_mni']
            * ( operarios_cortadoyrebajado + operarios_aparado
            + operarios_armadoyempaque ) * 12 / prod_anual_efectiva )
            * vm['contribuciones_ctaiva_alic'] / 100 )

i28_cont_os = (( i16_horas_cortado_rebajado + i17_horas_aparado
            + i18_horas_armado_empaque + i22_escalas_numeracion + i23_antig
            + i24_sac + i25_vac ) * vm['contrib_obrasocial_alic'] / 100 )

i29_seg_vida = (( i16_horas_cortado_rebajado + i17_horas_aparado
            + i18_horas_armado_empaque + i22_escalas_numeracion + i23_antig
            + i24_sac + i25_vac ) * vm['seguro_vida_obligat_alic'] / 100 )

i30_art = (( i16_horas_cortado_rebajado + i17_horas_aparado
            + i18_horas_armado_empaque + i22_escalas_numeracion + i23_antig
            + i24_sac + i25_vac ) * vm['art_alic'] / 100 )

i31_fondo_asistencial = (( i16_horas_cortado_rebajado + i17_horas_aparado
            + i18_horas_armado_empaque + i22_escalas_numeracion + i23_antig
            + i24_sac + i25_vac ) * vm['fondo_asistencial_alic'] / 100 )

i32_prev_despido = (( i16_horas_cortado_rebajado + i17_horas_aparado
            + i18_horas_armado_empaque + i22_escalas_numeracion + i23_antig
            + i24_sac + i25_vac ) * prevision_despido_coef / 100 )

i33_ausentismo = (( i16_horas_cortado_rebajado + i17_horas_aparado
            + i18_horas_armado_empaque + i22_escalas_numeracion + i23_antig
            + i24_sac ) * ausentismo / 100 )

i00_pruebas_prod = ( i01_honorarios_diseño + i02_mat_hormas + i03_mat_cuero
            + i04_mat_forro + i05_mat_contrafuerte + i06_mat_puntera
            + i07_mat_ojalillos + i08_mat_cordones + i09_mat_plantilla_armado
            + i10_mat_plantilla_vista + i11_mat_base + i12_mat_adhesivos
            + i13_mat_hilo + i14_mat_cajas_individuales + i15_mat_cajas_embalar
            + i16_horas_cortado_rebajado + i17_horas_aparado
            + i18_horas_armado_empaque + i19_muestra + i20_presentacion_venta
            + i21_viajes_chile + i22_escalas_numeracion + i23_antig + i24_sac
            + i25_vac + i26_cont_pat + i27_cont_pat_iva + i28_cont_os
            + i29_seg_vida + i30_art + i31_fondo_asistencial
            + i32_prev_despido + i33_ausentismo )

# Bloque II.- Materia prima

ii01_cuero = vm['pmat_cuero']*vm['dolar']/cuero

ii02_forro = vm['pmat_forro']*vm['dolar']/forro

ii03_contrafuerte = vm['pmat_contrafuerte']*vm['dolar']/contrafuerte

ii04_puntera = vm['pmat_puntera']*vm['dolar']/puntera

ii05_ojalillos = vm['pmat_ojalillos']*vm['dolar']/1000*ojalillos

ii06_cordones = vm['pmat_ojalillos']*vm['dolar']/72*cordones

ii07_plantilla_armado = vm['pmat_plantilla_armado']*vm['dolar']*plantilla_armado

ii08_plantilla_vista = vm['pmat_plantilla_vista']*vm['dolar']*plantilla_vista

ii09_base = ( base * vm['pmat_base_export'] * vm['dolar'] )

ii10_adhesivos = vm['pmat_adhesivos']*vm['dolar']/adhesivos

ii11_hilo = vm['pmat_hilo']*vm['dolar']/4000*hilo

ii12_cajas_indiv = vm['pmat_cajas_indiv']*cajas_indiv

ii13_cajas_embalar = vm['pmat_cajas_embalar']/cajas_embalar


ii00_materia_prima = (ii01_cuero + ii02_forro + ii03_contrafuerte
                + ii04_puntera + ii05_ojalillos + ii06_cordones
                + ii07_plantilla_armado + ii08_plantilla_vista
                + ii09_base + ii10_adhesivos + ii11_hilo
                + ii12_cajas_indiv + ii13_cajas_embalar)

# Bloque iii.- Mano de obra directa

iii01_rem_operarios = (vm['sal_especializado']
                *(operarios_cortadoyrebajado+operarios_aparado+operarios_armadoyempaque)
                *192*12/prod_anual_efectiva)
iii02_rem_operarios_NR = 0

iii03_merienda = (vm['sal_especializado']*22
                *(operarios_cortadoyrebajado+operarios_aparado+operarios_armadoyempaque)
                *12/prod_anual_efectiva)

iii04_premio_asistencia = (vm['sal_premio_asist']
                *(operarios_cortadoyrebajado+operarios_aparado+operarios_armadoyempaque)
                *12/prod_anual_efectiva)

iii05_premio_asist_perfecta = (vm['sal_asist_perf']
                *(operarios_cortadoyrebajado+operarios_aparado+operarios_armadoyempaque)
                *12/prod_anual_efectiva)

iii06_horasextras_15 = 0

iii07_horasextras_20 = 0

iii08_antiguedad = ((iii01_rem_operarios + iii06_horasextras_15 + iii07_horasextras_20)
                *antiguedad_cant*antiguedad_coef/100)

iii09_sac = ((iii01_rem_operarios + iii06_horasextras_15 + iii07_horasextras_20
                + iii08_antiguedad)*sac_coef/100)

iii10_vac = ((iii01_rem_operarios + iii06_horasextras_15 + iii07_horasextras_20
                + iii08_antiguedad)/30*vacaciones_dias/12)

iii11_cont_pat = (((iii01_rem_operarios + iii03_merienda + iii04_premio_asistencia
                + iii05_premio_asist_perfecta + iii06_horasextras_15 + iii07_horasextras_20
                + iii08_antiguedad+ + iii09_sac + iii10_vac)
                - vm['contribuciones_mni']*(operarios_cortadoyrebajado + operarios_aparado
                + operarios_armadoyempaque)/prod_mens)
                *vm['contribuciones_alic']/100)

iii12_cont_pat_iva = -(((iii01_rem_operarios + iii03_merienda + iii04_premio_asistencia
                + iii05_premio_asist_perfecta + iii06_horasextras_15 + iii07_horasextras_20
                + iii08_antiguedad+ + iii09_sac + iii10_vac)
                - vm['contribuciones_mni']*(operarios_cortadoyrebajado
                + operarios_aparado+operarios_armadoyempaque)/prod_mens)
                *vm['contribuciones_ctaiva_alic']/100)

iii13_cont_os = ((iii01_rem_operarios + iii03_merienda + iii04_premio_asistencia
                + iii05_premio_asist_perfecta + iii06_horasextras_15 + iii07_horasextras_20
                + iii08_antiguedad+ + iii09_sac + iii10_vac)
                *vm['contrib_obrasocial_alic']/100)

iii14_seg_vida = ((iii01_rem_operarios + iii03_merienda + iii04_premio_asistencia
                + iii05_premio_asist_perfecta + iii06_horasextras_15 + iii07_horasextras_20
                + iii08_antiguedad+ + iii09_sac + iii10_vac)
                *vm['seguro_vida_obligat_alic']/100)

iii15_art = ((iii01_rem_operarios + iii03_merienda + iii04_premio_asistencia
                + iii05_premio_asist_perfecta + iii06_horasextras_15 + iii07_horasextras_20
                + iii08_antiguedad+ + iii09_sac + iii10_vac)*vm['art_alic']/100)

iii16_fondo_asistencial = (( iii01_rem_operarios + iii03_merienda
                + iii04_premio_asistencia + iii05_premio_asist_perfecta
                + iii06_horasextras_15 + iii07_horasextras_20 + iii08_antiguedad
                + iii09_sac + iii10_vac ) * vm['fondo_asistencial_alic']
                / 100 )

iii17_prev_despido = ((iii01_rem_operarios + iii03_merienda + iii04_premio_asistencia
                + iii05_premio_asist_perfecta + iii06_horasextras_15 + iii07_horasextras_20
                + iii08_antiguedad+ + iii09_sac + iii10_vac)*prevision_despido_coef/100)

iii18_ausentismo = (( iii01_rem_operarios + iii08_antiguedad + iii09_sac
                + iii10_vac + iii11_cont_pat
                + iii12_cont_pat_iva + iii13_cont_os
                + iii14_seg_vida + iii15_art + iii16_fondo_asistencial
                + iii17_prev_despido ) * ausentismo / 100)

iii00_mano_obra_directa = ( iii01_rem_operarios
                + iii02_rem_operarios_NR + iii03_merienda + iii04_premio_asistencia
                + iii05_premio_asist_perfecta + iii06_horasextras_15
                + iii07_horasextras_20 + iii08_antiguedad + iii09_sac
                + iii10_vac + iii11_cont_pat + iii12_cont_pat_iva
                + iii13_cont_os + iii14_seg_vida + iii15_art
                + iii16_fondo_asistencial + iii17_prev_despido
                + iii18_ausentismo )

# Bloque IV.- Mano de obra indirecta

iv01_rem_deposito = (vm['sal_mant_a']*encargado_deposito*12/prod_anual_efectiva)

iv02_rem_expedicion = (vm['sal_exp_a']*expedicion*12/prod_anual_efectiva)

iv03_rem_supervisor = (vm['sal_des_a']*vm['sal_supervisor']
                *supervisor*12/prod_anual_efectiva)

iv04_rem_programacion = (vm['sal_des_a']*vm['sal_prog_prod']
                *programacion_prod*12/prod_anual_efectiva)

iv05_rem_admin = (vm['sal_adm_a']*administrativos*12/prod_anual_efectiva)

iv06_rem_vendedores = (vm['sal_vendedor_dta']*vendedores*12/prod_anual_efectiva)

iv07_rem_gtegral = (vm['sal_des_a']*vm['sal_gtegral']
                *gerente_gral*12/prod_anual_efectiva)

iv08_merienda = (0)

iv09_premio_asistencia = (0)

iv10_premio_asist_perfecta = (0)


iv11_antiguedad = ((iv01_rem_deposito + iv02_rem_expedicion + iv03_rem_supervisor
                + iv04_rem_programacion + iv05_rem_admin + iv06_rem_vendedores
                + iv07_rem_gtegral)*antiguedad_cant*antiguedad_coef/100)

iv12_sac = ((iv01_rem_deposito + iv02_rem_expedicion + iv03_rem_supervisor
                + iv04_rem_programacion + iv05_rem_admin + iv06_rem_vendedores
                + iv07_rem_gtegral + iv11_antiguedad)*sac_coef/100)

iv13_vacaciones = ((iv01_rem_deposito + iv02_rem_expedicion + iv03_rem_supervisor
                + iv04_rem_programacion + iv05_rem_admin + iv06_rem_vendedores
                + iv07_rem_gtegral + iv11_antiguedad)/30*vacaciones_dias/12)

iv14_cont_pat = ((iv01_rem_deposito + iv02_rem_expedicion + iv03_rem_supervisor
                + iv04_rem_programacion + iv05_rem_admin + iv06_rem_vendedores
                + iv07_rem_gtegral + iv11_antiguedad + iv12_sac + iv13_vacaciones
                - vm['contribuciones_mni']*(encargado_deposito + expedicion + supervisor
                + programacion_prod + administrativos + vendedores
                + gerente_gral)/prod_mens)*vm['contribuciones_alic']/100)

iv15_cont_pat_iva = -((iv01_rem_deposito + iv02_rem_expedicion + iv03_rem_supervisor
                + iv04_rem_programacion + iv05_rem_admin + iv06_rem_vendedores
                + iv07_rem_gtegral + iv11_antiguedad + iv12_sac + iv13_vacaciones
                - vm['contribuciones_mni']*(encargado_deposito + expedicion + supervisor
                + programacion_prod + administrativos + vendedores + gerente_gral)/prod_mens)
                *vm['contribuciones_ctaiva_alic']/100)

iv16_cont_os = ((iv01_rem_deposito + iv02_rem_expedicion + iv03_rem_supervisor
                + iv04_rem_programacion + iv05_rem_admin + iv06_rem_vendedores
                + iv07_rem_gtegral + iv11_antiguedad + iv12_sac + iv13_vacaciones)
                *vm['contrib_obrasocial_alic']/100)

iv17_seguro_vida = ((iv01_rem_deposito + iv02_rem_expedicion + iv03_rem_supervisor
                + iv04_rem_programacion + iv05_rem_admin + iv06_rem_vendedores
                + iv07_rem_gtegral + iv11_antiguedad + iv12_sac + iv13_vacaciones)
                *vm['seguro_vida_obligat_alic']/100)

iv18_art = ((iv01_rem_deposito + iv02_rem_expedicion + iv03_rem_supervisor
                + iv04_rem_programacion + iv05_rem_admin + iv06_rem_vendedores
                + iv07_rem_gtegral + iv11_antiguedad + iv12_sac + iv13_vacaciones)
                *vm['art_alic']/100)

iv19_fondo_asistencial = (( iv01_rem_deposito + iv02_rem_expedicion
                + iv03_rem_supervisor + iv04_rem_programacion + iv05_rem_admin
                + iv06_rem_vendedores + iv07_rem_gtegral + iv08_merienda
                + iv09_premio_asistencia + iv10_premio_asist_perfecta
                + iv11_antiguedad + iv12_sac + iv13_vacaciones )
                * vm['fondo_asistencial_alic'] / 100 )

iv20_prevision_despido = ((iv01_rem_deposito + iv02_rem_expedicion + iv03_rem_supervisor
                + iv04_rem_programacion + iv05_rem_admin + iv06_rem_vendedores
                + iv07_rem_gtegral + iv11_antiguedad + iv12_sac + iv13_vacaciones)
                *prevision_despido_coef/100)


iv00_mano_obra_indirecta = (iv01_rem_deposito
                + iv02_rem_expedicion + iv03_rem_supervisor + iv04_rem_programacion
                + iv05_rem_admin + iv06_rem_vendedores + iv07_rem_gtegral
                + iv08_merienda + iv09_premio_asistencia + iv10_premio_asist_perfecta
                + iv11_antiguedad + iv12_sac + iv13_vacaciones
                + iv14_cont_pat + iv15_cont_pat_iva
                + iv16_cont_os + iv17_seguro_vida
                + iv18_art + iv19_fondo_asistencial + iv20_prevision_despido)

# Bloque V.- Costo de maquinaria

v01_energia = ((potencia*vm['penergia_potencia_punta']+consumo_energia*vm['penergia_pico'])
                *12/prod_anual_efectiva)

v02_impytasas_energia = ((vm['penergia_oim']+vm['penergia_dto2298']+vm['penergia_ersep']
                +vm['penergia_ley9819'])/100*v01_energia)

v03_maq_matriceria = (vm['pmaq_matriceria']*vm['dolar']*maq_matrices_cant/prod_anual_efectiva)

v04_maq_troqueladora = (vm['pmaq_troqueladora']*vm['dolar']*maq_troqueladora_cant
                *(1-maq_troqueladora_vresid/100)
                /maq_troqueladora_years/prod_anual_efectiva)

v05_maq_rebajar = (vm['pmaq_rebajar']*vm['dolar']*maq_rebajar_cant
                *(1-maq_rebajar_vresid/100)
                /maq_rebajar_years/prod_anual_efectiva)

v06_maq_coser = (vm['pmaq_coser']*vm['dolar']*maq_coser_cant
                *(1-maq_coser_vresid/100)
                /maq_coser_years/prod_anual_efectiva)

v07_maq_mesa_preparado = (vm['pmaq_mesa_preparado']*vm['dolar']*maq_mesa_preparado_cant
                *(1-maq_mesa_preparado_vresid/100)
                /maq_mesa_preparado_years/prod_anual_efectiva)

v08_maq_ojalillar = (vm['pmaq_ojalillar']*vm['dolar']*maq_ojalillar_cant
                *(1-maq_ojalillar_vresid/100)
                /maq_ojalillar_years/prod_anual_efectiva)

v09_maq_cambrar_talon = (vm['pmaq_cambrar_talon']*vm['dolar']
                *maq_cambrar_talon_cant*(1-maq_cambrar_talon_vresid/100)
                /maq_cambrar_talon_years/prod_anual_efectiva)

v10_maq_humectadora = (vm['pmaq_humectadora']*vm['dolar']
                *maq_humectadora_cant*(1-maq_humectadora_vresid/100)
                /maq_humectadora_years/prod_anual_efectiva)

v11_maq_centraryarmar = (vm['pmaq_centraryarmar']*vm['dolar']
                *maq_centraryarmar_cant*(1-maq_centraryarmar_vresid/100)
                /maq_centraryarmar_years/prod_anual_efectiva)

v12_maq_kamburian = (vm['pmaq_kamburian']*vm['dolar']
                *maq_kamburian_cant*(1-maq_kamburian_vresid/100)
                /maq_kamburian_years/prod_anual_efectiva)

v13_maq_cerrar_base = (vm['pmaq_cerrar_base']*vm['dolar']
                *maq_cerrar_base_cant*(1-maq_cerrar_base_vresid/100)
                /maq_cerrar_base_years/prod_anual_efectiva)

v14_maq_asentar = (vm['pmaq_asentar']*vm['dolar']
                *maq_asentar_cant*(1-maq_asentar_vresid/100)
                /maq_asentar_years/prod_anual_efectiva)

v15_maq_raspar = (vm['pmaq_raspar']*vm['dolar']
                *maq_raspar_cant*(1-maq_raspar_vresid/100)
                /maq_raspar_years/prod_anual_efectiva)

v16_maq_conformador = (vm['pmaq_conformador']*vm['dolar']
                *maq_conformador_cant*(1-maq_conformador_vresid/100)
                /maq_conformador_years/prod_anual_efectiva)

v17_maq_raspar_contorno = (vm['pmaq_raspar_contorno']*vm['dolar']
                *maq_raspar_contorno_cant*(1-maq_raspar_contorno_vresid/100)
                /maq_raspar_contorno_years/prod_anual_efectiva)

v18_maq_flash = (vm['pmaq_flash']*vm['dolar']
                *maq_flash_cant*(1-maq_flash_vresid/100)
                /maq_flash_years/prod_anual_efectiva)

v19_maq_pegar = (vm['pmaq_pegar']*vm['dolar']
                *maq_pegar_cant*(1-maq_pegar_vresid/100)
                /maq_pegar_years/prod_anual_efectiva)

v20_maq_sacardehorma = (vm['pmaq_sacardehorma']*vm['dolar']
                *maq_sacardehorma_cant*(1-maq_sacardehorma_vresid/100)
                /maq_sacardehorma_years/prod_anual_efectiva)

v21_maq_lustrar = (vm['pmaq_lustrar']*vm['dolar']
                *maq_lustrar_cant*(1-maq_lustrar_vresid/100)
                /maq_lustrar_years/prod_anual_efectiva)

v22_maq_marcar_suela = (vm['pmaq_marcar_suela']*vm['dolar']
                *maq_marcar_suela_cant*(1-maq_marcar_suela_vresid/100)
                /maq_marcar_suela_years/prod_anual_efectiva)

v23_maq_compresor = (vm['pmaq_compresor']*vm['dolar']
                *maq_compresor_cant*(1-maq_compresor_vresid/100)
                /maq_compresor_years/prod_anual_efectiva)

v24_costo_oportunidad = ((vm['pmaq_troqueladora'] * maq_troqueladora_cant
                * ((1-maq_troqueladora_vresid/100)/2+maq_troqueladora_vresid/100)
                + vm['pmaq_rebajar'] * maq_rebajar_cant
                * ((1-maq_rebajar_vresid/100)/2+maq_rebajar_vresid/100)
                + vm['pmaq_coser'] * maq_coser_cant
                * ((1-maq_coser_vresid/100)/2+maq_coser_vresid/100)
                + vm['pmaq_mesa_preparado'] * maq_mesa_preparado_cant
                * ((1-maq_mesa_preparado_vresid/100)/2+maq_mesa_preparado_vresid/100)
                + vm['pmaq_ojalillar'] * maq_ojalillar_cant
                * ((1-maq_ojalillar_vresid/100)/2+maq_ojalillar_vresid/100)
                + vm['pmaq_cambrar_talon'] * maq_cambrar_talon_cant
                * ((1-maq_cambrar_talon_vresid/100)/2+maq_cambrar_talon_vresid/100)
                + vm['pmaq_humectadora'] * maq_humectadora_cant
                * ((1-maq_humectadora_vresid/100)/2+maq_humectadora_vresid/100)
                + vm['pmaq_centraryarmar'] * maq_centraryarmar_cant
                * ((1-maq_centraryarmar_vresid/100)/2+maq_centraryarmar_vresid/100)
                + vm['pmaq_kamburian'] * maq_kamburian_cant
                * ((1-maq_kamburian_vresid/100)/2+maq_kamburian_vresid/100)
                + vm['pmaq_cerrar_base'] * maq_cerrar_base_cant
                * ((1-maq_cerrar_base_vresid/100)/2+maq_cerrar_base_vresid/100)
                + vm['pmaq_asentar'] * maq_asentar_cant
                * ((1-maq_asentar_vresid/100)/2+maq_asentar_vresid/100)
                + vm['pmaq_raspar'] * maq_raspar_cant
                * ((1-maq_raspar_vresid/100)/2+maq_raspar_vresid/100)
                + vm['pmaq_conformador'] * maq_conformador_cant
                * ((1-maq_conformador_vresid/100)/2+maq_conformador_vresid/100)
                + vm['pmaq_raspar_contorno'] * maq_raspar_contorno_cant
                * ((1-maq_raspar_contorno_vresid/100)/2+maq_raspar_contorno_vresid/100)
                + vm['pmaq_flash'] * maq_flash_cant
                * ((1-maq_flash_vresid/100)/2+maq_flash_vresid/100)
                + vm['pmaq_pegar'] * maq_pegar_cant
                * ((1-maq_pegar_vresid/100)/2+maq_pegar_vresid/100)
                + vm['pmaq_sacardehorma'] * maq_sacardehorma_cant
                * ((1-maq_sacardehorma_vresid/100)/2+maq_sacardehorma_vresid/100)
                + vm['pmaq_lustrar'] * maq_lustrar_cant
                * ((1-maq_lustrar_vresid/100)/2+maq_lustrar_vresid/100)
                + vm['pmaq_marcar_suela'] * maq_marcar_suela_cant
                * ((1-maq_marcar_suela_vresid/100)/2+maq_marcar_suela_vresid/100)
                + vm['pmaq_compresor'] * maq_compresor_cant
                * ((1-maq_compresor_vresid/100)/2+maq_compresor_vresid/100)
                + vm['pmaq_camioneta'] * maq_camioneta_cant
                * ((1-maq_camioneta_vresid/100)/2+maq_camioneta_vresid/100))
                * vm['dolar']*costo_oportunidad/100/prod_anual_efectiva)


v00_maquinaria= (v01_energia + v02_impytasas_energia + v03_maq_matriceria + v04_maq_troqueladora
                + v05_maq_rebajar + v06_maq_coser + v07_maq_mesa_preparado + v08_maq_ojalillar
                + v09_maq_cambrar_talon + v10_maq_humectadora + v11_maq_centraryarmar
                + v12_maq_kamburian + v13_maq_cerrar_base + v14_maq_asentar
                + v15_maq_raspar + v16_maq_conformador + v17_maq_raspar_contorno
                + v18_maq_flash + v19_maq_pegar + v20_maq_sacardehorma
                + v21_maq_lustrar + v22_maq_marcar_suela + v23_maq_compresor
                + v24_costo_oportunidad)

# Bloque VI.- Costos fijos no asociados a la producción

vi01_alquiler = (vm['palquiler']*vm['dolar']*galpon*12/prod_anual_efectiva)

vi02_mueblesyutiles = ((vm['pcomputadora'] / maq_computadoras_years
                + vm['pescritorio'] / maq_escritorios_years
                + vm['psilla'] / maq_escritorios_years ) * maq_computadoras_cant
                / prod_anual_efectiva )


vi03_mantenimiento = (vm['sal_operario']*2*mantenim_gral*12/prod_anual_efectiva)

vi04_limpieza = (vm['sal_operario']*2*limpieza*12/prod_anual_efectiva)

vi05_camioneta_repos = (vm['pmaq_camioneta']*vm['dolar']*maq_camioneta_cant*(1-maq_camioneta_vresid/100)
                /maq_camioneta_years/prod_anual_efectiva)


vi06_camioneta_combustible = (vm['pgasoil']*maq_camioneta_cant*uso_camioneta*consumo_gasoil*12
                /prod_anual_efectiva)

vi07_camioneta_mantenim = (vm['pmaq_camioneta']*vm['dolar']*maq_camioneta_cant*mantenim_camioneta
                /100/prod_anual_efectiva)

vi08_seguro_incendio = vm['pseguro_incendio']/prod_anual_efectiva


vi09_costo_financiero = ( ii00_materia_prima* 1.21 * (pow((1 + vm['tasa_interes_mensual']
                / 100 ),(plazo_cobro - plazo_pago_insumos) / 30)) + ( iii00_mano_obra_directa
                + iv00_mano_obra_indirecta ) * (pow((1 + vm['tasa_interes_mensual'] / 100),(plazo_cobro
                - plazo_pago_salarios )/ 30)) - ii00_materia_prima* 1.21 - ( iii00_mano_obra_directa
                + iv00_mano_obra_indirecta ))


vi10_estudio_contable = vm['pestudio_contable']*12/prod_anual_efectiva

vi11_beneficios = ((i00_pruebas_prod+ ii00_materia_prima+ iii00_mano_obra_directa+ iv00_mano_obra_indirecta + v00_maquinaria+ vi01_alquiler
                + vi02_mueblesyutiles + vi03_mantenimiento + vi04_limpieza
                + vi05_camioneta_repos + vi06_camioneta_combustible
                + vi07_camioneta_mantenim + vi08_seguro_incendio
                + vi09_costo_financiero + vi10_estudio_contable)*mark_up/100)

vi00_costos_fijos_no_prod= (vi01_alquiler + vi02_mueblesyutiles + vi03_mantenimiento + vi04_limpieza
                + vi05_camioneta_repos + vi06_camioneta_combustible
                + vi07_camioneta_mantenim + vi08_seguro_incendio
                + vi09_costo_financiero + vi10_estudio_contable
                + vi11_beneficios)


# Bloque VII.- Costos impositivos y aduaneros

vii01_ingresos_brutos = (0)

vii02_comercioeindustria = (0)

vii03_imp_ganancias = ((vi11_beneficios + v24_costo_oportunidad)
                * vm['impgcias_benef_alic']/100
                + (vi11_beneficios + v24_costo_oportunidad)
                * (1 - reinversion_utilidades/100)
                * vm['impgcias_benef_dist_alic']/100)


vii04_imp_cheque = ((i00_pruebas_prod+ ii00_materia_prima+ iii00_mano_obra_directa+ iv00_mano_obra_indirecta
                +v00_maquinaria+ vi00_costos_fijos_no_prod)
                * (vm['impcheque_alic']+vm['impcheque_ctagcias_alic'])/100)

vii05_deposito_fiscal = ( vm['deposito_fiscal'] * vm['dolar'] / parametro_volumen )

vii06_archivo_digitalizacion_embarque = ( vm['archivo_digitalizacion_embarque']
                * vm['dolar'] / tamaño_envios_exterior )

vii07_certificado_origen = ( vm['certificado_origen']
                * vm['dolar'] / tamaño_envios_exterior )

vii08_gastos_operativos_despachante = ( vm['gastos_operativos_despachante']
                * vm['dolar'] / tamaño_envios_exterior )

vii09_despachante_aduana = (( i00_pruebas_prod + ii00_materia_prima
            + iii00_mano_obra_directa + iv00_mano_obra_indirecta
            + v00_maquinaria + vi00_costos_fijos_no_prod + 
            + vii01_ingresos_brutos
            + vii02_comercioeindustria + vii03_imp_ganancias
            + vii04_imp_cheque + vii05_deposito_fiscal
            + vii06_archivo_digitalizacion_embarque + vii07_certificado_origen
            + vii08_gastos_operativos_despachante )
            * vm['despachante_aduanas_porcent'] / 100 )

vii10_comision_vendedor_chile = (( i00_pruebas_prod + ii00_materia_prima
            + iii00_mano_obra_directa + iv00_mano_obra_indirecta
            + v00_maquinaria + vi00_costos_fijos_no_prod + 
            + vii01_ingresos_brutos
            + vii02_comercioeindustria + vii03_imp_ganancias
            + vii04_imp_cheque + vii05_deposito_fiscal
            + vii06_archivo_digitalizacion_embarque + vii07_certificado_origen
            + vii08_gastos_operativos_despachante )
            * vm['comision_vendedor'] / 100 )

vii11_reintegros_exportacion = ( - ( i00_pruebas_prod + ii00_materia_prima
            + iii00_mano_obra_directa + iv00_mano_obra_indirecta
            + v00_maquinaria + vi00_costos_fijos_no_prod + 
            + vii01_ingresos_brutos
            + vii02_comercioeindustria + vii03_imp_ganancias
            + vii04_imp_cheque ) / ( 1 + vm['reintegros_expo_porcent'] / 100 )
            * vm['reintegros_expo_porcent'] / 100 )

vii12_derechos_exportacion = (( i00_pruebas_prod + ii00_materia_prima
            + iii00_mano_obra_directa + iv00_mano_obra_indirecta
            + v00_maquinaria + vi00_costos_fijos_no_prod + 
            + vii01_ingresos_brutos
            + vii02_comercioeindustria + vii03_imp_ganancias
            + vii04_imp_cheque + vii05_deposito_fiscal
            + vii06_archivo_digitalizacion_embarque + vii07_certificado_origen
            + vii08_gastos_operativos_despachante + vii09_despachante_aduana
            + vii10_comision_vendedor_chile + vii11_reintegros_exportacion )
            / ( 1 - vm['derechos_expo_porcent'] / 100 )
            * vm['derechos_expo_PYME'] / 100 )


vii00_impuestosyaduaneros = ( vii01_ingresos_brutos + vii02_comercioeindustria
            + vii03_imp_ganancias + vii04_imp_cheque + vii05_deposito_fiscal
            + vii06_archivo_digitalizacion_embarque + vii07_certificado_origen
            + vii08_gastos_operativos_despachante + vii09_despachante_aduana
            + vii10_comision_vendedor_chile + vii11_reintegros_exportacion
            + vii12_derechos_exportacion )

# Bloque indicadores de costos

                    
Costo_Total_pesos = (i00_pruebas_prod + ii00_materia_prima
            + iii00_mano_obra_directa + iv00_mano_obra_indirecta
            + v00_maquinaria + vi00_costos_fijos_no_prod
            + vii00_impuestosyaduaneros)

Costo_Total_dolares = Costo_Total_pesos / vm['dolar']




# CONTROL:
print(Costo_Total_dolares)



