# Programa en Python - Sistema Estadistico de Costos Industria del Mueble


# MÓDULO I - CARGA DE VARIABLES MONETARIAS

import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import seaborn as sns

# Importar base de datos de series de tiempo con variables monetarias:

vm = pd.read_excel('Muebles variables monetarias v01.xlsx')


# Convertir columna mes en variable indexadora temporal:

vm.mes = pd.to_datetime(vm.mes)
vm.set_index('mes', inplace=True)       


# MÓDULO II - DEFINICION DE PARÁMETROS

# Parámetros generales
q_materia_prima = 72
q_dias_aprovisionamiento = 20
q_produccion_mensual_potencial = 6500
q_capacidad_utilizada = 100
q_produccion_mensual_efectiva = (q_produccion_mensual_potencial
                    * q_capacidad_utilizada/100)


# Mano de obra directa
q_jornada = 146
q_oficiales_aserradero = 7
q_ayudantes_aserradero = 11
q_autoelevadoristas_aserradero = 1
q_oficiales_secado = 3
q_ayudantes_secado = 0
q_autoelevadoristas_secado = 1
q_oficiales_remanufactura = 7
q_peones_remanufactura = 10
q_autoelevadoristas_remanufactura = 1

# Mano de obra indirecta
q_supervisores = 2
q_afiladores = 2
q_pers_mantenimiento = 2
q_pers_ventas = 1
q_pers_administrativo = 1
q_gerente_produccion = 1
q_gerente_ventas = 1
q_gerente_general = 1

# Maquinaria
q_descortezadora = 1
q_gemela = 1
q_reaserradora = 1
q_multiple = 1
q_canteadora = 1
q_despuntadora = 1
q_chipera = 1
q_cadena_verde = 1
q_cinta_transportadora = 1
q_sala_afilado = 2
q_compensador = 2
q_pala_cargadora = 1
q_camara1_secado = 1
q_camara2_secado = 1
q_caldera = 1
q_autoelevador = 2
q_opticut = 1
q_finger_joint = 1
q_moldurera = 1
q_prensa_tableros = 1
q_lijadora = 1
q_escuadradora = 1

y_descortezadora = 20
y_gemela = 20
y_reaserradora = 20
y_multiple = 20
y_canteadora = 20
y_despuntadora = 20
y_chipera = 20
y_cadena_verde = 20
y_cinta_transportadora = 20
y_sala_afilado = 20
y_compensador = 20
y_pala_cargadora = 20
y_camara1_secado = 20
y_camara2_secado = 20
y_caldera = 20
y_autoelevador = 20
y_opticut = 20
y_finger_joint = 20
y_moldurera = 20
y_prensa_tableros = 20
y_lijadora = 20
y_escuadradora = 20

vr_descortezadora = 30
vr_gemela = 30
vr_reaserradora = 30
vr_multiple = 30
vr_canteadora = 30
vr_despuntadora = 30
vr_chipera = 30
vr_cadena_verde = 30
vr_cinta_transportadora = 30
vr_sala_afilado = 30
vr_compensador = 30
vr_pala_cargadora = 30
vr_camara1_secado = 30
vr_camara2_secado = 30
vr_caldera = 30
vr_autoelevador = 30
vr_opticut = 30
vr_finger_joint = 30
vr_moldurera = 30
vr_prensa_tableros = 30
vr_lijadora = 30
vr_escuadradora = 30

costo_oportunidad = 4


# Consumibles y mantenimiento

q_energia_potencia = 600               # kw
q_energia_consumo = 98000              # kw/h mensuales
q_energia_potencia_punta = 5
q_energia_potencia_fuerapunta = 19
q_energia_pico = 5
q_energia_valle = 6
q_energia_resto = 13
q_galpon = 4000              # m2 de alquiler

# Parámetros laborales
q_antiguedad = 5           # promedio de años
q_antiguedad_coef = 1
q_prendas = 4         # cantidad por año
q_casco = 2           # cantidad por año
q_guantes = 2         # cantidad por año
q_sac = 8.33
q_vacaciones = 21
q_fondo_despido = 4
q_ausentismo = 3

# Parámetros costos fijos y varios

q_puestos_oficina = 5
q_amortizacion_computadoras = 5
q_amortizacion_muebles = 10
plazo_pago_insumos = 30
plazo_cobro = 60
plazo_pago_salarios = 30

mark_up = 5

# Parámetros tributarios
q_ventas_cba = 100
q_ventas_pba = 0
q_ventas_stafe = 0
q_ventas_cuyo = 0
q_ventas_mesopotamia = 0
q_ventas_noa = 0
q_ventas_neuquen = 0
reinversion_utilidades = 50


# MÓDULO III - ESTIMACIONES DE COSTOS


# Bloque I.- Materia prima

i01_rollizos_madera = (q_dias_aprovisionamiento * q_materia_prima
              * vm['p_rollizos_madera'] / q_produccion_mensual_efectiva)

i02_transporte_rollizos_madera = (q_dias_aprovisionamiento * q_materia_prima
              * vm['p_transporte_rollizos_madera'] / q_produccion_mensual_efectiva)

i00_materia_prima = (i01_rollizos_madera + i02_transporte_rollizos_madera)


# Bloque II.- Mano de obra directa

ii01_remuneracion_operarios = (((q_oficiales_aserradero + q_oficiales_secado
                + q_oficiales_remanufactura)
                *vm['w_madera_oficial_general']
                + (q_ayudantes_aserradero + q_ayudantes_secado)
                *vm['w_madera_ayudante'] + ( q_autoelevadoristas_aserradero
                + q_autoelevadoristas_secado + q_autoelevadoristas_remanufactura)
                * vm['w_madera_oficial_especializado'] + q_peones_remanufactura
                * vm['w_madera_peon'] ) * q_jornada / q_produccion_mensual_efectiva )  

ii02_remuneracion_operarios_norem = 0
                               
ii03_horas_extras = 0

ii04_horas_extras2 = 0

ii05_antiguedad = ((ii01_remuneracion_operarios + ii03_horas_extras + ii04_horas_extras2)
                *q_antiguedad * q_antiguedad_coef/100)

ii06_sac = ((ii01_remuneracion_operarios + ii03_horas_extras + ii04_horas_extras2
                + ii05_antiguedad) * q_sac / 100)

ii07_vacaciones = ((ii01_remuneracion_operarios + ii03_horas_extras + ii04_horas_extras2
                + ii05_antiguedad) / 30 * q_vacaciones/12)

ii08_contrib_patronales = ((ii01_remuneracion_operarios + ii03_horas_extras + ii04_horas_extras2
                + ii05_antiguedad + ii06_sac + ii07_vacaciones
                - vm['t_cont_patronales_mni']
                * (q_oficiales_aserradero + q_oficiales_secado + q_oficiales_remanufactura
                + q_ayudantes_aserradero + q_ayudantes_secado
                + q_peones_remanufactura
                + q_autoelevadoristas_aserradero + q_autoelevadoristas_secado + q_autoelevadoristas_remanufactura)
                / q_produccion_mensual_efectiva)
                * vm['t_cont_patronales_total'] / 100)

ii09_contrib_patronales_cred_fiscal = -((ii01_remuneracion_operarios + ii03_horas_extras + ii04_horas_extras2
                + ii05_antiguedad + ii06_sac + ii07_vacaciones
                - vm['t_cont_patronales_mni']
                * (q_oficiales_aserradero + q_oficiales_secado + q_oficiales_remanufactura
                + q_ayudantes_aserradero + q_ayudantes_secado
                + q_peones_remanufactura
                + q_autoelevadoristas_aserradero + q_autoelevadoristas_secado + q_autoelevadoristas_remanufactura)
                / q_produccion_mensual_efectiva)
                * vm['t_cont_patronales_cred_fisc'] / 100)

ii10_contrib_osocial = ((ii01_remuneracion_operarios + ii03_horas_extras + ii04_horas_extras2
                + ii05_antiguedad + ii06_sac + ii07_vacaciones)
                *vm['t_cont_osocial'] / 100)

ii11_seguro_vida_obligatorio = ((ii01_remuneracion_operarios + ii03_horas_extras + ii04_horas_extras2
                + ii05_antiguedad + ii06_sac + ii07_vacaciones)
                *vm['p_seguro_vida_oblig_muebles'] / 100)

ii12_art = ((ii01_remuneracion_operarios + ii03_horas_extras + ii04_horas_extras2
                + ii05_antiguedad + ii06_sac + ii07_vacaciones) * vm['p_art'] / 100)

ii13_prev_despido = ((ii01_remuneracion_operarios + ii03_horas_extras + ii04_horas_extras2
                + ii05_antiguedad + ii06_sac + ii07_vacaciones)
                * q_fondo_despido / 100)

ii14_ausentismo = ((ii01_remuneracion_operarios + ii05_antiguedad + ii06_sac
                + ii07_vacaciones + ii08_contrib_patronales + ii09_contrib_patronales_cred_fiscal
                + ii10_contrib_osocial + ii11_seguro_vida_obligatorio + ii12_art
                + ii13_prev_despido ) * q_ausentismo / 100)

ii00_mano_obra_directa = (ii01_remuneracion_operarios + ii02_remuneracion_operarios_norem
                + ii03_horas_extras + ii04_horas_extras2 + ii05_antiguedad + ii06_sac
                + ii07_vacaciones + ii08_contrib_patronales
                + ii09_contrib_patronales_cred_fiscal + ii10_contrib_osocial
                + ii11_seguro_vida_obligatorio + ii12_art + ii13_prev_despido
                + ii14_ausentismo)


# Bloque III.- Mano de obra indirecta

iii01_rem_supervisores = (q_supervisores * vm['w_madera_supervisor']
                / q_produccion_mensual_efectiva)
                        
iii02_rem_afiladores = (q_afiladores * vm['w_madera_afilador']
                / q_produccion_mensual_efectiva)

iii03_rem_mantenimiento = (q_pers_mantenimiento * vm['w_madera_mantenim']
                / q_produccion_mensual_efectiva)

iii04_rem_ventas = (q_pers_ventas * vm['w_madera_ventas']
                / q_produccion_mensual_efectiva)

iii05_rem_administrativos = (q_pers_administrativo * vm['w_madera_admin']
                / q_produccion_mensual_efectiva)

iii06_rem_gerente_produccion = (q_gerente_produccion * vm['w_madera_gte_prod']
                / q_produccion_mensual_efectiva)

iii07_rem_gerente_ventas = (q_gerente_ventas * vm['w_madera_gte_ventas']
                / q_produccion_mensual_efectiva)

iii08_rem_gerente_general = (q_gerente_general * vm['w_madera_gerente_gral']
                / q_produccion_mensual_efectiva)

iii09_antiguedad = ((iii01_rem_supervisores + iii02_rem_afiladores
                + iii03_rem_mantenimiento + iii04_rem_ventas
                + iii05_rem_administrativos + iii06_rem_gerente_produccion
                + iii07_rem_gerente_ventas + iii08_rem_gerente_general)
                * q_antiguedad * q_antiguedad_coef / 100)

iii10_sac = ((iii01_rem_supervisores + iii02_rem_afiladores
                + iii03_rem_mantenimiento + iii04_rem_ventas
                + iii05_rem_administrativos + iii06_rem_gerente_produccion
                + iii07_rem_gerente_ventas + iii08_rem_gerente_general
                + iii09_antiguedad) * q_sac / 100)

iii11_vacaciones = ((iii01_rem_supervisores + iii02_rem_afiladores
                + iii03_rem_mantenimiento + iii04_rem_ventas
                + iii05_rem_administrativos + iii06_rem_gerente_produccion
                + iii07_rem_gerente_ventas + iii08_rem_gerente_general
                + iii09_antiguedad)
                / 30 * q_vacaciones / 12)

iii12_contribuciones = ((iii01_rem_supervisores + iii02_rem_afiladores
                + iii03_rem_mantenimiento + iii04_rem_ventas
                + iii05_rem_administrativos + iii06_rem_gerente_produccion
                + iii07_rem_gerente_ventas + iii08_rem_gerente_general
                + iii09_antiguedad
                + iii10_sac + iii11_vacaciones
                - vm['t_cont_patronales_mni'] *
                (q_supervisores + q_afiladores + q_pers_mantenimiento
                + q_gerente_produccion + q_gerente_ventas
                + q_gerente_general) / q_produccion_mensual_efectiva)
                * vm['t_cont_patronales_total'] / 100)

iii13_contrib_crevmiscal = -((iii01_rem_supervisores + iii02_rem_afiladores
                + iii03_rem_mantenimiento + iii04_rem_ventas
                + iii05_rem_administrativos + iii06_rem_gerente_produccion
                + iii07_rem_gerente_ventas + iii08_rem_gerente_general
                + iii09_antiguedad
                + iii10_sac + iii11_vacaciones
                - vm['t_cont_patronales_mni'] *
                (q_supervisores + q_afiladores + q_pers_mantenimiento
                + q_gerente_produccion + q_gerente_ventas
                + q_gerente_general) / q_produccion_mensual_efectiva)
                *vm['t_cont_patronales_cred_fisc']/100)

iii14_contrib_osocial = ((iii01_rem_supervisores + iii02_rem_afiladores
                + iii03_rem_mantenimiento + iii04_rem_ventas
                + iii05_rem_administrativos + iii06_rem_gerente_produccion
                + iii07_rem_gerente_ventas + iii08_rem_gerente_general
                + iii09_antiguedad
                + iii10_sac + iii11_vacaciones) * vm['t_cont_osocial']/100)

iii15_seguro_vida = ((iii01_rem_supervisores + iii02_rem_afiladores
                + iii03_rem_mantenimiento + iii04_rem_ventas
                + iii05_rem_administrativos + iii06_rem_gerente_produccion
                + iii07_rem_gerente_ventas + iii08_rem_gerente_general
                + iii09_antiguedad
                + iii10_sac + iii11_vacaciones) * vm['p_seguro_vida_oblig_muebles']/100)

iii16_art = ((iii01_rem_supervisores + iii02_rem_afiladores
                + iii03_rem_mantenimiento + iii04_rem_ventas
                + iii05_rem_administrativos + iii06_rem_gerente_produccion
                + iii07_rem_gerente_ventas + iii08_rem_gerente_general
                + iii09_antiguedad
                + iii10_sac + iii11_vacaciones) * vm['p_art']/100)

iii17_prevision_despido = ((iii01_rem_supervisores + iii02_rem_afiladores
                + iii03_rem_mantenimiento + iii04_rem_ventas
                + iii05_rem_administrativos + iii06_rem_gerente_produccion
                + iii07_rem_gerente_ventas + iii08_rem_gerente_general
                + iii09_antiguedad
                + iii10_sac + iii11_vacaciones) * q_fondo_despido / 100)

iii00_mano_obra_indirecta = (iii01_rem_supervisores + iii02_rem_afiladores
                + iii03_rem_mantenimiento + iii04_rem_ventas
                + iii05_rem_administrativos + iii06_rem_gerente_produccion
                + iii07_rem_gerente_ventas + iii08_rem_gerente_general
                + iii09_antiguedad
                + iii10_sac + iii11_vacaciones + iii12_contribuciones + iii13_contrib_crevmiscal
                + iii14_contrib_osocial + iii15_seguro_vida + iii16_art
                + iii17_prevision_despido)
                               

# Bloque IV.- Costo de maquinaria

iv01_energia = ((q_energia_potencia * q_energia_potencia_punta / (q_energia_potencia_punta+q_energia_potencia_fuerapunta) * vm['p_energia_potencia_punta']
                 + q_energia_potencia * q_energia_potencia_fuerapunta / (q_energia_potencia_punta+q_energia_potencia_fuerapunta) * vm['p_energia_potencia_fuerapunta']
                 + q_energia_consumo * q_energia_pico / (q_energia_pico+q_energia_valle+q_energia_resto) * vm['p_energia_pico']
                 + q_energia_consumo * q_energia_valle / (q_energia_pico+q_energia_valle+q_energia_resto) * vm['p_energia_valle']
                 + q_energia_consumo * q_energia_resto / (q_energia_pico+q_energia_valle+q_energia_resto) * vm['p_energia_resto'])
                 / q_produccion_mensual_efectiva)

iv02_impuestos_energia = ((vm['t_energia_perc_dgi'] + vm['t_energia_oim'] + vm['t_energia_dto2298']
                + vm['t_energia_ersep'] + vm['t_energia_ley9819']) / 100
                * iv01_energia)

iv03_repos_descortezadora = (q_descortezadora * vm['p_descortezadora'] * vm['dolar']
                * (1-vr_descortezadora/100) / y_descortezadora / 12
                / q_produccion_mensual_efectiva)
                               
iv04_repos_gemela = (q_gemela * vm['p_gemela'] * vm['dolar']
                * (1-vr_gemela/100) / y_gemela / 12
                / q_produccion_mensual_efectiva)

iv05_repos_reaserradora = (q_reaserradora * vm['p_reaserradora'] * vm['dolar']
                * (1-vr_reaserradora/100) / y_reaserradora / 12
                / q_produccion_mensual_efectiva)

iv06_repos_multiple = (q_multiple * vm['p_multiple'] * vm['dolar']
                * (1-vr_multiple/100) / y_multiple / 12
                / q_produccion_mensual_efectiva)

iv07_repos_canteadora = (q_canteadora * vm['p_canteadora'] * vm['dolar']
                * (1-vr_canteadora/100) / y_canteadora / 12
                / q_produccion_mensual_efectiva)

iv08_repos_despuntadora = (q_despuntadora * vm['p_despuntadora'] * vm['dolar']
                * (1-vr_despuntadora/100) / y_despuntadora / 12
                / q_produccion_mensual_efectiva)

iv09_repos_chipera = (q_chipera * vm['p_chipera'] * vm['dolar']
                * (1-vr_chipera/100) / y_chipera / 12
                / q_produccion_mensual_efectiva)

iv10_repos_cadena_verde = (q_cadena_verde * vm['p_cadena_verde'] * vm['dolar']
                * (1-vr_cadena_verde/100) / y_cadena_verde / 12
                / q_produccion_mensual_efectiva)

iv11_repos_cinta_transportadora = (q_cinta_transportadora * vm['p_cinta_transportadora'] * vm['dolar']
                * (1-vr_cinta_transportadora/100) / y_cinta_transportadora / 12
                / q_produccion_mensual_efectiva)

iv12_repos_sala_afilado = (q_sala_afilado * vm['p_sala_afilado'] * vm['dolar']
                * (1-vr_sala_afilado/100) / y_sala_afilado / 12
                / q_produccion_mensual_efectiva)

iv13_repos_compensador = (q_compensador * vm['p_compensador'] * vm['dolar']
                * (1-vr_compensador/100) / y_compensador / 12
                / q_produccion_mensual_efectiva)

iv14_repos_pala_cargadora = (q_pala_cargadora * vm['p_pala_cargadora'] * vm['dolar']
                * (1-vr_pala_cargadora/100) / y_pala_cargadora / 12
                / q_produccion_mensual_efectiva)


iv15_repos_camara1_secado = (q_camara1_secado * vm['p_camara1_secado'] * vm['dolar']
                * (1-vr_camara1_secado/100) / y_camara1_secado / 12
                / q_produccion_mensual_efectiva)

iv16_repos_camara2_secado = (q_camara2_secado * vm['p_camara2_secado'] * vm['dolar']
                * (1-vr_camara2_secado/100) / y_camara2_secado / 12
                / q_produccion_mensual_efectiva)

iv17_repos_caldera = (q_caldera * vm['p_caldera'] * vm['dolar']
                * (1-vr_caldera/100) / y_caldera / 12
                / q_produccion_mensual_efectiva)

iv18_repos_autoelevador = (q_autoelevador * vm['p_autoelevador'] * vm['dolar']
                * (1-vr_autoelevador/100) / y_autoelevador / 12
                / q_produccion_mensual_efectiva)

iv19_repos_opticut = (q_opticut * vm['p_opticut'] * vm['dolar']
                * (1-vr_opticut/100) / y_opticut / 12
                / q_produccion_mensual_efectiva)

iv20_repos_finger_joint = (q_finger_joint * vm['p_finger_joint'] * vm['dolar']
                * (1-vr_finger_joint/100) / y_finger_joint / 12
                / q_produccion_mensual_efectiva)

iv21_repos_moldurera = (q_moldurera * vm['p_moldurera'] * vm['dolar']
                * (1-vr_moldurera/100) / y_moldurera / 12
                / q_produccion_mensual_efectiva)

iv22_repos_prensa_tableros = (q_prensa_tableros * vm['p_prensa_tableros'] * vm['dolar']
                * (1-vr_prensa_tableros/100) / y_prensa_tableros / 12
                / q_produccion_mensual_efectiva)

iv23_repos_lijadora = (q_lijadora * vm['p_lijadora'] * vm['dolar']
                * (1-vr_lijadora/100) / y_lijadora / 12
                / q_produccion_mensual_efectiva)

iv24_repos_escuadradora = (q_escuadradora * vm['p_escuadradora'] * vm['dolar']
                * (1-vr_escuadradora/100) / y_escuadradora / 12
                / q_produccion_mensual_efectiva)


iv25_costo_oportunidad = ((q_descortezadora * vm['p_descortezadora'] * vm['dolar']
                * ((1-vr_descortezadora/100) / 2 + vr_descortezadora/100)
                + q_gemela * vm['p_gemela'] * vm['dolar']
                * ((1-vr_gemela/100) / 2 + vr_gemela/100)
                + q_reaserradora * vm['p_reaserradora'] * vm['dolar']
                * ((1-vr_reaserradora/100) / 2 + vr_reaserradora/100)
                + q_multiple * vm['p_multiple'] * vm['dolar']
                * ((1-vr_multiple/100) / 2 + vr_multiple/100)
                + q_canteadora * vm['p_canteadora'] * vm['dolar']
                * ((1-vr_canteadora/100) / 2 + vr_canteadora/100)
                + q_despuntadora * vm['p_despuntadora'] * vm['dolar']
                * ((1-vr_despuntadora/100) / 2 + vr_despuntadora/100)
                + q_chipera * vm['p_chipera'] * vm['dolar']
                * ((1-vr_chipera/100) / 2 + vr_chipera/100)
                + q_cadena_verde * vm['p_cadena_verde'] * vm['dolar']
                * ((1-vr_cadena_verde/100) / 2 + vr_cadena_verde/100)
                + q_cinta_transportadora * vm['p_cinta_transportadora'] * vm['dolar']
                * ((1-vr_cinta_transportadora/100) / 2 + vr_cinta_transportadora/100)
                + q_sala_afilado * vm['p_sala_afilado'] * vm['dolar']
                * ((1-vr_sala_afilado/100) / 2 + vr_sala_afilado/100)
                + q_compensador * vm['p_compensador'] * vm['dolar']
                * ((1-vr_compensador/100) / 2 + vr_compensador/100)
                + q_pala_cargadora * vm['p_pala_cargadora'] * vm['dolar']
                * ((1-vr_pala_cargadora/100) / 2 + vr_pala_cargadora/100)
                + q_camara1_secado * vm['p_camara1_secado'] * vm['dolar']
                * ((1-vr_camara1_secado/100) / 2 + vr_camara1_secado/100)
                + q_camara2_secado * vm['p_camara2_secado'] * vm['dolar']
                * ((1-vr_camara2_secado/100) / 2 + vr_camara2_secado/100)
                + q_caldera * vm['p_caldera'] * vm['dolar']
                * ((1-vr_caldera/100) / 2 + vr_caldera/100)
                + q_autoelevador * vm['p_autoelevador'] * vm['dolar']
                * ((1-vr_autoelevador/100) / 2 + vr_autoelevador/100)
                + q_opticut * vm['p_opticut'] * vm['dolar']
                * ((1-vr_opticut/100) / 2 + vr_opticut/100)
                + q_finger_joint * vm['p_finger_joint'] * vm['dolar']
                * ((1-vr_finger_joint/100) / 2 + vr_finger_joint/100)
                + q_moldurera * vm['p_moldurera'] * vm['dolar']
                * ((1-vr_moldurera/100) / 2 + vr_moldurera/100)
                + q_prensa_tableros * vm['p_prensa_tableros'] * vm['dolar']
                * ((1-vr_prensa_tableros/100) / 2 + vr_prensa_tableros/100)
                + q_lijadora * vm['p_lijadora'] * vm['dolar']
                * ((1-vr_lijadora/100) / 2 + vr_lijadora/100)
                + q_escuadradora * vm['p_escuadradora'] * vm['dolar']
                * ((1-vr_escuadradora/100) / 2 + vr_escuadradora/100))
                * costo_oportunidad /100 / 12 / q_produccion_mensual_efectiva)


iv00_maquinaria = (iv01_energia + iv02_impuestos_energia + iv03_repos_descortezadora
                   + iv04_repos_gemela + iv05_repos_reaserradora + iv06_repos_multiple
                   + iv07_repos_canteadora + iv08_repos_despuntadora + iv09_repos_chipera
                   + iv10_repos_cadena_verde + iv11_repos_cinta_transportadora
                   + iv12_repos_sala_afilado + iv13_repos_compensador
                   + iv14_repos_pala_cargadora + iv15_repos_camara1_secado
                   + iv16_repos_camara2_secado + iv17_repos_caldera
                   + iv18_repos_autoelevador + iv19_repos_opticut
                   + iv20_repos_finger_joint + iv21_repos_moldurera
                   + iv22_repos_prensa_tableros + iv23_repos_lijadora
                   + iv24_repos_escuadradora + iv25_costo_oportunidad)

                               
# Bloque V.- Costos fijos no asociados a la producción

v01_alquiler = (vm['p_alquiler_aserradero'] * vm['dolar'] * q_galpon / q_produccion_mensual_efectiva)

v02_muebles = ((vm['p_computadora'] * q_puestos_oficina / q_amortizacion_computadoras
                 + vm['p_escritorio'] * q_puestos_oficina / q_amortizacion_muebles
                 + vm['p_silla'] * q_puestos_oficina / q_amortizacion_muebles) / 12
                / q_produccion_mensual_efectiva)

v03_costo_financiero = (i00_materia_prima * ( pow ( 1
                + vm['p_tasa_interes_diaria'] /100,( plazo_cobro
                - plazo_pago_insumos ))) - i00_materia_prima 
                + ( ii00_mano_obra_directa + iii00_mano_obra_indirecta )
                * ( pow ( 1 + vm['p_tasa_interes_diaria'] / 100,( plazo_cobro
                - plazo_pago_salarios )))
                - (ii00_mano_obra_directa + iii00_mano_obra_indirecta ))
                

v04_estudio_contable = (vm['p_estudio_contable'] / q_produccion_mensual_efectiva)

v05_beneficios = ((i00_materia_prima + ii00_mano_obra_directa + iii00_mano_obra_indirecta
                + iv00_maquinaria + v01_alquiler + v02_muebles + v03_costo_financiero
                + v04_estudio_contable) * mark_up / 100)


v00_costos_fijos = (v01_alquiler + v02_muebles + v03_costo_financiero
                + v04_estudio_contable + v05_beneficios)
                        

# Bloque VI.- Costos impositivos

#vi01_impuesto_ingresos_brutos = ((i00_materia_prima + ii00_mano_obra_directa
#               + iii00_mano_obra_indirecta + iv00_maquinaria + v00_costos_fijos)
#               * (vm['t_ib_extjuris_pba']/100 * q_ventas_pba / 100
#               + vm['t_ib_extjuris_stafe']/100 * q_ventas_stafe / 100
#               + vm['t_ib_extjuris_mza']/100 * q_ventas_cuyo / 100
#               + vm['t_ib_extjuris_corrientes']/100 * q_ventas_mesopotamia / 100
#               + vm['t_ib_extjuris_salta']/100 * q_ventas_noa / 100
#               + vm['t_ib_extjuris_neuquen']/100 * q_ventas_neuquen / 100))

vi01_impuesto_ingresos_brutos = (0)

#vi02_tasa_comercioeindustria = ((i00_materia_prima + ii00_mano_obra_directa
#               + iii00_mano_obra_indirecta + iv00_maquinaria + v00_costos_fijos)
#               * vm['t_comercioeindustria']/100)

vi02_tasa_comercioeindustria = (0)

#IMPUESTO A LAS GANANCIAS CON COSTO DE OPORTUNIDAD
#vi03_impuesto_ganancias = ((v05_beneficios + iv25_costo_oportunidad)
#               * vm['t_ganancias']/100
#               + (v05_beneficios + iv25_costo_oportunidad)
#               * (1 - reinversion_utilidades/100)
#               * vm['t_dividendos']/100)

vi03_impuesto_ganancias = ((v05_beneficios )
                * vm['t_ganancias']/100
                + (v05_beneficios )
                * (1 - reinversion_utilidades/100)
                * vm['t_dividendos']/100)

#vi04_impuesto_cheque = ((i00_materia_prima + ii00_mano_obra_directa
#               + iii00_mano_obra_indirecta + iv00_maquinaria + v00_costos_fijos)
#               * 1.21 * (vm['t_cheque']+vm['t_cheque_cred_fiscal'])/100)

vi04_impuesto_cheque = (0)

vi00_impuestos = (vi01_impuesto_ingresos_brutos + vi02_tasa_comercioeindustria
                + vi03_impuesto_ganancias + vi04_impuesto_cheque)
                   


# Bloque Indicadores de costos

                    
costo_tablero_pesos = (i00_materia_prima + ii00_mano_obra_directa
                + iii00_mano_obra_indirecta + iv00_maquinaria
                + v00_costos_fijos + vi00_impuestos)

costo_tablero_dolares = costo_tablero_pesos / vm['dolar']




# CONTROL:
print(vi00_impuestos)

