# Programa en Python - Sistema Estadistico de Costos Industria del Mueble


# MÓDULO I - CARGA DE VARIABLES MONETARIAS

import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import seaborn as sns

# Importar base de datos de series de tiempo con variables monetarias:

vm = pd.read_excel('Muebles variables monetarias v01.xlsx')


# Convertir columna mes en variable indexadora temporal:

vm.mes = pd.to_datetime(vm.mes)
vm.set_index('mes', inplace=True)       


# MÓDULO II - DEFINICION DE PARÁMETROS

# Parámetros generales
q_produccion_mensual_potencial = 3200
q_capacidad_utilizada = 100
q_produccion_mensual_efectiva = q_produccion_mensual_potencial * q_capacidad_utilizada / 100


# Materias primas

q_melamina = 3.3    # m2 por gabinete
q_manijas = 2
q_ensambles = 8
q_regatones = 5
q_tarugos = 8
q_soportes_estantes = 4
q_bisagras = 4
q_cerraduras = 1
q_tornillos = 1     # kits por gatinete
q_marquillas = 1
q_cantos = 20.4     # ml por gabinete
q_cola = 0.24       # kg por gabinete



# Mano de obra directa
q_jornada = 192
q_operarios_seccionadora = 2
q_operarios_pegado = 4
q_operarios_centros_trabajo = 2
q_operarios_bancos_armado = 4
q_operarios_alimentador_piezas = 2


# Mano de obra indirecta
q_supervisores = 2
q_disenadores = 1
q_planificacion_prod = 1
q_pers_compras = 1
q_pers_mantenimiento = 1
q_pers_maestranza = 1
q_pers_administrativo = 3
q_vendedores = 2
q_gerente_general = 1

# Maquinaria
q_seccionadora = 1
q_pegadora_canto = 2
q_centro_trabajo = 2
q_banco_armado = 4
q_herramientas_neumaticas = 4
q_autoelevador = 2

y_seccionadora = 8
y_pegadora_canto = 8
y_centro_trabajo = 8
y_banco_armado = 15
y_herramientas_neumaticas = 3
y_autoelevador = 5

vr_seccionadora = 30
vr_pegadora_canto = 30
vr_centro_trabajo = 50
vr_banco_armado = 0
vr_herramientas_neumaticas = 0
vr_autoelevador = 0

costo_oportunidad = 4


# Consumibles y mantenimiento

q_energia_potencia = 140               # kw
q_energia_consumo = 22000              # kw/h mensuales
q_energia_potencia_punta = 5
q_energia_potencia_fuerapunta = 19
q_energia_pico = 5
q_energia_valle = 6
q_energia_resto = 13
q_galpon = 3300              # m2 de alquiler

# Parámetros laborales
q_antiguedad = 5           # promedio de años
q_antiguedad_coef = 1
q_prendas = 4         # cantidad por año
q_casco = 2           # cantidad por año
q_guantes = 2         # cantidad por año
q_sac = 8.33
q_vacaciones = 21
q_fondo_despido = 4
q_ausentismo = 3

# Parámetros costos fijos y varios

q_puestos_oficina = 13
q_amortizacion_computadoras = 5
q_amortizacion_muebles = 10
plazo_pago_insumos = 21
plazo_cobro = 60
plazo_pago_salarios = 30
mark_up = 10


# Parámetros tributarios
q_ventas_cba = 10
q_ventas_pba = 10
q_ventas_stafe = 5
q_ventas_cuyo = 20
q_ventas_mesopotamia = 10
q_ventas_noa = 40
q_ventas_neuquen = 5
reinversion_utilidades = 50


# MÓDULO III - ESTIMACIONES DE COSTOS


# Bloque I.- Materia prima

i01_melamina = vm['p_melamina']*q_melamina

i02_manijas = vm['p_manija']*q_manijas

i03_ensambles = vm['p_ensamble']*q_ensambles

i04_regatones = vm['p_regaton']*q_regatones

i05_tarugos = vm['p_tarugo']*q_tarugos

i06_soportes_estantes = vm['p_soporte_estante']*q_soportes_estantes

i07_bisagras = vm['p_bisagra']*q_bisagras

i08_cerraduras = vm['p_cerradura']*q_cerraduras

i09_tornillos = vm['p_tornillo']*q_tornillos

i10_marquilla = vm['p_marquilla']*q_marquillas

i11_cantos = vm['p_cantos']*q_cantos

i12_cola = vm['p_cola']*q_cola

 

i00_materia_prima = (i01_melamina + i02_manijas + i03_ensambles + i04_regatones + i05_tarugos
                + i06_soportes_estantes + i07_bisagras + i08_cerraduras
                + i09_tornillos + i10_marquilla + i11_cantos
                + i12_cola)


# Bloque II.- Mano de obra directa

ii01_remuneracion_operarios = (((q_operarios_seccionadora + q_operarios_pegado
                      + q_operarios_centros_trabajo
                      + q_operarios_bancos_armado) * vm['w_madera_oficial_especializado']
                      + q_operarios_alimentador_piezas * vm['w_madera_ayudante'])
                      * q_jornada / q_produccion_mensual_efectiva)

ii02_remuneracion_operarios_norem = 0
                               
ii03_horas_extras = 0

ii04_horas_extras2 = 0

ii05_antiguedad = ((ii01_remuneracion_operarios + ii03_horas_extras + ii04_horas_extras2)
                *q_antiguedad * q_antiguedad_coef/100)

ii06_sac = ((ii01_remuneracion_operarios + ii03_horas_extras + ii04_horas_extras2
                + ii05_antiguedad) * q_sac / 100)

ii07_vacaciones = ((ii01_remuneracion_operarios + ii03_horas_extras + ii04_horas_extras2
                + ii05_antiguedad) / 30 * q_vacaciones/12)

ii08_contrib_patronales = (((ii01_remuneracion_operarios + ii03_horas_extras + ii04_horas_extras2
                + ii05_antiguedad + ii06_sac + ii07_vacaciones)
                - vm['t_cont_patronales_mni']*(q_operarios_seccionadora
                + q_operarios_pegado + q_operarios_centros_trabajo + q_operarios_bancos_armado
                + q_operarios_alimentador_piezas) / q_produccion_mensual_efectiva)
                * vm['t_cont_patronales_total'] / 100)

ii09_contrib_patronales_cred_fiscal = -(((ii01_remuneracion_operarios + ii03_horas_extras + ii04_horas_extras2
                + ii05_antiguedad + ii06_sac + ii07_vacaciones)
                - vm['t_cont_patronales_mni']*(q_operarios_seccionadora
                + q_operarios_pegado + q_operarios_centros_trabajo + q_operarios_bancos_armado
                + q_operarios_alimentador_piezas) / q_produccion_mensual_efectiva)
                * vm['t_cont_patronales_cred_fisc'] / 100)

ii10_contrib_osocial = ((ii01_remuneracion_operarios + ii03_horas_extras + ii04_horas_extras2
                + ii05_antiguedad + ii06_sac + ii07_vacaciones)
                *vm['t_cont_osocial'] / 100)

ii11_seguro_vida_obligatorio = ((ii01_remuneracion_operarios + ii03_horas_extras + ii04_horas_extras2
                + ii05_antiguedad + ii06_sac + ii07_vacaciones)
                *vm['p_seguro_vida_oblig_muebles'] / 100)

ii12_art = ((ii01_remuneracion_operarios + ii03_horas_extras + ii04_horas_extras2
                + ii05_antiguedad + ii06_sac + ii07_vacaciones) * vm['p_art'] / 100)

ii13_prev_despido = ((ii01_remuneracion_operarios + ii03_horas_extras + ii04_horas_extras2
                + ii05_antiguedad + ii06_sac + ii07_vacaciones)
                * q_fondo_despido / 100)

ii14_ausentismo = ((ii01_remuneracion_operarios + ii05_antiguedad + ii06_sac
                + ii07_vacaciones + ii08_contrib_patronales + ii09_contrib_patronales_cred_fiscal
                + ii10_contrib_osocial + ii11_seguro_vida_obligatorio + ii12_art
                + ii13_prev_despido ) * q_ausentismo / 100)

ii00_mano_obra_directa = (ii01_remuneracion_operarios + ii02_remuneracion_operarios_norem
                + ii03_horas_extras + ii04_horas_extras2 + ii05_antiguedad + ii06_sac
                + ii07_vacaciones + ii08_contrib_patronales
                + ii09_contrib_patronales_cred_fiscal + ii10_contrib_osocial
                + ii11_seguro_vida_obligatorio + ii12_art + ii13_prev_despido
                + ii14_ausentismo)



# Bloque III.- Mano de obra indirecta

iii01_rem_supervisores = (q_supervisores * vm['w_madera_supervisor']
                / q_produccion_mensual_efectiva)
                        
iii02_rem_disenadores = (q_disenadores * vm['w_madera_admin']
                / q_produccion_mensual_efectiva)

iii03_rem_planificacion_produccion = (q_planificacion_prod * vm['w_madera_planificacion_prod']
                / q_produccion_mensual_efectiva)

iii04_rem_compras = (q_pers_compras * vm['w_madera_compras']
                / q_produccion_mensual_efectiva)

iii05_rem_mantenimiento = (q_pers_mantenimiento * vm['w_madera_mantenim']
                / q_produccion_mensual_efectiva)

iii06_rem_maestranza = (q_pers_maestranza * vm['w_madera_afilador']
                / q_produccion_mensual_efectiva)

iii07_rem_administrativos = (q_pers_administrativo * vm['w_madera_admin']
                / q_produccion_mensual_efectiva)

iii08_rem_vendedores = (q_vendedores * vm['w_madera_ventas']
                / q_produccion_mensual_efectiva)

iii09_rem_gerente_general = (q_gerente_general * vm['w_madera_gerente_gral']
                / q_produccion_mensual_efectiva)


iii10_antiguedad = ((iii01_rem_supervisores + iii02_rem_disenadores
                + iii03_rem_planificacion_produccion + iii04_rem_compras
                + iii05_rem_mantenimiento + iii06_rem_maestranza
                + iii07_rem_administrativos + iii08_rem_vendedores
                + iii09_rem_gerente_general)
                * q_antiguedad * q_antiguedad_coef / 100)

iii11_sac = ((iii01_rem_supervisores + iii02_rem_disenadores
                + iii03_rem_planificacion_produccion + iii04_rem_compras
                + iii05_rem_mantenimiento + iii06_rem_maestranza
                + iii07_rem_administrativos + iii08_rem_vendedores
                + iii09_rem_gerente_general + iii10_antiguedad) * q_sac / 100)

iii12_vacaciones = ((iii01_rem_supervisores + iii02_rem_disenadores
                + iii03_rem_planificacion_produccion + iii04_rem_compras
                + iii05_rem_mantenimiento + iii06_rem_maestranza
                + iii07_rem_administrativos + iii08_rem_vendedores
                + iii09_rem_gerente_general + iii10_antiguedad)
                / 30 * q_vacaciones / 12)

iii13_contribuciones = ((iii01_rem_supervisores + iii02_rem_disenadores
                + iii03_rem_planificacion_produccion + iii04_rem_compras
                + iii05_rem_mantenimiento + iii06_rem_maestranza
                + iii07_rem_administrativos + iii08_rem_vendedores
                + iii09_rem_gerente_general + iii10_antiguedad
                + iii11_sac + iii12_vacaciones
                - vm['t_cont_patronales_mni'] *
                (q_supervisores + q_disenadores + q_planificacion_prod
                + q_pers_compras + q_pers_mantenimiento
                + q_pers_maestranza + q_pers_administrativo
                + q_vendedores + q_gerente_general) / q_produccion_mensual_efectiva)
                * vm['t_cont_patronales_total'] / 100)

iii14_contrib_crevmiscal = -((iii01_rem_supervisores + iii02_rem_disenadores
                + iii03_rem_planificacion_produccion + iii04_rem_compras
                + iii05_rem_mantenimiento + iii06_rem_maestranza
                + iii07_rem_administrativos + iii08_rem_vendedores
                + iii09_rem_gerente_general + iii10_antiguedad
                + iii11_sac + iii12_vacaciones
                - vm['t_cont_patronales_mni'] *
                (q_supervisores + q_disenadores + q_planificacion_prod
                + q_pers_compras + q_pers_mantenimiento
                + q_pers_maestranza + q_pers_administrativo
                + q_vendedores + q_gerente_general) / q_produccion_mensual_efectiva)
                *vm['t_cont_patronales_cred_fisc']/100)

iii15_contrib_osocial = ((iii01_rem_supervisores + iii02_rem_disenadores
                + iii03_rem_planificacion_produccion + iii04_rem_compras
                + iii05_rem_mantenimiento + iii06_rem_maestranza
                + iii07_rem_administrativos + iii08_rem_vendedores
                + iii09_rem_gerente_general + iii10_antiguedad
                + iii11_sac + iii12_vacaciones) * vm['t_cont_osocial']/100)

iii16_seguro_vida = ((iii01_rem_supervisores + iii02_rem_disenadores
                + iii03_rem_planificacion_produccion + iii04_rem_compras
                + iii05_rem_mantenimiento + iii06_rem_maestranza
                + iii07_rem_administrativos + iii08_rem_vendedores
                + iii09_rem_gerente_general + iii10_antiguedad
                + iii11_sac + iii12_vacaciones) * vm['p_seguro_vida_oblig_muebles']/100)

iii17_art = ((iii01_rem_supervisores + iii02_rem_disenadores
                + iii03_rem_planificacion_produccion + iii04_rem_compras
                + iii05_rem_mantenimiento + iii06_rem_maestranza
                + iii07_rem_administrativos + iii08_rem_vendedores
                + iii09_rem_gerente_general + iii10_antiguedad
                + iii11_sac + iii12_vacaciones) * vm['p_art']/100)

iii18_prevision_despido = ((iii01_rem_supervisores + iii02_rem_disenadores
                + iii03_rem_planificacion_produccion + iii04_rem_compras
                + iii05_rem_mantenimiento + iii06_rem_maestranza
                + iii07_rem_administrativos + iii08_rem_vendedores
                + iii09_rem_gerente_general + iii10_antiguedad
                + iii11_sac + iii12_vacaciones) * q_fondo_despido / 100)

iii00_mano_obra_indirecta = (iii01_rem_supervisores + iii02_rem_disenadores
                + iii03_rem_planificacion_produccion + iii04_rem_compras
                + iii05_rem_mantenimiento + iii06_rem_maestranza
                + iii07_rem_administrativos + iii08_rem_vendedores
                + iii09_rem_gerente_general + iii10_antiguedad + iii11_sac
                + iii12_vacaciones + iii13_contribuciones + iii14_contrib_crevmiscal
                + iii15_contrib_osocial + iii16_seguro_vida + iii17_art
                + iii18_prevision_despido)
                               

# Bloque IV.- Costo de maquinaria

iv01_energia = ((q_energia_potencia * q_energia_potencia_punta / (q_energia_potencia_punta+q_energia_potencia_fuerapunta) * vm['p_energia_potencia_punta']
                 + q_energia_potencia * q_energia_potencia_fuerapunta / (q_energia_potencia_punta+q_energia_potencia_fuerapunta) * vm['p_energia_potencia_fuerapunta']
                 + q_energia_consumo * q_energia_pico / (q_energia_pico+q_energia_valle+q_energia_resto) * vm['p_energia_pico']
                 + q_energia_consumo * q_energia_valle / (q_energia_pico+q_energia_valle+q_energia_resto) * vm['p_energia_valle']
                 + q_energia_consumo * q_energia_resto / (q_energia_pico+q_energia_valle+q_energia_resto) * vm['p_energia_resto'])
                 / q_produccion_mensual_efectiva)

iv02_impuestos_energia = ((vm['t_energia_perc_dgi'] + vm['t_energia_oim'] + vm['t_energia_dto2298']
                + vm['t_energia_ersep'] + vm['t_energia_ley9819']) / 100
                * iv01_energia)

iv03_repos_seccionadora = (q_seccionadora * vm['p_seccionadora'] * vm['euro']
                * (1-vr_seccionadora/100) / y_seccionadora / 12
                / q_produccion_mensual_efectiva)
                               
iv04_repos_pegadora_canto = (q_pegadora_canto * vm['p_pegadora_canto'] * vm['euro']
                * (1-vr_pegadora_canto/100) / y_pegadora_canto / 12
                / q_produccion_mensual_efectiva)

iv05_repos_centro_trabajo = (q_centro_trabajo * vm['p_centro_trabajo'] * vm['euro']
                * (1-vr_centro_trabajo/100) / y_centro_trabajo / 12
                / q_produccion_mensual_efectiva)

iv06_repos_banco_armado = (q_banco_armado * vm['p_banco_armado'] * vm['euro']
                * (1-vr_banco_armado/100) / y_banco_armado / 12
                / q_produccion_mensual_efectiva)

iv07_repos_herramientas_neumaticas = (q_herramientas_neumaticas * vm['p_herramientas_neumaticas'] * vm['euro']
                * (1-vr_herramientas_neumaticas/100) / y_herramientas_neumaticas / 12
                / q_produccion_mensual_efectiva)

iv08_repos_autoelevador = (q_autoelevador * vm['p_autoelevador'] * vm['euro']
                * (1-vr_autoelevador/100) / y_autoelevador / 12
                / q_produccion_mensual_efectiva)

iv09_costo_oportunidad = ((q_seccionadora * vm['p_seccionadora'] * vm['euro']
                * ((1-vr_seccionadora/100) * 0.05 + vr_seccionadora/100)
                + q_pegadora_canto * vm['p_pegadora_canto'] * vm['euro']
                * ((1-vr_pegadora_canto/100) * 0.05 + vr_pegadora_canto/100)
                + q_centro_trabajo * vm['p_centro_trabajo'] * vm['euro']
                * ((1-vr_centro_trabajo/100) * 0.05 + vr_centro_trabajo/100)
                + q_banco_armado * vm['p_banco_armado'] * vm['euro']
                * ((1-vr_banco_armado/100) * 0.05 + vr_banco_armado/100)
                + q_herramientas_neumaticas * vm['p_herramientas_neumaticas'] * vm['euro']
                * ((1-vr_herramientas_neumaticas/100) * 0.05 + vr_herramientas_neumaticas/100)
                + q_autoelevador * vm['p_autoelevador'] * vm['dolar']
                * ((1-vr_autoelevador/100) * 0.05 + vr_autoelevador/100)) 
                * costo_oportunidad /100 / 12 / q_produccion_mensual_efectiva)


iv00_maquinaria = (iv01_energia + iv02_impuestos_energia + iv03_repos_seccionadora
                + iv04_repos_pegadora_canto + iv05_repos_centro_trabajo
                + iv06_repos_banco_armado + iv07_repos_herramientas_neumaticas
                + iv08_repos_autoelevador + iv09_costo_oportunidad)

                               
# Bloque V.- Costos fijos no asociados a la producción

v01_alquiler = (vm['p_alquiler_fabricacion'] * vm['dolar'] * q_galpon / q_produccion_mensual_efectiva)

v02_muebles = ((vm['p_computadora'] * q_puestos_oficina / q_amortizacion_computadoras
                 + vm['p_escritorio'] * q_puestos_oficina / q_amortizacion_muebles
                 + vm['p_silla'] * q_puestos_oficina / q_amortizacion_muebles) / 12
                / q_produccion_mensual_efectiva)


v03_costo_financiero = ( i00_materia_prima * ( pow ( 1 + vm['p_tasa_interes_diaria']
            / 100,( plazo_cobro - plazo_pago_insumos ))) - i00_materia_prima
            + ( ii00_mano_obra_directa + iii00_mano_obra_indirecta )
            * ( pow ( 1 + vm['p_tasa_interes_diaria'] / 100,( plazo_cobro
            - plazo_pago_salarios ))) - ( ii00_mano_obra_directa
            + iii00_mano_obra_indirecta ))

v04_estudio_contable = (vm['p_estudio_contable'] / q_produccion_mensual_efectiva)

v05_beneficios = ((i00_materia_prima + ii00_mano_obra_directa + iii00_mano_obra_indirecta
                + iv00_maquinaria + v01_alquiler + v02_muebles + v03_costo_financiero
                + v04_estudio_contable) * mark_up / 100)



v00_costos_fijos = (v01_alquiler + v02_muebles + v03_costo_financiero + v04_estudio_contable
                + v05_beneficios)
                        

# Bloque VI.- Costos impositivos

vi01_impuesto_ingresos_brutos = ((i00_materia_prima + ii00_mano_obra_directa
                + iii00_mano_obra_indirecta + iv00_maquinaria + v00_costos_fijos)
                * (vm['t_ib_extjuris_pba']/100 * q_ventas_pba / 100
                + vm['t_ib_extjuris_stafe']/100 * q_ventas_stafe / 100
                + vm['t_ib_extjuris_mza']/100 * q_ventas_cuyo / 100
                + vm['t_ib_extjuris_corrientes']/100 * q_ventas_mesopotamia / 100
                + vm['t_ib_extjuris_salta']/100 * q_ventas_noa / 100
                + vm['t_ib_extjuris_neuquen']/100 * q_ventas_neuquen / 100))

vi02_tasa_comercioeindustria = ((i00_materia_prima + ii00_mano_obra_directa
                + iii00_mano_obra_indirecta + iv00_maquinaria + v00_costos_fijos)
                * vm['t_comercioeindustria']/100)

                   
#vi03_impuesto_ganancias = ((v05_beneficios + iv09_costo_oportunidad)
#               * vm['t_ganancias']/100
#               + (v05_beneficios + iv09_costo_oportunidad)
#               * (1 - reinversion_utilidades/100)
#               * vm['t_dividendos']/100)

vi03_impuesto_ganancias = ((v05_beneficios)
                * vm['t_ganancias']/100
                + (v05_beneficios)
                * (1 - reinversion_utilidades/100)
                * vm['t_dividendos']/100)

vi04_impuesto_cheque = ((i00_materia_prima + ii00_mano_obra_directa
                + iii00_mano_obra_indirecta + iv00_maquinaria
                + v00_costos_fijos + vi01_impuesto_ingresos_brutos
                + vi02_tasa_comercioeindustria + vi03_impuesto_ganancias )
                * 1.21 * (vm['t_cheque'] - vm['t_cheque_cred_fiscal'])/100)


vi00_impuestos = (vi01_impuesto_ingresos_brutos + vi02_tasa_comercioeindustria
                + vi03_impuesto_ganancias + vi04_impuesto_cheque)
                   


# Bloque Indicadores de costos

                    
costo_gabinete_pesos = (i00_materia_prima + ii00_mano_obra_directa
                + iii00_mano_obra_indirecta + iv00_maquinaria
                + v00_costos_fijos + vi00_impuestos)

costo_gabinete_dolares = costo_gabinete_pesos / vm['dolar']




# CONTROL:
print(vi00_impuestos)

