# Programa en Python - Sistema Estadistico de Costos Industria del Mueble


# MÓDULO I - CARGA DE VARIABLES MONETARIAS

import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import seaborn as sns

# Importar base de datos de series de tiempo con variables monetarias:

vm = pd.read_excel('Muebles variables monetarias v01.xlsx')


# Convertir columna mes en variable indexadora temporal:

vm.mes = pd.to_datetime(vm.mes)
vm.set_index('mes', inplace=True)       


# MÓDULO II - DEFINICION DE PARÁMETROS

# Parámetros generales
q_placas_mes = 300
ratio_placas_modulo = 0.81
q_produccion_mensual_potencial = q_placas_mes / ratio_placas_modulo
q_capacidad_utilizada = 100
q_produccion_mensual_efectiva = q_produccion_mensual_potencial * q_capacidad_utilizada / 100
ratio_modulos_cocina = 18
q_bajomesada_ancho = 1
q_bajomesada_profundidad = 0.58
q_bajomesada_alto = 0.74
q_alacena_ancho = 1
q_alacena_profundidad = 0.32
q_alacena_alto = 0.60


# Materias primas

ratio_m2_placa = 5.03

q_bajomesada_modulos_puertas = 8
q_bajomesadap_melamina_estructura = 0.586
q_bajomesadap_melamina_frente = 0.170
q_bajomesadap_melamina_fondo = 0.150
q_bajomesadap_cantos_45mm = 15
q_bajomesadap_cantos_2mm = 5
q_bajomesadap_tornillos = 8
q_bajomesadap_tarugos = 12
q_bajomesadap_bisagras = 4
q_bajomesadap_tiradores = 0.33
q_bajomesadap_zocalos = 0.4
q_bajomesadap_patas_zocalos = 4
q_bajomesadap_clips_zocalos = 2

q_bajomesada_modulos_cajones = 2
q_bajomesadac_melamina_estructura = 0.608
q_bajomesadac_melamina_frente = 0.170
q_bajomesadac_melamina_fondo = 0.150
q_bajomesadac_cantos_45mm = 25
q_bajomesadac_cantos_2mm = 8
q_bajomesadac_tornillos = 8
q_bajomesadac_tarugos = 12
q_bajomesadac_guias_cajon = 1
q_bajomesadac_tiradores = 1
q_bajomesadac_zocalos = 0.4
q_bajomesadac_patas_zocalos = 4
q_bajomesadac_clips_zocalos = 2

q_alacena = 8
q_alacena_melamina_estructura = 0.287
q_alacena_melamina_frente = 0.235
q_alacena_melamina_fondo = 0.168
q_alacena_cantos_45mm = 13
q_alacena_cantos_2mm = 4
q_alacena_tornillos = 8
q_alacena_tarugos = 12
q_alacena_bisagras = 4
q_alacena_tiradores = 0.33
q_alacena_zocalos = 0.4


# Mano de obra directa
q_jornada = 192
q_operarios = 8


# Mano de obra indirecta
q_supervisores = 1
q_disenadores = 2
q_planificacion_prod = 0
q_pers_compras = 0
q_pers_mantenimiento = 0
q_pers_maestranza = 1
q_pers_administrativo = 1
q_vendedores = 0
q_gerente_general = 1

# Maquinaria
q_autoelevador = 1
q_seccionadora_horizontal = 1
q_canteadora = 1
q_perforadora_multiple = 1
q_pistola_neumatica = 4
q_atornillador_electrico = 4

q_taladro = 4
q_cabina_pintura = 1
q_cabina_secado = 1
q_compresor = 1
q_aspiradora = 3
q_rack = 10

y_autoelevador = 10
y_seccionadora_horizontal = 10
y_canteadora = 10
y_perforadora_multiple = 10
y_pistola_neumatica = 5
y_atornillador_electrico = 5

y_taladro = 5
y_cabina_pintura = 20
y_cabina_secado = 20
y_compresor = 5
y_aspiradora = 5
y_rack = 20

vr_autoelevador = 30
vr_seccionadora_horizontal = 30
vr_canteadora = 30
vr_perforadora_multiple = 30
vr_pistola_neumatica = 0
vr_atornillador_electrico = 0

vr_taladro = 0
vr_cabina_pintura = 0
vr_cabina_secado = 0
vr_compresor = 20
vr_aspiradora = 0
vr_rack = 0

costo_oportunidad = 4


# Consumibles y mantenimiento

q_energia_potencia = 140               # kw
q_energia_consumo = 7000              # kw/h mensuales
q_energia_potencia_punta = 5
q_energia_potencia_fuerapunta = 19
q_energia_pico = 5
q_energia_valle = 6
q_energia_resto = 13
q_galpon = 1500              # m2 de alquiler

# Parámetros laborales
q_antiguedad = 15           # promedio de años
q_antiguedad_coef = 1
q_prendas = 4         # cantidad por año
q_casco = 2           # cantidad por año
q_guantes = 2         # cantidad por año
q_sac = 8.33
q_vacaciones = 35
q_fondo_despido = 4
q_ausentismo = 3

# Parámetros costos fijos y varios

q_puestos_oficina = 6
q_amortizacion_computadoras = 5
q_amortizacion_muebles = 10
plazo_pago_insumos = 30
plazo_cobro = 30
plazo_pago_salarios = 30
cobros_tarjeta_credito = 50
plazo_cobro_tarjetas_credito = 28
comisiones_tarjetas_credito = 1.5

mark_up = 10


# Parámetros tributarios
q_ventas_cba = 100
q_ventas_pba = 0
q_ventas_stafe = 0
q_ventas_cuyo = 0
q_ventas_mesopotamia = 0
q_ventas_noa = 0
q_ventas_neuquen = 0
reinversion_utilidades = 50


# MÓDULO III - ESTIMACIONES DE COSTOS


# Bloque I.- Materia prima

i01_melamina = (((q_bajomesadap_melamina_estructura + q_bajomesadap_melamina_frente
                + q_bajomesadap_melamina_fondo) * q_bajomesada_modulos_puertas
                + (q_bajomesadac_melamina_estructura + q_bajomesadac_melamina_frente
                + q_bajomesadac_melamina_fondo) * q_bajomesada_modulos_cajones
                + (q_alacena_melamina_estructura + q_alacena_melamina_frente
                + q_alacena_melamina_fondo) * q_alacena)
                / ratio_modulos_cocina * vm['p_melamina_18mm'])

i02_cantos = ((q_bajomesadap_cantos_45mm * q_bajomesada_modulos_puertas
              + q_bajomesadac_cantos_45mm * q_bajomesada_modulos_cajones
              + q_alacena_cantos_45mm * q_alacena) / ratio_modulos_cocina
              * vm['p_canto_045mm']
              + (q_bajomesadap_cantos_2mm * q_bajomesada_modulos_puertas
              + q_bajomesadac_cantos_2mm * q_bajomesada_modulos_cajones
              + q_alacena_cantos_2mm * q_alacena) / ratio_modulos_cocina
              * vm['p_canto_2mm'])

i03_tornillos = ((q_bajomesadap_tornillos * q_bajomesada_modulos_puertas
              + q_bajomesadac_tornillos * q_bajomesada_modulos_cajones
              + q_alacena_tornillos * q_alacena) / ratio_modulos_cocina
              * vm['p_tornillo_minifix'])

i04_tarugos = ((q_bajomesadap_tarugos * q_bajomesada_modulos_puertas
              + q_bajomesadac_tarugos * q_bajomesada_modulos_cajones
              + q_alacena_tarugos * q_alacena) / ratio_modulos_cocina
              * vm['p_tarugo'])

i05_bisagras = ((q_bajomesadap_bisagras * q_bajomesada_modulos_puertas
              + q_alacena_bisagras * q_alacena) / ratio_modulos_cocina
              * vm['p_bisagra'])

i06_guias_cajones = (q_bajomesadac_guias_cajon * q_bajomesada_modulos_cajones
               / ratio_modulos_cocina * vm['p_guia_cajon'])

i07_tiradores = ((q_bajomesadap_tiradores * q_bajomesada_modulos_puertas
              + q_bajomesadac_tiradores * q_bajomesada_modulos_cajones
              + q_alacena_tiradores * q_alacena) / ratio_modulos_cocina
              * vm['p_tirador'])

i08_zocalos = ((q_bajomesadap_zocalos * q_bajomesada_modulos_puertas
              + q_bajomesadac_zocalos * q_bajomesada_modulos_cajones
              + q_alacena_zocalos * q_alacena) / ratio_modulos_cocina
              * vm['p_zocalo'])

i09_patas_zocalos = ((q_bajomesadap_patas_zocalos * q_bajomesada_modulos_puertas
              + q_bajomesadac_patas_zocalos * q_bajomesada_modulos_cajones)
              / ratio_modulos_cocina * vm['p_pata_zocalo'])

i10_clips_zocalos = ((q_bajomesadap_clips_zocalos * q_bajomesada_modulos_puertas
              + q_bajomesadac_clips_zocalos * q_bajomesada_modulos_cajones)
              / ratio_modulos_cocina * vm['p_clip_zocalo'])

i00_materia_prima = (i01_melamina + i02_cantos + i03_tornillos + i04_tarugos + i05_bisagras
                + i06_guias_cajones + i07_tiradores + i08_zocalos
                + i09_patas_zocalos + i10_clips_zocalos)


# Bloque II.- Mano de obra directa

ii01_remuneracion_operarios = (q_operarios * q_jornada
                * vm['w_madera_oficial_especializado']
                / q_produccion_mensual_efectiva)

ii02_remuneracion_operarios_norem = 0
                               
ii03_horas_extras = 0

ii04_horas_extras2 = 0

ii05_antiguedad = ((ii01_remuneracion_operarios + ii03_horas_extras + ii04_horas_extras2)
                *q_antiguedad * q_antiguedad_coef/100)

ii06_sac = ((ii01_remuneracion_operarios + ii03_horas_extras + ii04_horas_extras2
                + ii05_antiguedad) * q_sac / 100)

ii07_vacaciones = ((ii01_remuneracion_operarios + ii02_remuneracion_operarios_norem
                + ii05_antiguedad) / 30 * q_vacaciones /12)

ii08_contrib_patronales = ((ii01_remuneracion_operarios + ii03_horas_extras + ii04_horas_extras2
                + ii05_antiguedad + ii06_sac + ii07_vacaciones
                - vm['t_cont_patronales_mni'] * q_operarios / q_produccion_mensual_efectiva)
                * vm['t_cont_patronales_total'] / 100)

ii09_contrib_patronales_cred_fiscal = -((ii01_remuneracion_operarios + ii03_horas_extras + ii04_horas_extras2
                + ii05_antiguedad + ii06_sac + ii07_vacaciones
                - vm['t_cont_patronales_mni'] * q_operarios / q_produccion_mensual_efectiva)
                * vm['t_cont_patronales_cred_fisc'] / 100)

ii10_contrib_osocial = ((ii01_remuneracion_operarios + ii03_horas_extras + ii04_horas_extras2
                + ii05_antiguedad + ii06_sac + ii07_vacaciones)
                *vm['t_cont_osocial'] / 100)

ii11_seguro_vida_obligatorio = ((ii01_remuneracion_operarios + ii03_horas_extras + ii04_horas_extras2
                + ii05_antiguedad + ii06_sac + ii07_vacaciones)
                *vm['p_seguro_vida_oblig_muebles'] / 100)

ii12_art = ((ii01_remuneracion_operarios + ii03_horas_extras + ii04_horas_extras2
                + ii05_antiguedad + ii06_sac + ii07_vacaciones) * vm['p_art'] / 100)

ii13_prev_despido = ((ii01_remuneracion_operarios + ii03_horas_extras + ii04_horas_extras2
                + ii05_antiguedad + ii06_sac + ii07_vacaciones)
                * q_fondo_despido / 100)

ii14_ausentismo = ((ii01_remuneracion_operarios + ii05_antiguedad + ii06_sac
                + ii07_vacaciones + ii08_contrib_patronales + ii09_contrib_patronales_cred_fiscal
                + ii10_contrib_osocial + ii11_seguro_vida_obligatorio + ii12_art
                + ii13_prev_despido ) * q_ausentismo / 100)

ii00_mano_obra_directa = (ii01_remuneracion_operarios + ii02_remuneracion_operarios_norem
                + ii03_horas_extras + ii04_horas_extras2 + ii05_antiguedad + ii06_sac
                + ii07_vacaciones + ii08_contrib_patronales
                + ii09_contrib_patronales_cred_fiscal + ii10_contrib_osocial
                + ii11_seguro_vida_obligatorio + ii12_art + ii13_prev_despido
                + ii14_ausentismo)


# Bloque III.- Mano de obra indirecta

iii01_rem_supervisores = (q_supervisores * vm['w_madera_supervisor']
                / q_produccion_mensual_efectiva)
                        
iii02_rem_disenadores = (q_disenadores * vm['w_madera_admin']
                / q_produccion_mensual_efectiva)

iii03_rem_planificacion_produccion = (q_planificacion_prod * vm['w_madera_planificacion_prod']
                / q_produccion_mensual_efectiva)

iii04_rem_compras = (q_pers_compras * vm['w_madera_compras']
                / q_produccion_mensual_efectiva)

iii05_rem_mantenimiento = (q_pers_mantenimiento * vm['w_madera_mantenim']
                / q_produccion_mensual_efectiva)

iii06_rem_maestranza = (q_pers_maestranza * vm['w_madera_afilador']
                / q_produccion_mensual_efectiva)

iii07_rem_administrativos = (q_pers_administrativo * vm['w_madera_admin']
                / q_produccion_mensual_efectiva)

iii08_rem_vendedores = (q_vendedores * vm['w_madera_ventas']
                / q_produccion_mensual_efectiva)

iii09_rem_gerente_general = (q_gerente_general * vm['w_madera_gerente_gral']
                / q_produccion_mensual_efectiva)


iii10_antiguedad = ((iii01_rem_supervisores + iii02_rem_disenadores
                + iii03_rem_planificacion_produccion + iii04_rem_compras
                + iii05_rem_mantenimiento + iii06_rem_maestranza
                + iii07_rem_administrativos + iii08_rem_vendedores
                + iii09_rem_gerente_general)
                * q_antiguedad * q_antiguedad_coef / 100)

iii11_sac = ((iii01_rem_supervisores + iii02_rem_disenadores
                + iii03_rem_planificacion_produccion + iii04_rem_compras
                + iii05_rem_mantenimiento + iii06_rem_maestranza
                + iii07_rem_administrativos + iii08_rem_vendedores
                + iii09_rem_gerente_general + iii10_antiguedad) * q_sac / 100)

iii12_vacaciones = ((iii01_rem_supervisores + iii02_rem_disenadores
                + iii03_rem_planificacion_produccion + iii04_rem_compras
                + iii05_rem_mantenimiento + iii06_rem_maestranza
                + iii07_rem_administrativos + iii08_rem_vendedores
                + iii09_rem_gerente_general + iii10_antiguedad)
                / 30 * q_vacaciones / 12)

iii13_contribuciones = ((iii01_rem_supervisores + iii02_rem_disenadores
                + iii03_rem_planificacion_produccion + iii04_rem_compras
                + iii05_rem_mantenimiento + iii06_rem_maestranza
                + iii07_rem_administrativos + iii08_rem_vendedores
                + iii09_rem_gerente_general + iii10_antiguedad
                + iii11_sac + iii12_vacaciones
                - vm['t_cont_patronales_mni'] *
                (q_supervisores + q_disenadores + q_planificacion_prod
                + q_pers_compras + q_pers_mantenimiento
                + q_pers_maestranza + q_pers_administrativo
                + q_vendedores + q_gerente_general) / q_produccion_mensual_efectiva)
                * vm['t_cont_patronales_total'] / 100)

iii14_contrib_crevmiscal = -((iii01_rem_supervisores + iii02_rem_disenadores
                + iii03_rem_planificacion_produccion + iii04_rem_compras
                + iii05_rem_mantenimiento + iii06_rem_maestranza
                + iii07_rem_administrativos + iii08_rem_vendedores
                + iii09_rem_gerente_general + iii10_antiguedad
                + iii11_sac + iii12_vacaciones
                - vm['t_cont_patronales_mni'] *
                (q_supervisores + q_disenadores + q_planificacion_prod
                + q_pers_compras + q_pers_mantenimiento
                + q_pers_maestranza + q_pers_administrativo
                + q_vendedores + q_gerente_general) / q_produccion_mensual_efectiva)
                *vm['t_cont_patronales_cred_fisc']/100)

iii15_contrib_osocial = ((iii01_rem_supervisores + iii02_rem_disenadores
                + iii03_rem_planificacion_produccion + iii04_rem_compras
                + iii05_rem_mantenimiento + iii06_rem_maestranza
                + iii07_rem_administrativos + iii08_rem_vendedores
                + iii09_rem_gerente_general + iii10_antiguedad
                + iii11_sac + iii12_vacaciones) * vm['t_cont_osocial']/100)

iii16_seguro_vida = ((iii01_rem_supervisores + iii02_rem_disenadores
                + iii03_rem_planificacion_produccion + iii04_rem_compras
                + iii05_rem_mantenimiento + iii06_rem_maestranza
                + iii07_rem_administrativos + iii08_rem_vendedores
                + iii09_rem_gerente_general + iii10_antiguedad
                + iii11_sac + iii12_vacaciones) * vm['p_seguro_vida_oblig_muebles']/100)

iii17_art = ((iii01_rem_supervisores + iii02_rem_disenadores
                + iii03_rem_planificacion_produccion + iii04_rem_compras
                + iii05_rem_mantenimiento + iii06_rem_maestranza
                + iii07_rem_administrativos + iii08_rem_vendedores
                + iii09_rem_gerente_general + iii10_antiguedad
                + iii11_sac + iii12_vacaciones) * vm['p_art']/100)

iii18_prevision_despido = ((iii01_rem_supervisores + iii02_rem_disenadores
                + iii03_rem_planificacion_produccion + iii04_rem_compras
                + iii05_rem_mantenimiento + iii06_rem_maestranza
                + iii07_rem_administrativos + iii08_rem_vendedores
                + iii09_rem_gerente_general + iii10_antiguedad
                + iii11_sac + iii12_vacaciones) * q_fondo_despido / 100)

iii00_mano_obra_indirecta = (iii01_rem_supervisores + iii02_rem_disenadores
                + iii03_rem_planificacion_produccion + iii04_rem_compras
                + iii05_rem_mantenimiento + iii06_rem_maestranza
                + iii07_rem_administrativos + iii08_rem_vendedores
                + iii09_rem_gerente_general + iii10_antiguedad + iii11_sac
                + iii12_vacaciones + iii13_contribuciones + iii14_contrib_crevmiscal
                + iii15_contrib_osocial + iii16_seguro_vida + iii17_art
                + iii18_prevision_despido)
                               

# Bloque IV.- Costo de maquinaria

iv01_energia = ((q_energia_potencia * q_energia_potencia_punta / (q_energia_potencia_punta+q_energia_potencia_fuerapunta) * vm['p_energia_potencia_punta']
                 + q_energia_potencia * q_energia_potencia_fuerapunta / (q_energia_potencia_punta+q_energia_potencia_fuerapunta) * vm['p_energia_potencia_fuerapunta']
                 + q_energia_consumo * q_energia_pico / (q_energia_pico+q_energia_valle+q_energia_resto) * vm['p_energia_pico']
                 + q_energia_consumo * q_energia_valle / (q_energia_pico+q_energia_valle+q_energia_resto) * vm['p_energia_valle']
                 + q_energia_consumo * q_energia_resto / (q_energia_pico+q_energia_valle+q_energia_resto) * vm['p_energia_resto'])
                 / q_produccion_mensual_efectiva)

iv02_impuestos_energia = ((vm['t_energia_perc_dgi'] + vm['t_energia_oim'] + vm['t_energia_dto2298']
                + vm['t_energia_ersep'] + vm['t_energia_ley9819']) / 100
                * iv01_energia)

iv03_repos_autoelevador = (q_autoelevador * vm['p_autoelevador'] * vm['dolar']
                * (1-vr_autoelevador/100) / y_autoelevador / 12
                / q_produccion_mensual_efectiva)
                               
iv04_repos_seccionadora_horizontal = (q_seccionadora_horizontal * vm['p_seccionadora_horizontal'] * vm['dolar']
                * (1-vr_seccionadora_horizontal/100) / y_seccionadora_horizontal / 12
                / q_produccion_mensual_efectiva)

iv05_repos_canteadora = (q_canteadora * vm['p_canteadora'] * vm['dolar']
                * (1-vr_canteadora/100) / y_canteadora / 12
                / q_produccion_mensual_efectiva)

iv06_repos_perforadora = (q_perforadora_multiple * vm['p_perforadora_multiple'] * vm['dolar']
                * (1-vr_perforadora_multiple/100) / y_perforadora_multiple / 12
                / q_produccion_mensual_efectiva)

iv07_repos_pistola = (q_pistola_neumatica * vm['p_pistola_neumatica'] * vm['dolar']
                * (1-vr_pistola_neumatica/100) / y_pistola_neumatica / 12
                / q_produccion_mensual_efectiva)

iv08_repos_atornillador = (q_atornillador_electrico * vm['p_atornillador_electrico'] * vm['dolar']
                * (1-vr_atornillador_electrico/100) / y_atornillador_electrico / 12
                / q_produccion_mensual_efectiva)

iv09_repos_taladro = (q_taladro * vm['p_taladro'] * vm['dolar']
                * (1-vr_taladro/100) / y_taladro / 12
                / q_produccion_mensual_efectiva)

iv10_repos_cabina_pintura = (q_cabina_pintura * vm['p_cabina_pintura'] * vm['dolar']
                * (1-vr_cabina_pintura/100) / y_cabina_pintura / 12
                / q_produccion_mensual_efectiva)

iv11_repos_cabina_secado = (q_cabina_secado * vm['p_cabina_secado'] * vm['dolar']
                * (1-vr_cabina_secado/100) / y_cabina_secado / 12
                / q_produccion_mensual_efectiva)

iv12_repos_compresor = (q_compresor * vm['p_compresor'] * vm['dolar']
                * (1-vr_compresor/100) / y_compresor / 12
                / q_produccion_mensual_efectiva)

iv13_repos_aspiradoras = (q_aspiradora * vm['p_aspiradora'] * vm['dolar']
                * (1-vr_aspiradora/100) / y_aspiradora / 12
                / q_produccion_mensual_efectiva)

iv14_repos_racks = (q_rack * vm['p_rack'] * vm['dolar']
                * (1-vr_rack/100) / y_rack / 12
                / q_produccion_mensual_efectiva)


iv15_costo_oportunidad = ((q_autoelevador * vm['p_autoelevador'] * vm['dolar']
                * ((1-vr_autoelevador/100) / 2 + vr_autoelevador/100)
                + q_seccionadora_horizontal * vm['p_seccionadora_horizontal'] * vm['dolar']
                * ((1-vr_seccionadora_horizontal/100) / 2 + vr_seccionadora_horizontal/100)
                + q_canteadora * vm['p_canteadora'] * vm['dolar']
                * ((1-vr_canteadora/100) / 2 + vr_canteadora/100)
                + q_perforadora_multiple * vm['p_perforadora_multiple'] * vm['dolar']
                * ((1-vr_perforadora_multiple/100) / 2 + vr_perforadora_multiple/100)
                + q_pistola_neumatica * vm['p_pistola_neumatica'] * vm['dolar']
                * ((1-vr_pistola_neumatica/100) / 2 + vr_pistola_neumatica/100)
                + q_atornillador_electrico * vm['p_atornillador_electrico'] * vm['dolar']
                * ((1-vr_atornillador_electrico/100) / 2 + vr_atornillador_electrico/100)
                + q_taladro * vm['p_taladro'] * vm['dolar']
                * ((1-vr_taladro/100) / 2 + vr_taladro/100)
                + q_cabina_pintura * vm['p_cabina_pintura'] * vm['dolar']
                * ((1-vr_cabina_pintura/100) / 2 + vr_cabina_pintura/100)
                + q_cabina_secado * vm['p_cabina_secado'] * vm['dolar']
                * ((1-vr_cabina_secado/100) / 2 + vr_cabina_secado/100)
                + q_compresor * vm['p_compresor'] * vm['dolar']
                * ((1-vr_compresor/100) / 2 + vr_compresor/100)
                + q_aspiradora * vm['p_aspiradora'] * vm['dolar']
                * ((1-vr_aspiradora/100) / 2 + vr_aspiradora/100)
                + q_rack * vm['p_rack'] * vm['dolar']
                * ((1-vr_rack/100) / 2 + vr_rack/100))
                * costo_oportunidad /100 / 12 / q_produccion_mensual_efectiva)


iv00_maquinaria = (iv01_energia + iv02_impuestos_energia + iv03_repos_autoelevador
                + iv04_repos_seccionadora_horizontal + iv05_repos_canteadora
                + iv06_repos_perforadora + iv07_repos_pistola
                + iv08_repos_atornillador + iv09_repos_taladro
                + iv10_repos_cabina_pintura + iv11_repos_cabina_secado
                + iv12_repos_compresor + iv13_repos_aspiradoras
                + iv14_repos_racks + iv15_costo_oportunidad)

                               
# Bloque V.- Costos fijos no asociados a la producción

v01_alquiler = (vm['p_alquiler_fabricacion'] * vm['dolar'] * q_galpon / q_produccion_mensual_efectiva)


v02_higiene_seguridad = vm['p_higiene_seguridad'] / q_produccion_mensual_efectiva

v03_seguridad = vm['p_seguridad'] / q_produccion_mensual_efectiva


v04_muebles = ((vm['p_computadora'] * q_puestos_oficina / q_amortizacion_computadoras
                 + vm['p_escritorio'] * q_puestos_oficina / q_amortizacion_muebles
                 + vm['p_silla'] * q_puestos_oficina / q_amortizacion_muebles) / 12
                / q_produccion_mensual_efectiva)

v05_costo_financiero = (i00_materia_prima*1.21*(1+vm['p_tasa_interes_diaria']/100)**(plazo_cobro-plazo_pago_insumos)
                + (ii00_mano_obra_directa+iii00_mano_obra_indirecta)*(1+vm['p_tasa_interes_diaria']/100)**(plazo_cobro-plazo_pago_salarios)
                - i00_materia_prima*1.21 - (ii00_mano_obra_directa+iii00_mano_obra_indirecta)
                + (i00_materia_prima + ii00_mano_obra_directa + iii00_mano_obra_indirecta
                + iv00_maquinaria + v01_alquiler + v02_higiene_seguridad
                + v03_seguridad + v04_muebles)*1.21 * cobros_tarjeta_credito/100 * comisiones_tarjetas_credito/100
                + (i00_materia_prima + ii00_mano_obra_directa + iii00_mano_obra_indirecta
                + iv00_maquinaria + v01_alquiler + v02_higiene_seguridad
                + v03_seguridad + v04_muebles)*1.21 * cobros_tarjeta_credito/100 * (1+vm['p_tasa_interes_diaria']/100)**(plazo_cobro_tarjetas_credito)
                - (i00_materia_prima + ii00_mano_obra_directa + iii00_mano_obra_indirecta
                + iv00_maquinaria + v01_alquiler + v02_higiene_seguridad
                + v03_seguridad + v04_muebles)*1.21 * cobros_tarjeta_credito/100)

v06_estudio_contable = (vm['p_estudio_contable'] / q_produccion_mensual_efectiva)

v07_beneficios = ((i00_materia_prima + ii00_mano_obra_directa + iii00_mano_obra_indirecta
                + iv00_maquinaria + v01_alquiler + v02_higiene_seguridad
                + v03_seguridad + v04_muebles + v05_costo_financiero
                + v06_estudio_contable) * mark_up / 100)



v00_costos_fijos = (v01_alquiler + v02_higiene_seguridad + v03_seguridad
                + v04_muebles + v05_costo_financiero + v06_estudio_contable
                + v07_beneficios)
                        

# Bloque VI.- Costos impositivos

vi01_impuesto_ingresos_brutos = ((i00_materia_prima + ii00_mano_obra_directa
                + iii00_mano_obra_indirecta + iv00_maquinaria + v00_costos_fijos)
                * (vm['t_ib_extjuris_pba']/100 * q_ventas_pba / 100
                + vm['t_ib_extjuris_stafe']/100 * q_ventas_stafe / 100
                + vm['t_ib_extjuris_mza']/100 * q_ventas_cuyo / 100
                + vm['t_ib_extjuris_corrientes']/100 * q_ventas_mesopotamia / 100
                + vm['t_ib_extjuris_salta']/100 * q_ventas_noa / 100
                + vm['t_ib_extjuris_neuquen']/100 * q_ventas_neuquen / 100))

vi02_tasa_comercioeindustria = ((i00_materia_prima + ii00_mano_obra_directa
                + iii00_mano_obra_indirecta + iv00_maquinaria + v00_costos_fijos)
                * vm['t_comercioeindustria']/100)

                   
#vi03_impuesto_ganancias = ((v07_beneficios + iv15_costo_oportunidad)
#               * vm['t_ganancias']/100
#               + (v07_beneficios + iv15_costo_oportunidad)
#               * (1 - reinversion_utilidades/100)
#               * vm['t_dividendos']/100)

vi03_impuesto_ganancias = ((v07_beneficios )
                * vm['t_ganancias']/100
                + (v07_beneficios )
                * (1 - reinversion_utilidades/100)
                * vm['t_dividendos']/100)
                       
vi04_impuesto_cheque = ((i00_materia_prima + ii00_mano_obra_directa
                + iii00_mano_obra_indirecta + iv00_maquinaria
                + v00_costos_fijos + vi01_impuesto_ingresos_brutos
                + vi02_tasa_comercioeindustria + vi03_impuesto_ganancias )
                * 1.21 * (vm['t_cheque'] - vm['t_cheque_cred_fiscal']) / 100)


vi00_impuestos = (vi01_impuesto_ingresos_brutos + vi02_tasa_comercioeindustria
                + vi03_impuesto_ganancias + vi04_impuesto_cheque)
                   


# Bloque Indicadores de costos

                    
costo_modulo_pesos = (i00_materia_prima + ii00_mano_obra_directa
                + iii00_mano_obra_indirecta + iv00_maquinaria
                + v00_costos_fijos + vi00_impuestos)

costo_modulo_dolares = costo_modulo_pesos / vm['dolar']




# CONTROL:
print(costo_modulo_dolares)

