# Programa en Python - Sistema Estadistico de Costos Industria del Mueble


# MÓDULO I - CARGA DE VARIABLES MONETARIAS

import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import seaborn as sns

# Importar base de datos de series de tiempo con variables monetarias:

vm = pd.read_excel('Muebles variables monetarias v01.xlsx')


# Convertir columna mes en variable indexadora temporal:

vm.mes = pd.to_datetime(vm.mes)
vm.set_index('mes', inplace=True)

# MÓDULO II - DEFINICION DE PARÁMETROS

q_camiones = 3.00
q_carga_neta = 36.00
q_km_potenciales = 2000.00
tasa_actividad = 100.00
q_km_efectivos = 2000.00
q_tramo = 100.00
q_tramos_extraordinarios = 0.00
q_item423 = 0.00800
q_item424 = 0.00800
q_horas_extraordinarias = 1.00
q_control_descarga = 0.00
q_control_descarga_coef = 4.16667
q_antiguedad = 3.00
q_antiguedad_coef = 1.00
q_fuera_residencia = 0.00
q_prendas = 4.00
q_casco = 2.00
q_guantes = 2.00
q_botiquin = 2.00
q_sac_coef = 8.33
q_vacaciones_dias = 14.00
q_vacaciones_coef = 4.86
q_prevision_despido_coef = 4.00
q_medicina_laboral_coef = 8.00
q_gasoil = 0.4000
q_lubricante_motor = 0.001125
q_lubricante_diferencial = 0.000028
q_lubricante_caja = 0.000033
q_neumaticos_nuevos = 0.000220
q_neumaticos_recapados = 0.000220
q_filtro_aire = 0.000013
q_filtro_aceite = 0.000025
q_filtro_gasoil = 0.000033
q_trampa_agua = 0.000033
q_lavado_engrase = 4
q_amortizacion_vr = 40.0
q_amortizacion_anos = 8
q_reparaciones_repuestos = 6.5
q_administrativo_primera = 1
q_administrativo_segunda = 1
q_personal_operativo = 1
q_personal_taller = 1
q_jefe_trafico = 1
q_viaticos_comida = 22
q_viaticos_especial = 26
q_amortizacion_computadoras = 5
q_amortizacion_muebles = 10
q_costo_oportunidad = 4.0
mark_up = 10.0
utilidades_distribuidas = 50.0
incidencia_ib_cba = 0.0
incidencia_ib_pba = 0.0
incidencia_ib_caba = 0.0

# MODULO III - ESTIMACIONES DE COSTO

# Bloque I - Costos Asociados al Personal de Conducción

i01_rem_basica = ( vm['w_camioneros_conductor_primera'] / q_km_efectivos )

i02_bono = ( vm['w_camioneros_bono'] / q_km_efectivos )

i03_item423 = ( q_item423 / 100 * vm['w_camioneros_conductor_primera'] )

i04_item424 = ( q_item424 / 100 * vm['w_camioneros_conductor_primera'] )

i05_rem_extraordinaria = ( q_horas_extraordinarias * q_tramos_extraordinarios
            * q_tramo / q_km_efectivos * i01_rem_basica )

i06_control_descarga = ( q_control_descarga_coef / 100
            * vm['w_camioneros_conductor_primera'] * q_control_descarga
            / q_km_efectivos )

i07_antiguedad = ( q_antiguedad_coef / 100 * q_antiguedad
            * vm['w_camioneros_conductor_primera'] / q_km_efectivos )

i08_fuera_resid_a = ( vm['w_camioneros_FR_A'] * q_fuera_residencia
            / q_km_efectivos )

i09_fuera_resid_b = ( vm['w_camioneros_FR_B'] * q_fuera_residencia
            / q_km_efectivos )

i10_sac = (( i01_rem_basica + i03_item423 + i05_rem_extraordinaria
            + i07_antiguedad + i09_fuera_resid_b ) * q_sac_coef / 100 )

i11_vacaciones = (( i01_rem_basica + i03_item423 + i05_rem_extraordinaria
            + i07_antiguedad + i09_fuera_resid_b ) * q_vacaciones_coef / 100 )

i12_uniforme = (( vm['p_chofer_uniforme'] * q_prendas + vm['p_chofer_casco']
            * q_casco + vm['p_chofer_guantes'] * q_guantes
            + vm['p_chofer_botiquin'] * q_botiquin ) / 12 / q_km_efectivos )

i13_contrib_patronales = (( i01_rem_basica + i03_item423 + i05_rem_extraordinaria
            + i07_antiguedad + i09_fuera_resid_b + i10_sac + i11_vacaciones )
            * vm['t_cont_patronales_total'] / 100 )

i14_contrib_patronales_cred_fiscal = (-( i01_rem_basica + i03_item423
            + i05_rem_extraordinaria + i07_antiguedad + i09_fuera_resid_b
            + i10_sac + i11_vacaciones )
            * vm['t_cont_patronales_cred_fisc'] / 100 )

i15_contrib_osocial = (( i01_rem_basica + i03_item423 + i05_rem_extraordinaria
            + i07_antiguedad + i09_fuera_resid_b + i10_sac + i11_vacaciones )
            * vm['t_cont_osocial'] / 100 )

i16_seguro_vida_obligatorio = (( i01_rem_basica + i03_item423
            + i05_rem_extraordinaria + i07_antiguedad + i09_fuera_resid_b
            + i10_sac + i11_vacaciones )
            * vm['p_seguro_vida_oblig_muebles'] / 100 )

i17_contrib_federacion = (( i01_rem_basica + i03_item423 + i05_rem_extraordinaria
            + i07_antiguedad + i09_fuera_resid_b + i10_sac + i11_vacaciones )
            * vm['p_contribucion_federacion'] / 100 )

i18_art = (( i01_rem_basica + i03_item423 + i05_rem_extraordinaria
            + i07_antiguedad + i09_fuera_resid_b + i10_sac + i11_vacaciones )
            * vm['p_art'] / 100 )

i19_prev_despido = (( i01_rem_basica + i02_bono + i03_item423 + i04_item424
            + i05_rem_extraordinaria + i06_control_descarga + i07_antiguedad
            + i08_fuera_resid_a + i09_fuera_resid_b + i10_sac + i11_vacaciones )
            * q_prevision_despido_coef / 100 )

i20_ausentismo = (( i01_rem_basica + i02_bono + i03_item423 + i04_item424
            + i05_rem_extraordinaria + i06_control_descarga + i07_antiguedad
            + i08_fuera_resid_a + i09_fuera_resid_b + i10_sac + i11_vacaciones )
            * q_medicina_laboral_coef / 100 )

i21_ayuda_escolar = ( vm['w_camioneros_ayuda_esc'] / 12 / q_km_efectivos )

i22_licencia_nacional_habilitante = ( vm['w_camioneros_licencia_nacional']
            / 12 / q_km_efectivos )

i23_psicofisico = ( vm['w_camioneros_psicofisico'] / 12 / q_km_efectivos )

i00_personal_conduccion = ( i01_rem_basica + i02_bono + i03_item423 + i04_item424
            + i05_rem_extraordinaria + i06_control_descarga + i07_antiguedad
            + i08_fuera_resid_a + i09_fuera_resid_b + i10_sac + i11_vacaciones
            + i12_uniforme + i13_contrib_patronales
            + i14_contrib_patronales_cred_fiscal + i15_contrib_osocial
            + i16_seguro_vida_obligatorio + i17_contrib_federacion + i18_art
            + i19_prev_despido + i20_ausentismo + i21_ayuda_escolar
            + i22_licencia_nacional_habilitante + i23_psicofisico )

# Bloque II - Costos Variables Asociados al Vehiculo

ii01_combustible = ( q_gasoil * vm['p_gasoil'] )

ii02_impuesto_comb_liquidos = ( q_gasoil * vm['t_igo'] )

ii03_impuesto_comb_liquidos_credfiscal = ( 0 )

ii04_impuesto_dioxido_carbono = ( 0 )

ii05_lubricante_motor = ( q_lubricante_motor * vm['p_lubricante_motor'] )
    
ii06_lubricante_diferencial = ( q_lubricante_diferencial
            * vm['p_lubricante_diferencial'] )
    
ii07_lubricante_caja = ( q_lubricante_caja * vm['p_lubricante_caja'] )
    
ii08_neumaticos_nuevos = ( q_neumaticos_nuevos
            * ( vm['p_neumaticos_nuevos_liso'] * 14
            + vm['p_neumaticos_nuevos_taco'] * 4 ) / 18 )
                           
ii09_neumaticos_recapados = ( q_neumaticos_recapados
            * vm['p_neumaticos_recapados'] )

ii10_filtro_aire = ( q_filtro_aire * vm['p_filtro_aire'] )

ii11_filtro_aceite = ( q_filtro_aceite * vm['p_filtro_aceite'] )

ii12_filtro_gasoil = ( q_filtro_gasoil * vm['p_filtro_gasoil'] )

ii13_trampa_agua = ( q_trampa_agua * vm['p_trampa_agua'] )

ii14_lavado_engrase = ( q_lavado_engrase * vm['p_lavado_engrase']
            / q_km_efectivos )

ii00_costos_variables_vehiculo = ( ii01_combustible
            + ii02_impuesto_comb_liquidos
            + ii03_impuesto_comb_liquidos_credfiscal
            + ii04_impuesto_dioxido_carbono + ii05_lubricante_motor
            + ii06_lubricante_diferencial + ii07_lubricante_caja
            + ii08_neumaticos_nuevos + ii09_neumaticos_recapados
            + ii10_filtro_aire + ii11_filtro_aceite + ii12_filtro_gasoil
            + ii13_trampa_agua + ii14_lavado_engrase )

# Bloque III - Costos Fijos Asociados al Vehículo

iii01_patente = (( vm['p_tractor_420_valorfiscal']
            + vm['p_remolque_3ejes_valorfiscal'] ) * vm['t_patente'] / 100
            / 12 / q_km_efectivos )

iii02_ruta = ( vm['p_ruta'] / 12 / q_km_efectivos )

iii03_itv = ( vm['p_itv'] / 12 / q_km_efectivos )

iii04_rentas = (( vm['p_tractor_420_valorfiscal']
            + vm['p_remolque_3ejes_valorfiscal'] ) * vm['t_rentas_automotor']
            / 100 * ( 1 - vm['t_rentas_automotor_descuento'] / 100 )
            / 12 / q_km_efectivos )

iii05_seguro_vehiculos = ( vm['p_seguro_camiones'] / 100 * ( vm['p_tractor_420_valorfiscal']
            + vm['p_remolque_3ejes_valorfiscal'] ) / 12 / q_km_efectivos )

iii06_reparaciones_repuestos = (( vm['p_tractor_420'] + vm['p_remolque_3ejes'] )
            * q_reparaciones_repuestos / 100 / 12 / q_km_efectivos )

iii07_amortizacion_camiones = (( vm['p_tractor_420'] + vm['p_remolque_3ejes'] )
            * ( 1 - q_amortizacion_vr / 100 ) / q_amortizacion_anos
            / 12 / q_km_efectivos )

iii08_costo_oportunidad = (( vm['p_tractor_420'] + vm['p_remolque_3ejes'] )
            * ( q_amortizacion_vr + ( 100 - q_amortizacion_vr ) / 2 ) / 100
            * q_costo_oportunidad / 100 / 12 / q_km_efectivos )

iii09_costo_comunicacion = ( vm['costos_cominicacion_camiones'] / q_km_efectivos )

iii00_costos_fijos_vehiculos = ( iii01_patente + iii02_ruta + iii03_itv
            + iii04_rentas + iii05_seguro_vehiculos
            + iii06_reparaciones_repuestos + iii07_amortizacion_camiones
            + iii08_costo_oportunidad + iii09_costo_comunicacion )

# Bloque IV - Costos Fijos No Asociados al Vehículo

iv01_personal_admin = (( vm['w_camioneros_adm_primera']
            * q_administrativo_primera + vm['w_camioneros_adm_segunda']
            * q_administrativo_segunda ) / q_camiones / q_km_efectivos )

iv02_personal_operativo = ( vm['w_camioneros_oficial_planchada']
            * q_personal_operativo / q_camiones / q_km_efectivos )

iv03_personal_taller = ( vm['w_camioneros_taller']
            * q_personal_taller / q_camiones / q_km_efectivos )

iv04_jefe_trafico = ( vm['w_camioneros_trafico']
            * q_jefe_trafico / q_camiones / q_km_efectivos )

iv05_bono = ( vm['w_camioneros_bono'] * ( q_administrativo_primera
            + q_administrativo_segunda + q_personal_operativo
            + q_personal_taller + q_jefe_trafico ) / q_camiones
            / q_km_efectivos )

iv06_viaticos = (( vm['w_camioneros_viaticos_comida'] * q_viaticos_comida
            * ( q_administrativo_primera  + q_administrativo_segunda
            + q_personal_operativo + q_personal_taller + q_jefe_trafico )
            + vm['w_camioneros_viaticos_especial'] * q_viaticos_especial
            * ( q_administrativo_primera  + q_administrativo_segunda
            + q_personal_operativo + q_personal_taller + q_jefe_trafico ))
            / q_camiones / q_km_efectivos )
                 
iv07_antiguedad = (( iv01_personal_admin + iv02_personal_operativo
            + iv03_personal_taller + iv04_jefe_trafico ) * q_antiguedad_coef
            / 100 * q_antiguedad )
                 
iv08_sac = (( iv01_personal_admin + iv02_personal_operativo
            + iv03_personal_taller + iv04_jefe_trafico ) * q_sac_coef
            / 100 )
                 
iv09_vacaciones = (( iv01_personal_admin + iv02_personal_operativo
            + iv03_personal_taller + iv04_jefe_trafico ) * q_vacaciones_coef
            / 100 )
                 
iv10_contrib_patronales = (( iv01_personal_admin + iv02_personal_operativo
            + iv03_personal_taller + iv04_jefe_trafico + iv07_antiguedad
            + iv08_sac + iv09_vacaciones ) * vm['t_cont_patronales_total'] / 100)
                 
iv11_contrib_patronales_cred_fiscal = (-( iv01_personal_admin
            + iv02_personal_operativo + iv03_personal_taller
            + iv04_jefe_trafico + iv07_antiguedad + iv08_sac + iv09_vacaciones )
            * vm['t_cont_patronales_cred_fisc'] / 100 )
                 
iv12_contrib_osocial = (( iv01_personal_admin + iv02_personal_operativo
            + iv03_personal_taller + iv04_jefe_trafico + iv07_antiguedad
            + iv08_sac + iv09_vacaciones ) * vm['t_cont_osocial'] / 100)
                 
iv13_seguro_vida_obligatorio = (( iv01_personal_admin + iv02_personal_operativo
            + iv03_personal_taller + iv04_jefe_trafico + iv07_antiguedad
            + iv08_sac + iv09_vacaciones ) * vm['p_seguro_vida_oblig_muebles']
            / 100)
                 
iv14_contrib_federacion = (( iv01_personal_admin + iv02_personal_operativo
            + iv03_personal_taller + iv04_jefe_trafico + iv07_antiguedad
            + iv08_sac + iv09_vacaciones ) * vm['p_contribucion_federacion']
            / 100)
                 
iv15_art = (( iv01_personal_admin + iv02_personal_operativo
            + iv03_personal_taller + iv04_jefe_trafico + iv07_antiguedad
            + iv08_sac + iv09_vacaciones ) * vm['p_art'] / 100)
                 
iv16_prev_despido = (( iv01_personal_admin + iv02_personal_operativo
            + iv03_personal_taller + iv04_jefe_trafico + iv05_bono
            + iv06_viaticos + iv07_antiguedad + iv08_sac + iv09_vacaciones )
            * q_prevision_despido_coef / 100 )
                 
iv17_alquiler = ( vm['p_alquiler_emp_transporte'] / q_camiones
            / q_km_efectivos )
                 
iv18_energia = ( vm['p_energia_emp_transporte'] / q_camiones
            / q_km_efectivos )
                 
iv19_muebles = ((( vm['p_computadora'] / q_amortizacion_computadoras / 12 )
            * ( q_administrativo_primera  + q_administrativo_segunda
            + q_personal_operativo + q_personal_taller + q_jefe_trafico )
            + (( vm['p_escritorio'] + vm['p_silla'] ) / q_amortizacion_muebles
            / 12 )) / q_camiones / q_km_efectivos )
                 
iv20_costo_financiero = ((( i01_rem_basica + i02_bono + i03_item423
            + i04_item424 + i05_rem_extraordinaria + i06_control_descarga
            + i07_antiguedad + i08_fuera_resid_a + i09_fuera_resid_b )
            + ii01_combustible + ( iv01_personal_admin + iv02_personal_operativo
            + iv03_personal_taller + iv04_jefe_trafico + iv05_bono
            + iv06_viaticos )) * vm['p_tasa_interes_mensual'] / 100
            * vm['costos_erogables_financiados'] / 100 )
                 
iv21_estudio_contable = ( vm['p_estudio_contable'] / q_camiones
            / q_km_efectivos )
                 
iv22_beneficios = (( i00_personal_conduccion + ii00_costos_variables_vehiculo
            + iii00_costos_fijos_vehiculos + ( iv01_personal_admin
            + iv02_personal_operativo + iv03_personal_taller
            + iv04_jefe_trafico + iv05_bono + iv06_viaticos + iv07_antiguedad
            + iv08_sac + iv09_vacaciones + iv10_contrib_patronales
            + iv11_contrib_patronales_cred_fiscal + iv12_contrib_osocial
            + iv13_seguro_vida_obligatorio + iv14_contrib_federacion + iv15_art
            + iv16_prev_despido + iv17_alquiler + iv18_energia + iv19_muebles
            + iv20_costo_financiero )) * mark_up / 100 )

iv00_costos_fijos_resto = ( iv01_personal_admin + iv02_personal_operativo
            + iv03_personal_taller + iv04_jefe_trafico + iv05_bono
            + iv06_viaticos + iv07_antiguedad + iv08_sac + iv09_vacaciones
            + iv10_contrib_patronales + iv11_contrib_patronales_cred_fiscal
            + iv12_contrib_osocial + iv13_seguro_vida_obligatorio
            + iv14_contrib_federacion + iv15_art + iv16_prev_despido
            + iv17_alquiler + iv18_energia + iv19_muebles
            + iv20_costo_financiero + iv21_estudio_contable + iv22_beneficios )

# Bloque VI.- Costos impositivos

v01_impuesto_ingresos_brutos = (( i00_personal_conduccion + ii00_costos_variables_vehiculo
            + iii00_costos_fijos_vehiculos + iv00_costos_fijos_resto )
            * vm['t_ib_transporte_cba'] / 100 )

v02_tasa_comercioeindustria = (( i00_personal_conduccion + ii00_costos_variables_vehiculo
            + iii00_costos_fijos_vehiculos + iv00_costos_fijos_resto )
            * vm['t_comercioeindustria'] / 100 )

v03_impuesto_ganancias = ( iv22_beneficios * vm['t_ganancias'] / 100
            + iv22_beneficios * utilidades_distribuidas / 100
            * vm['t_dividendos'] / 100 )

v04_impuesto_cheque = (( i00_personal_conduccion + ii00_costos_variables_vehiculo
            + iii00_costos_fijos_vehiculos + iv00_costos_fijos_resto
            + v01_impuesto_ingresos_brutos + v02_tasa_comercioeindustria
            + v03_impuesto_ganancias )
            * vm['t_cheque'] / 100 )

v05_impuesto_cheque_cred_fiscal = (-( i00_personal_conduccion + ii00_costos_variables_vehiculo
            + iii00_costos_fijos_vehiculos + iv00_costos_fijos_resto
            + v01_impuesto_ingresos_brutos + v02_tasa_comercioeindustria
            + v03_impuesto_ganancias + v04_impuesto_cheque )
            * vm['t_cheque_cred_fiscal'] / 100 )

v00_impuestos = ( v01_impuesto_ingresos_brutos + v02_tasa_comercioeindustria
            + v03_impuesto_ganancias + v04_impuesto_cheque
            + v05_impuesto_cheque_cred_fiscal )

# Bloque Indicadores de costos

                    
costo_km_pesos = ( i00_personal_conduccion + ii00_costos_variables_vehiculo
            + iii00_costos_fijos_vehiculos + iv00_costos_fijos_resto
            + v00_impuestos )

costo_tn_pesos = ( costo_km_pesos * q_tramo / q_carga_neta )

costo_km_dolares = ( costo_km_pesos / vm['dolar'] )

costo_tn_dolares = ( costo_tn_pesos / vm['dolar'] )

#CONTROL

print (costo_tn_dolares)
