# Programa en Python - Sistema Estadistico de Costos Industria Grafica- 


# MÓDULO I - CARGA DE VARIABLES MONETARIAS

import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import seaborn as sns


# Importar base de datos de series de tiempo con variables monetarias:

vm = pd.read_excel('Variables monetarias costos industria grafica.xlsx')


# Convertir columna mes en variable indexadora temporal:

vm.mes = pd.to_datetime(vm.mes)
vm.set_index('mes', inplace=True)       

# MÓDULO II - Definicion de Parametros - libros LIBROS

#Parámetros generales
ratio_ejemplares_tirada = 1000
ratio_tiradas_dia = 1
q_dias_trabajados_mes = 20
q_produccion_mensual_potencial = 20000
q_capacidad_utilizada = 100
q_produccion_mensual_efectiva = 20000
q_paginas_ejemplar = 200
#Materias Primas	
q_papel_tapa_gramaje = 300
q_papel_tapa_pliego_ancho = 0.15
q_papel_tapa_pliego_largo = 0.21
q_papel_interior_gramaje = 80
q_papel_interior_pliego_ancho = 0.15
q_papel_interior_pliego_largo = 0.21
tinta_para_tapa = 3.8
laminado_para_tapa = 90
demasia_pliego_por_tirada = 150
demasia_porcentaje = 2.0
q_planchas_impresion_tapas = 4.0
q_planchas_impresion_interior = 25.0
tinta_para_interior = 8.0
alambre_engrapado = 1.35
cajas = 15.0
pallets = 5.0
nylon_embalaje = 0.3
#Mano de obra directa	
q_jornada = 184
q_op_guillotinista = 1
q_op_maquinista_offset = 1
q_op_ayudante_offset = 1
q_op_ctp = 1
q_op_laminadora = 1
q_op_dobladora = 0
q_op_encuadernadora = 1
#Mano de obra Indirecta	
q_personal_admin = 1
q_personal_comercial = 1
q_presupuestista = 1
q_personal_limpieza = 1
q_encargado_logistica = 1
q_gerente_general = 1
#Maquinaria	
q_plotter = 1
q_ctp = 1
q_guillotina = 1
q_impresora = 1
q_laminadora = 1
q_dobladora = 0
q_encuadernadora = 1
q_alzadora = 1
q_utilitario = 1
q_computadoras_admin = 6
a_plotter = 5
a_ctp = 5
a_guillotina = 20
a_impresora = 20
a_laminadora = 15
a_dobladora = 15
a_encuadernadora = 20
a_alzadora = 15
a_utilitario = 10
a_computadoras_admin = 5
vr_plotter = 0
vr_ctp = 30
vr_guillotina = 40
vr_impresora = 0
vr_laminadora = 30
vr_dobladora = 30
vr_encuadernadora = 30
vr_alzadora = 30
vr_utilitario = 30
vr_computadoras_admin = 0
costo_oportunidad = 4.0
#Resto parámetros
q_energia_potencia = 90.00
q_energia_consumo = 22000
q_energia_potencia_punta = 5
q_energia_potencia_fuerapunta = 19
q_energia_pico = 5
q_energia_valle = 6
q_energia_resto = 13
q_galpon = 600
q_antiguedad = 10.00
q_antiguedad_coef = 1.00
q_prendas = 4.00
q_casco = 2.00
q_guantes = 2.00
q_sac = 8.33
q_vacaciones = 28.00
q_fondo_despido = 4.00
q_ausentismo = 3.00
q_puestos_oficina = 6
q_amortizacion_muebles = 10
plazo_pago_insumos = 30
plazo_cobro = 60
plazo_pago_salarios = 30
mark_up = 10.0
q_ventas_cba = 50.0
q_ventas_pba = 0.0
q_ventas_stafe = 0.0
q_ventas_cuyo = 10.0
q_ventas_mesopotamia = 0.0
q_ventas_noa = 40.0
q_ventas_nequen = 0.0
reinversion_utilidades = 50.0


#MÓDULO 3 - ESTIMACIONES DE COSTOS

# EDITORIAL LIBROS


#Bloque I - Materia Prima

i01_papel = ( q_papel_tapa_gramaje * q_papel_tapa_pliego_ancho
            * q_papel_tapa_pliego_largo * 2 / 1000 * vm['p_papel_ilustr_300gr']
            * vm['dolar'] + q_papel_interior_gramaje
            * q_papel_interior_pliego_ancho * q_papel_interior_pliego_largo
            / 2 / 1000 * q_paginas_ejemplar * vm['p_papel_obra_80gr']
            * vm['dolar'] )

i02_tinta = ( tinta_para_tapa / 1000 * vm['p_tinta_libros'] * vm['dolar']
            + tinta_para_interior / 1000 * vm['p_tinta_libros'] * vm['dolar'] )

i03_laminado = ( laminado_para_tapa / 1000 * vm['p_laminado_libros']
            * vm['dolar'] )

i04_plancha_impresion = (( q_planchas_impresion_tapas
            + q_planchas_impresion_interior ) * vm['p_plancha_impr_libros']
            * vm['dolar'] / ratio_ejemplares_tirada )

i05_alambre_engrapado = ( alambre_engrapado / 1000
            * vm['p_alambre_engrapado_libros'] * vm['dolar'] )

i06_cajas = ( vm['p_caja_libros'] / cajas )

i07_pallets = ( vm['p_pallet'] * pallets / 1000 )

i08_streech = ( nylon_embalaje * pallets / ratio_ejemplares_tirada
            * vm['p_nylon_pallets_libros'] * vm['dolar'] )

i00_materia_prima = ( i01_papel + i02_tinta + i03_laminado
            + i04_plancha_impresion + i05_alambre_engrapado + i06_cajas
            + i07_pallets + i08_streech )

#Bloque II - Costos de Mano de Obra Directa

ii01_remuneracion_operarios = (( q_op_guillotinista * vm['categoria_08']
            + q_op_maquinista_offset * vm['categoria_10'] + q_op_ayudante_offset
            * vm['categoria_07'] + q_op_ctp * vm['categoria_08']
            + q_op_laminadora * vm['categoria_08'] + q_op_dobladora
            * vm['categoria_08'] + q_op_encuadernadora * ( vm['categoria_08']
            + vm['categoria_05']) / 2 ) / q_produccion_mensual_efectiva )
                                 
ii02_remuneracion_operarios_norem = ( 0 )

ii03_horas_extras = ( 0 )

ii04_horas_extras2 = ( 0 )

ii05_antiguedad = (( ii01_remuneracion_operarios + ii03_horas_extras
            + ii04_horas_extras2 ) * q_antiguedad_coef / 100 * q_antiguedad )

ii06_sac = (( ii01_remuneracion_operarios + ii03_horas_extras
            + ii04_horas_extras2 + ii05_antiguedad ) * q_sac / 100 )

ii07_vacaciones = (( ii01_remuneracion_operarios
            + ii02_remuneracion_operarios_norem + ii05_antiguedad ) / 30
            * q_vacaciones / 12 )

ii08_contrib_patronales = ((( ii01_remuneracion_operarios + ii03_horas_extras
            + ii04_horas_extras2 + ii05_antiguedad + ii06_sac + ii07_vacaciones )
            - vm['t_cont_patronales_mni'] * (q_op_guillotinista
            + q_op_maquinista_offset + q_op_ayudante_offset + q_op_ctp
            + q_op_laminadora + q_op_dobladora + q_op_encuadernadora )
            / q_produccion_mensual_efectiva ) * vm['t_cont_patronales_total']
            / 100 )
                             
ii09_contrib_patronales_cred_fiscal = (-(( ii01_remuneracion_operarios
            + ii03_horas_extras + ii04_horas_extras2 + ii05_antiguedad
            + ii06_sac + ii07_vacaciones ) - vm['t_cont_patronales_mni']
            * (q_op_guillotinista + q_op_maquinista_offset
            + q_op_ayudante_offset + q_op_ctp + q_op_laminadora + q_op_dobladora
            + q_op_encuadernadora ) / q_produccion_mensual_efectiva )
            * vm['t_cont_patronales_cred_fisc'] / 100 )

ii10_contrib_osocial = (( ii01_remuneracion_operarios
            + ii03_horas_extras + ii04_horas_extras2 + ii05_antiguedad
            + ii06_sac + ii07_vacaciones ) * vm['t_cont_osocial'] / 100 )

ii11_seguro_vida_obligatorio  = (( ii01_remuneracion_operarios
            + ii03_horas_extras + ii04_horas_extras2 + ii05_antiguedad
            + ii06_sac + ii07_vacaciones ) * vm['p_seguro_vida_oblig_muebles']
            / 100 )

ii12_art = (( ii01_remuneracion_operarios
            + ii03_horas_extras + ii04_horas_extras2 + ii05_antiguedad
            + ii06_sac + ii07_vacaciones ) * vm['p_art'] / 100 )

ii13_prev_despido = (( ii01_remuneracion_operarios
            + ii02_remuneracion_operarios_norem + ii03_horas_extras
            + ii04_horas_extras2 + ii05_antiguedad + ii06_sac
            + ii07_vacaciones ) * q_fondo_despido / 100 )

ii14_ausentismo = (( ii01_remuneracion_operarios + ii05_antiguedad + ii06_sac
            + ii07_vacaciones + ii08_contrib_patronales
            + ii09_contrib_patronales_cred_fiscal + ii10_contrib_osocial
            + ii11_seguro_vida_obligatorio + ii12_art + ii13_prev_despido )
            * q_ausentismo / 100 )

ii15_aporte_UGA = (( ii01_remuneracion_operarios
            + ii03_horas_extras + ii04_horas_extras2 + ii05_antiguedad
            + ii06_sac + ii07_vacaciones ) * vm['aporte_uga'] / 100 )

ii16_aporte_AFATIDA = (( ii01_remuneracion_operarios
            + ii03_horas_extras + ii04_horas_extras2 + ii05_antiguedad
            + ii06_sac + ii07_vacaciones ) * vm['aporte_afatida'] / 100 )

ii00_mano_obra_directa = ( ii01_remuneracion_operarios
            + ii02_remuneracion_operarios_norem + ii03_horas_extras
            + ii04_horas_extras2 + ii05_antiguedad + ii06_sac
            + ii07_vacaciones + ii08_contrib_patronales
            + ii09_contrib_patronales_cred_fiscal + ii10_contrib_osocial
            + ii11_seguro_vida_obligatorio + ii12_art + ii13_prev_despido
            + ii14_ausentismo + ii15_aporte_UGA + ii16_aporte_AFATIDA )

# Bloque III - Costos de Mano de Obra Indirecta

iii01_rem_supervisores = ( vm['convenio_personal_admin'] * q_personal_admin
            / q_produccion_mensual_efectiva )

iii02_rem_disenadores = ( vm['convenio_personal_comercial']
            * q_personal_comercial / q_produccion_mensual_efectiva )

iii03_rem_presupuetista = ( vm['convenio_presupuetista'] * q_presupuestista
            / q_produccion_mensual_efectiva )

iii04_rem_limpieza = ( vm['convenio_personal_limpieza'] * q_personal_limpieza
            / q_produccion_mensual_efectiva )

iii05_rem_encargado_logistica = ( vm['convenio_encargado_logistica']
            * q_encargado_logistica / q_produccion_mensual_efectiva )

iii06_rem_gerente_general = ( vm['convenio_gerente_general'] * q_gerente_general
            / q_produccion_mensual_efectiva )

iii07_antiguedad = (( iii01_rem_supervisores + iii02_rem_disenadores
            + iii03_rem_presupuetista + iii04_rem_limpieza
            + iii05_rem_encargado_logistica + iii06_rem_gerente_general )
            * q_antiguedad_coef / 100 * q_antiguedad )

iii08_no_rem = ( vm['no_rem'] * ( q_personal_admin + q_personal_comercial
            + q_presupuestista + q_personal_limpieza + q_encargado_logistica
            + q_gerente_general ) / q_produccion_mensual_efectiva )
            
iii09_sac = (( iii01_rem_supervisores + iii02_rem_disenadores
            + iii03_rem_presupuetista + iii04_rem_limpieza
            + iii05_rem_encargado_logistica + iii06_rem_gerente_general
            + iii07_antiguedad ) * q_sac / 100 )

iii10_vacaciones = (( iii01_rem_supervisores + iii02_rem_disenadores
            + iii03_rem_presupuetista + iii04_rem_limpieza
            + iii05_rem_encargado_logistica + iii06_rem_gerente_general
            + iii07_antiguedad ) / 30 * q_vacaciones / 12 )

iii11_contrib_patronales = ((( iii01_rem_supervisores + iii02_rem_disenadores
            + iii03_rem_presupuetista + iii04_rem_limpieza
            + iii05_rem_encargado_logistica + iii06_rem_gerente_general
            + iii07_antiguedad + iii08_no_rem + iii09_sac + iii10_vacaciones )
            - vm['t_cont_patronales_mni'] * ( q_personal_admin
            + q_personal_comercial + q_presupuestista + q_personal_limpieza
            + q_encargado_logistica + q_gerente_general )
            / q_produccion_mensual_efectiva ) * vm['t_cont_patronales_total']
            / 100 )

iii12_contrib_patronales_cred_fiscal = (-(( iii01_rem_supervisores
            + iii02_rem_disenadores + iii03_rem_presupuetista
            + iii04_rem_limpieza + iii05_rem_encargado_logistica
            + iii06_rem_gerente_general + iii07_antiguedad + iii08_no_rem + iii09_sac
            + iii10_vacaciones ) - vm['t_cont_patronales_mni']
            * ( q_personal_admin + q_personal_comercial + q_presupuestista
            + q_personal_limpieza + q_encargado_logistica + q_gerente_general )
            / q_produccion_mensual_efectiva )
            * vm['t_cont_patronales_cred_fisc'] / 100 )

iii13_contrib_osocial = (( iii01_rem_supervisores + iii02_rem_disenadores
            + iii03_rem_presupuetista + iii04_rem_limpieza
            + iii05_rem_encargado_logistica + iii06_rem_gerente_general
            + iii07_antiguedad + iii08_no_rem + iii09_sac + iii10_vacaciones )
            * vm['t_cont_osocial'] / 100 )

iii14_seguro_vida_obligatorio = (( iii01_rem_supervisores + iii02_rem_disenadores
            + iii03_rem_presupuetista + iii04_rem_limpieza
            + iii05_rem_encargado_logistica + iii06_rem_gerente_general
            + iii07_antiguedad ) * vm['p_seguro_vida_oblig_muebles'] / 100 )

iii15_art = (( iii01_rem_supervisores + iii02_rem_disenadores
            + iii03_rem_presupuetista + iii04_rem_limpieza
            + iii05_rem_encargado_logistica + iii06_rem_gerente_general
            + iii07_antiguedad + iii08_no_rem + iii09_sac + iii10_vacaciones )
            * vm['p_art'] / 100 )

iii16_prev_despido = (( iii01_rem_supervisores + iii02_rem_disenadores
            + iii03_rem_presupuetista + iii04_rem_limpieza
            + iii05_rem_encargado_logistica + iii06_rem_gerente_general
            + iii07_antiguedad + iii08_no_rem + iii09_sac + iii10_vacaciones )
            * q_fondo_despido / 100 )

iii17_aporte_uga = (( iii01_rem_supervisores + iii02_rem_disenadores
            + iii03_rem_presupuetista + iii04_rem_limpieza
            + iii05_rem_encargado_logistica + iii06_rem_gerente_general
            + iii07_antiguedad ) * vm['aporte_uga'] / 100 )

iii18_aporte_afatida = (( iii01_rem_supervisores + iii02_rem_disenadores
            + iii03_rem_presupuetista + iii04_rem_limpieza
            + iii05_rem_encargado_logistica + iii06_rem_gerente_general
            + iii07_antiguedad + iii08_no_rem + iii09_sac + iii10_vacaciones )
            * vm['aporte_afatida'] / 100 )

iii00_mano_obra_indirecta = ( iii01_rem_supervisores + iii02_rem_disenadores
            + iii03_rem_presupuetista + iii04_rem_limpieza
            + iii05_rem_encargado_logistica + iii06_rem_gerente_general
            + iii07_antiguedad + iii08_no_rem + iii09_sac + iii10_vacaciones
            + iii11_contrib_patronales + iii12_contrib_patronales_cred_fiscal
            + iii13_contrib_osocial + iii14_seguro_vida_obligatorio
            + iii15_art + iii16_prev_despido + iii17_aporte_uga
            + iii18_aporte_afatida )

#Bloque IV - Costos de Maquinaria

iv01_energia = (( q_energia_potencia * q_energia_potencia_punta
            / ( q_energia_potencia_punta + q_energia_potencia_fuerapunta )
            * vm['p_energia_potencia_punta'] + q_energia_potencia
            * q_energia_potencia_fuerapunta / ( q_energia_potencia_punta
            + q_energia_potencia_fuerapunta )
            * vm['p_energia_potencia_fuerapunta'] + q_energia_consumo
            * q_energia_pico / ( q_energia_pico + q_energia_valle
            + q_energia_resto ) * vm['p_energia_pico'] + q_energia_consumo
            * q_energia_valle / ( q_energia_pico + q_energia_valle
            + q_energia_resto ) * vm['p_energia_valle'] + q_energia_consumo
            * q_energia_resto / ( q_energia_pico + q_energia_valle
            + q_energia_resto ) * vm['p_energia_resto'] )
            / q_produccion_mensual_efectiva )

iv02_impuestos_energia = ( iv01_energia * ( vm['t_energia_perc_dgi']
            + vm['t_energia_oim'] + vm['t_energia_dto2298']
            + vm['t_energia_ersep'] + vm['t_energia_ley9819'] ) / 100 )

iv03_rep_plotter = ( vm['p_plotter_libros'] * vm['dolar'] * q_plotter
            * ( 1 - vr_plotter / 100 ) / a_plotter / 12
            / q_produccion_mensual_efectiva )

iv04_rep_ctp = ( vm['p_ctp_libros'] * vm['dolar'] * q_ctp
            * ( 1 - vr_ctp / 100 ) / a_ctp / 12
            / q_produccion_mensual_efectiva )

iv05_guillotina = ( vm['p_guillotina_libros'] * vm['dolar'] * q_guillotina
            * ( 1 - vr_guillotina / 100 ) / a_guillotina / 12
            / q_produccion_mensual_efectiva )

iv06_impresora = ( vm['p_impresora_libros'] * vm['dolar'] * q_impresora
            * ( 1 - vr_impresora / 100 ) / a_impresora / 12
            / q_produccion_mensual_efectiva )

iv07_laminadora = ( vm['p_laminadora_libros'] * vm['dolar'] * q_laminadora
            * ( 1 - vr_laminadora / 100 ) / a_laminadora / 12
            / q_produccion_mensual_efectiva )

iv08_dobladora = ( vm['p_dobladora_libros'] * vm['dolar'] * q_dobladora
            * ( 1 - vr_dobladora / 100 ) / a_dobladora / 12
            / q_produccion_mensual_efectiva )

iv09_encuadernadora = ( vm['p_encuadernadora_libros'] * vm['dolar']
            * q_encuadernadora * ( 1 - vr_encuadernadora / 100 )
            / a_encuadernadora / 12 / q_produccion_mensual_efectiva )

iv10_alzadora = ( vm['p_alzadora_libros'] * vm['dolar']
            * q_alzadora * ( 1 - vr_alzadora / 100 )
            / a_alzadora / 12 / q_produccion_mensual_efectiva )      

iv11_utilitario = ( vm['p_utilitario'] * vm['dolar'] * q_utilitario
            * ( 1 - vr_utilitario / 100 ) / a_utilitario / 12
            / q_produccion_mensual_efectiva )

iv12_computadoras_amdin = ( vm['p_computadora_admin'] * vm['dolar']
            * q_computadoras_admin * ( 1 - vr_computadoras_admin / 100 )
            / a_computadoras_admin / 12 / q_produccion_mensual_efectiva )

iv13_costo_oportunidad = (( q_plotter * vm['p_plotter_libros'] * vm['dolar']
            * (( 1 - vr_plotter / 100 ) / 2 + vr_plotter / 100 ) + q_ctp
            * vm['p_ctp_libros'] * vm['dolar'] * (( 1 - vr_ctp / 100 ) / 2
            + vr_ctp / 100 ) + q_guillotina * vm['p_guillotina_libros']
            * vm['dolar'] * (( 1 - vr_guillotina / 100 ) / 2 + vr_guillotina
            / 100 ) + q_impresora * vm['p_impresora_libros'] * vm['dolar']
            * (( 1 - vr_impresora / 100 ) / 2 + vr_impresora / 100 )
            + q_laminadora * vm['p_laminadora_libros'] * vm['dolar']
            * (( 1 - vr_laminadora / 100 ) / 2 + vr_laminadora / 100 )
            + q_dobladora * vm['p_dobladora_libros'] * vm['dolar'] * (( 1
            - vr_dobladora / 100 ) / 2 + vr_dobladora / 100 ) + q_encuadernadora
            * vm['p_encuadernadora_libros'] * vm['dolar'] * (( 1
            - vr_encuadernadora / 100 ) / 2 + vr_encuadernadora / 100 ))
            * costo_oportunidad / 100 / 12 / q_produccion_mensual_potencial )

iv00_maquinaria = ( iv01_energia + iv02_impuestos_energia + iv03_rep_plotter
            + iv04_rep_ctp + iv05_guillotina + iv06_impresora
            + iv07_laminadora + iv08_dobladora + iv09_encuadernadora
            + iv10_alzadora + iv11_utilitario + iv12_computadoras_amdin
            + iv13_costo_oportunidad )

#Bloque V - Costos Fijos No Asociados a la Producción

v01_alquiler = ( q_galpon * vm['p_alquiler_fabricacion'] * vm['dolar']
            / q_produccion_mensual_efectiva )

v02_muebles = ( q_computadoras_admin * ( vm['p_silla'] + vm['p_escritorio'] )
            / q_amortizacion_muebles / 12 / q_produccion_mensual_potencial )

v03_costo_financiero = ( i00_materia_prima * ( pow ( 1 + vm['p_tasa_interes_diaria']
            / 100,( plazo_cobro - plazo_pago_insumos ))) - i00_materia_prima
            + ( ii00_mano_obra_directa + iii00_mano_obra_indirecta )
            * ( pow ( 1 + vm['p_tasa_interes_diaria'] / 100,( plazo_cobro
            - plazo_pago_salarios ))) - ( ii00_mano_obra_directa
            + iii00_mano_obra_indirecta ))

v04_estudio_contable = ( vm['p_estudio_contable']
            / q_produccion_mensual_efectiva )

v05_beneficios = (( i00_materia_prima + ii00_mano_obra_directa
            + iii00_mano_obra_indirecta + iv00_maquinaria + ( v01_alquiler
            + v02_muebles + v03_costo_financiero + v04_estudio_contable ))
            * mark_up / 100 )

v00_costos_fijos = ( v01_alquiler + v02_muebles + v03_costo_financiero
            + v04_estudio_contable + v05_beneficios )

#Bloque VI - Costos Impositivos

vi01_impuesto_ingresos_brutos = ((  i00_materia_prima + ii00_mano_obra_directa
            + iii00_mano_obra_indirecta + iv00_maquinaria + v00_costos_fijos )
            * ( vm['t_ib_extjuris_pba'] * q_ventas_pba
            + vm['t_ib_extjuris_stafe'] * q_ventas_stafe
            + vm['t_ib_extjuris_mza'] * q_ventas_cuyo
            + vm['t_ib_extjuris_corrientes'] * q_ventas_mesopotamia
            + vm['t_ib_extjuris_salta'] * q_ventas_noa
            + vm['t_ib_extjuris_neuquen'] * q_ventas_nequen ) / 100 / 100 )

vi02_tasa_comercioeindustria = ((  i00_materia_prima + ii00_mano_obra_directa
            + iii00_mano_obra_indirecta + iv00_maquinaria + v00_costos_fijos )
            * vm['t_comercioeindustria'] / 100 )

vi03_impuesto_ganancias = ( v05_beneficios * vm['t_ganancias'] / 100
            + v05_beneficios * ( 1 - reinversion_utilidades / 100 )
            * vm['t_dividendos'] / 100 )

vi04_impuesto_cheque = (( i00_materia_prima + ii00_mano_obra_directa
            + iii00_mano_obra_indirecta + iv00_maquinaria + v00_costos_fijos
            + vi01_impuesto_ingresos_brutos + vi02_tasa_comercioeindustria
            + vi03_impuesto_ganancias ) * 1.21 * ( vm['t_cheque']
            - vm['t_cheque_cred_fiscal'] ) / 100 )

vi00_impuestos = ( vi01_impuesto_ingresos_brutos
            + vi02_tasa_comercioeindustria + vi03_impuesto_ganancias
            + vi04_impuesto_cheque )

# Bloque Indicadores de Costo

costo_ejemplar_pesos = ( i00_materia_prima + ii00_mano_obra_directa
            + iii00_mano_obra_indirecta + iv00_maquinaria + v00_costos_fijos
            + vi00_impuestos )

costo_ejemplar_dolares = ( costo_ejemplar_pesos / vm['dolar'] )

#CONTROL

print (costo_ejemplar_dolares)

