# Programa en Python- Sistema Estadistico de Costos Industria Grafica


# MÓDULO I - CARGA DE VARIABLES MONETARIAS

import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import seaborn as sns


# Importar base de datos de series de tiempo con variables monetarias:

vm = pd.read_excel('Variables monetarias costos industria grafica.xlsx')


# Convertir columna mes en variable indexadora temporal:

vm.mes = pd.to_datetime(vm.mes)
vm.set_index('mes', inplace=True)       

# MÓDULO II - Definicion de Parametros - PACKAGING

ratio_estuches_tirada= 100000
ratio_tiradas_dia= 1
q_dias_trabajados_mes= 20
q_produccion_mensual_potencial= 2000000
q_capacidad_utilizada= 100
q_produccion_mensual_efectiva= 2000000
ratio_estuches_pliego= 4.0
tamano_pliego_largo= 0.72
tamano_pliego_ancho= 0.51
tamano_pliego_gramaje= 0.25
peso_pliego= 0.092
demasia_fijo_tirada= 150
demasia_porcentaje_tirada= 2.0
pliegos_por_tirada= 25000.0
colores= 4.0
tinta_kg_tirada= 1.0
barniz_kg_tirada= 1.000
caja_empaque= 200
pallet= 25
troquel= 1
matrices= 100000
q_jornada= 184
q_operario_guillotinista= 1
q_operario_maquinista= 1
q_operario_ayudante= 1
q_operario_ctp= 0
q_operario_troqueladora= 1
q_operario_pegadora= 1
q_operario_packaging= 1
q_admin= 1
q_comercial= 1
q_presupuestista= 1
q_personal_limpieza= 1
q_encargado_logistica= 1
q_gerente_general= 1
q_plotter= 1
q_ctp= 0
q_guillotina= 1
q_impresora= 1
q_troqueladora= 1
q_descartonadora= 0
q_pegadora= 1
q_utilitario= 1
q_computadora_diseño= 1
q_computadora_admin= 6
q_softw_diseno= 1
q_softw_maquetacion= 1
a_plotter= 5
a_ctp= 5
a_guillotina= 20
a_impresora= 20
a_troqueladora= 15
a_descartonadora= 10
a_pegadora= 15
a_utilitario=10
a_computadora_diseño= 3
a_computadora_admin= 5
a_softw_diseno= 3
a_softw_maquetacion= 3
vr_plotter= 0
vr_ctp= 30
vr_guillotina= 40
vr_impresora= 20
vr_troqueladora= 30
vr_descartonadora= 30
vr_pegadora= 40
vr_utilitario= 30
vr_computadora_diseño= 0
vr_computadora_admin= 0
vr_softw_diseno= 0
vr_softw_maquetacion= 0
costo_oportunidad= 4.0
q_energia_potencia= 90.00
q_energia_consumo= 22000
q_energia_potencia_punta= 5
q_energia_potencia_fuerapunta= 19
q_energia_pico= 5
q_energia_valle= 6
q_energia_resto= 13
q_galpon= 600
q_antiguedad= 10.00
q_antiguedad_coef= 1.00
q_prendas= 4.00
q_casco= 2.00
q_guantes= 2.00
q_sac= 8.33
q_vacaciones= 28.00
q_fondo_despido= 4.00
q_ausentismo= 3.00
q_puestos_oficina= 6
q_amortizacion_muebles= 10
plazo_pago_insumos= 30
plazo_cobro= 60
plazo_pago_salarios= 30
mark_up= 10.0
q_ventas_cba= 50.0
q_ventas_pba= 0.0
q_ventas_stafe= 0.0
q_ventas_cuyo= 10.0
q_ventas_mesopotamia= 0.0
q_ventas_noa= 40.0
q_ventas_nequen= 0.0
reinversion_utilidades= 50.0

#MÓDULO 3 - ESTIMACIONES DE COSTOS

# PACKAGING

#Bloque I - Materia Prima

i01_cartulina = ( vm['p_cartulina'] * vm['dolar'] *peso_pliego
            / ratio_estuches_pliego)

i02_cartulina_demasia = ( vm['p_cartulina'] * vm['dolar'] *peso_pliego
            * demasia_fijo_tirada / ratio_estuches_tirada + i01_cartulina
            * demasia_porcentaje_tirada / 100)

i03_tinta = ( vm['p_tinta'] * vm['dolar'] * tinta_kg_tirada * colores
            / ratio_estuches_tirada)

i04_barniz = ( vm['p_barniz'] * vm['dolar'] * barniz_kg_tirada * colores
            / ratio_estuches_tirada)

i05_cajas_empaque = ( vm['p_caja_empaque'] / caja_empaque)

i06_pallets = ( vm['p_pallet'] / pallet / caja_empaque)

i07_troquel = ( vm['p_troquel'] * troquel / q_produccion_mensual_efectiva)

i08_matrices = ( vm['p_matriz'] * vm['dolar'] * colores / matrices
            * pliegos_por_tirada / ratio_estuches_tirada)

i00_materia_prima = ( i01_cartulina + i02_cartulina_demasia + i03_tinta
            + i04_barniz + i05_cajas_empaque + i06_pallets + i07_troquel
            + i08_matrices)

#Bloque II - Costos de Mano de Obra Directa

ii01_remuneracion_operarios = (( q_operario_guillotinista * vm['categoria_08']
            + q_operario_maquinista * vm['categoria_10'] + q_operario_ayudante
            * vm['categoria_07'] + q_operario_ctp * vm['categoria_08']
            + q_operario_troqueladora * vm['categoria_09']
            + q_operario_pegadora * vm['categoria_07'] + q_operario_packaging
            * vm['categoria_05']) / q_produccion_mensual_efectiva)

ii02_remuneracion_operarios_norem = (0)

ii03_horas_extras = (0)

ii04_horas_extras2 = (0)

ii05_antiguedad = ((ii01_remuneracion_operarios + ii03_horas_extras
            + ii04_horas_extras2) * q_antiguedad_coef / 100 *q_antiguedad)

ii06_sac = ((ii01_remuneracion_operarios + ii03_horas_extras
            + ii04_horas_extras2 + ii05_antiguedad) * q_sac / 100)

ii07_vacaciones = ((ii01_remuneracion_operarios
            + ii02_remuneracion_operarios_norem + ii05_antiguedad) / 30
            * q_vacaciones /12)

ii08_contrib_patronales = (((ii01_remuneracion_operarios + ii03_horas_extras
            + ii04_horas_extras2 + ii05_antiguedad + ii06_sac
            + ii07_vacaciones ) - vm['t_cont_patronales_mni']
            * (q_admin + q_comercial + q_presupuestista + q_personal_limpieza
            + q_encargado_logistica + q_gerente_general)
            / q_produccion_mensual_efectiva) * vm['t_cont_patronales_total']
            / 100)

ii09_contrib_patronales_cred_fiscal = - (((ii01_remuneracion_operarios
            + ii03_horas_extras + ii04_horas_extras2 + ii05_antiguedad
            + ii06_sac + ii07_vacaciones ) - vm['t_cont_patronales_mni']
            * (q_admin + q_comercial + q_presupuestista + q_personal_limpieza
            + q_encargado_logistica + q_gerente_general)
            / q_produccion_mensual_efectiva)
            * vm['t_cont_patronales_cred_fisc'] / 100)

ii10_contrib_osocial = ((ii01_remuneracion_operarios + ii03_horas_extras
            + ii04_horas_extras2 + ii05_antiguedad + ii06_sac + ii07_vacaciones)
            * vm['t_cont_osocial'] / 100)

ii11_seguro_vida_obligatorio = ((ii01_remuneracion_operarios
            + ii03_horas_extras + ii04_horas_extras2 + ii05_antiguedad
            + ii06_sac + ii07_vacaciones) * vm['p_seguro_vida_oblig_muebles']
            / 100)

ii12_art = ((ii01_remuneracion_operarios + ii03_horas_extras
            + ii04_horas_extras2 + ii05_antiguedad + ii06_sac + ii07_vacaciones)
            * vm['p_art'] / 100)

ii13_prev_despido = ((ii01_remuneracion_operarios
            + ii02_remuneracion_operarios_norem + ii03_horas_extras
            + ii04_horas_extras2 + ii05_antiguedad + ii06_sac + ii07_vacaciones)
            * q_fondo_despido / 100)

ii14_ausentismo = ((ii01_remuneracion_operarios + ii05_antiguedad + ii06_sac
            + ii07_vacaciones + ii08_contrib_patronales
            + ii09_contrib_patronales_cred_fiscal + ii10_contrib_osocial
            + ii11_seguro_vida_obligatorio + ii12_art + ii13_prev_despido)
            * q_ausentismo / 100)

ii15_aporte_UGA = ((ii01_remuneracion_operarios + ii03_horas_extras
            + ii04_horas_extras2 + ii05_antiguedad + ii06_sac + ii07_vacaciones)
            * vm['aporte_uga'] / 100)

ii16_aporte_AFATIDA = ((ii01_remuneracion_operarios + ii03_horas_extras
            + ii04_horas_extras2 + ii05_antiguedad + ii06_sac + ii07_vacaciones)
            * vm['aporte_afatida'] / 100)

ii00_mano_obra_directa = (ii01_remuneracion_operarios + ii02_remuneracion_operarios_norem
            + ii03_horas_extras + ii04_horas_extras2 + ii05_antiguedad
            + ii06_sac + ii07_vacaciones + ii08_contrib_patronales
            + ii09_contrib_patronales_cred_fiscal + ii10_contrib_osocial
            + ii11_seguro_vida_obligatorio + ii12_art + ii13_prev_despido
            + ii14_ausentismo + ii15_aporte_UGA + ii16_aporte_AFATIDA)

#Bloque III - Costos de Mano de Obra Indirecta

iii01_rem_admin= ( vm['convenio_personal_admin'] * q_admin
            / q_produccion_mensual_efectiva)

iii02_rem_comercial= ( vm['convenio_personal_comercial'] * q_comercial
            / q_produccion_mensual_efectiva)

iii03_rem_presupuetista= ( vm['convenio_presupuetista'] * q_presupuestista
            / q_produccion_mensual_efectiva)

iii04_rem_limpieza= ( vm['convenio_personal_limpieza'] * q_personal_limpieza
            / q_produccion_mensual_efectiva)

iii05_rem_mantenimiento= ( vm['convenio_encargado_logistica']
            * q_encargado_logistica / q_produccion_mensual_efectiva)

iii06_rem_gerente_general = ( vm['convenio_gerente_general']
            * q_gerente_general / q_produccion_mensual_efectiva)

iii07_antiguedad = (( iii01_rem_admin + iii02_rem_comercial
            + iii03_rem_presupuetista + iii04_rem_limpieza
            + iii05_rem_mantenimiento + iii06_rem_gerente_general)
            * q_antiguedad_coef / 100 * q_antiguedad)

iii08_no_rem = ( vm['no_rem'] * ( q_admin + q_comercial + q_presupuestista
            + q_personal_limpieza + q_encargado_logistica + q_gerente_general )
            / q_produccion_mensual_efectiva )

iii09_sac = (( iii01_rem_admin + iii02_rem_comercial + iii03_rem_presupuetista
            + iii04_rem_limpieza + iii05_rem_mantenimiento
            + iii06_rem_gerente_general + iii07_antiguedad) * q_sac / 100)

iii10_vacaciones = (( iii01_rem_admin + iii02_rem_comercial
            + iii03_rem_presupuetista + iii04_rem_limpieza
            + iii05_rem_mantenimiento + iii06_rem_gerente_general
            + iii07_antiguedad) / 30 * q_vacaciones / 12)

iii11_contrib_patronales = ((( iii01_rem_admin + iii02_rem_comercial
            + iii03_rem_presupuetista + iii04_rem_limpieza
            + iii05_rem_mantenimiento + iii06_rem_gerente_general
            + iii07_antiguedad + iii09_sac + iii10_vacaciones)
            - vm['t_cont_patronales_mni'] * (q_admin + q_comercial
            + q_presupuestista + q_personal_limpieza + q_encargado_logistica
            + q_gerente_general) / q_produccion_mensual_efectiva)
            * vm['t_cont_patronales_total'] / 100)

iii12_contrib_patronales_cred_fiscal = - ((( iii01_rem_admin
            + iii02_rem_comercial + iii03_rem_presupuetista
            + iii04_rem_limpieza + iii05_rem_mantenimiento
            + iii06_rem_gerente_general + iii07_antiguedad + iii09_sac
            + iii10_vacaciones) - vm['t_cont_patronales_mni']
            * (q_admin + q_comercial + q_presupuestista + q_personal_limpieza
            + q_encargado_logistica + q_gerente_general)
            / q_produccion_mensual_efectiva) * vm['t_cont_patronales_cred_fisc']
            / 100)

iii13_contrib_osocial = ((iii01_rem_admin + iii02_rem_comercial
            + iii03_rem_presupuetista + iii04_rem_limpieza
            + iii05_rem_mantenimiento + iii06_rem_gerente_general
            + iii07_antiguedad + iii09_sac + iii10_vacaciones)
            * vm['t_cont_osocial'] / 100)

iii14_seguro_vida_obligatorio = (( iii01_rem_admin+ iii02_rem_comercial
            + iii03_rem_presupuetista + iii04_rem_limpieza
            + iii05_rem_mantenimiento + iii06_rem_gerente_general
            + iii07_antiguedad + iii09_sac + iii10_vacaciones)
            * vm['p_seguro_vida_oblig_muebles'] / 100)

iii15_art = (( iii01_rem_admin + iii02_rem_comercial + iii03_rem_presupuetista
            + iii04_rem_limpieza + iii05_rem_mantenimiento
            + iii06_rem_gerente_general + iii07_antiguedad + iii09_sac
            + iii10_vacaciones) * vm['p_art'] / 100)

iii16_prev_despido = (( iii01_rem_admin + iii02_rem_comercial
            + iii03_rem_presupuetista + iii04_rem_limpieza
            + iii05_rem_mantenimiento + iii06_rem_gerente_general
            + iii07_antiguedad + iii09_sac + iii10_vacaciones )
            * q_fondo_despido / 100)

iii17_aporte_UGA = (( iii01_rem_admin + iii02_rem_comercial
            + iii03_rem_presupuetista + iii04_rem_limpieza
            + iii05_rem_mantenimiento + iii06_rem_gerente_general
            + iii07_antiguedad + iii09_sac + iii10_vacaciones )
            * vm['aporte_uga'] / 100)

iii18_aporte_AFATIDA = (( iii01_rem_admin + iii02_rem_comercial
            + iii03_rem_presupuetista + iii04_rem_limpieza
            + iii05_rem_mantenimiento + iii06_rem_gerente_general
            + iii07_antiguedad + iii09_sac + iii10_vacaciones )
            * vm['aporte_afatida'] / 100 )

iii00_mano_obra_indirecta = ( iii01_rem_admin + iii02_rem_comercial + iii03_rem_presupuetista
            + iii04_rem_limpieza + iii05_rem_mantenimiento
            + iii06_rem_gerente_general + iii07_antiguedad + iii08_no_rem
            + iii09_sac + iii10_vacaciones + iii11_contrib_patronales
            + iii12_contrib_patronales_cred_fiscal + iii13_contrib_osocial
            + iii14_seguro_vida_obligatorio + iii15_art + iii16_prev_despido
            + iii17_aporte_UGA  + iii18_aporte_AFATIDA )

#Bloque IV - Costos de Maquinaria

iv01_energia = (( q_energia_potencia * q_energia_potencia_punta
            / ( q_energia_potencia_punta + q_energia_potencia_fuerapunta )
            * vm['p_energia_potencia_punta'] +  q_energia_potencia *
            + q_energia_potencia_fuerapunta / ( q_energia_potencia_punta
            + q_energia_potencia_fuerapunta )
            * vm['p_energia_potencia_fuerapunta'] + q_energia_consumo
            * q_energia_pico / ( q_energia_pico + q_energia_valle
            + q_energia_resto ) * vm['p_energia_pico'] + q_energia_consumo
            * q_energia_valle / ( q_energia_pico + q_energia_valle
            + q_energia_resto ) * vm['p_energia_valle'] + q_energia_consumo
            * q_energia_resto / ( q_energia_pico + q_energia_valle
            + q_energia_resto ) * vm['p_energia_resto'] )
            / q_produccion_mensual_efectiva )

iv02_impuestos_energia = ( iv01_energia * ( vm['t_energia_perc_dgi']
            + vm['t_energia_oim'] + vm['t_energia_dto2298']
            + vm['t_energia_ersep'] + vm['t_energia_ley9819'] ) / 100 )

iv03_reposicion_plotter = ( vm['p_plotter'] * vm['dolar'] * q_plotter * ( 1
            - vr_plotter / 100 ) / a_plotter / 12
            / q_produccion_mensual_efectiva)

iv04_reposicion_ctp = ( vm['p_ctp'] * vm['dolar'] * q_ctp * ( 1 - vr_ctp / 100 )
            / a_ctp / 12 / q_produccion_mensual_efectiva )

iv05_reposicion_guillotina = ( vm['p_guillotina'] * vm['dolar'] * q_guillotina
            * ( 1 - vr_guillotina / 100 ) / a_guillotina / 12
            / q_produccion_mensual_efectiva )

iv06_reposicion_impresora = ( vm['p_impresora'] * vm['dolar'] * q_impresora
            * ( 1 - vr_impresora / 100 ) / a_impresora / 12
            / q_produccion_mensual_efectiva )

iv07_reposicion_troqueladora = ( vm['p_troqueladora'] * vm['dolar']
            * q_troqueladora * ( 1 - vr_troqueladora / 100 ) / a_troqueladora
            / 12 / q_produccion_mensual_efectiva )

iv08_reposicion_descartonadora = ( vm['p_descartonadora'] * vm['dolar']
            * q_descartonadora * ( 1 - vr_descartonadora / 100 )
            / a_descartonadora / 12 / q_produccion_mensual_efectiva )

iv09_reposicion_pegadora =  ( vm['p_pegadora'] * vm['dolar'] * q_pegadora
            * ( 1 - vr_pegadora / 100 ) / a_pegadora / 12
            / q_produccion_mensual_efectiva )

iv10_reposicion_utilitario = ( vm['p_utilitario'] * vm['dolar'] * q_utilitario
            * ( 1 - vr_utilitario / 100 ) / a_utilitario / 12
            / q_produccion_mensual_efectiva )

iv11_repo_computadora_diseno = ( vm['p_computadora_diseño'] * vm['dolar']
            * q_computadora_diseño * ( 1 - vr_computadora_diseño / 100 )
            / a_computadora_diseño / 12 / q_produccion_mensual_efectiva )

iv12_repo_computadora_admin = ( vm['p_computadora_admin'] * vm['dolar']
            * q_computadora_admin * ( 1 - vr_computadora_admin / 100 )
            / a_computadora_admin / 12 / q_produccion_mensual_efectiva )

iv13_repo_softw_diseno = ( vm['p_softw_diseño'] * vm['dolar']
            * q_softw_diseno * ( 1 - vr_softw_diseno / 100 )
            / a_softw_diseno / 12 / q_produccion_mensual_efectiva )

iv14_repo_softw_maquetacion = ( vm['p_softw_maquetacion'] * vm['dolar']
            * q_softw_maquetacion * ( 1 - vr_softw_maquetacion / 100 )
            / a_softw_maquetacion / 12 / q_produccion_mensual_efectiva )

iv15_costo_oportunidad = (( q_plotter * vm['p_plotter'] * vm['dolar']
            * (( 1 - vr_plotter / 100 ) / 2 + vr_plotter / 100 )
            + q_ctp * vm['p_ctp'] * vm['dolar']
            * (( 1 - vr_ctp / 100 ) / 2 + vr_ctp / 100 )
            + q_guillotina * vm['p_guillotina'] * vm['dolar']
            * (( 1 - vr_guillotina / 100 ) / 2 + vr_guillotina / 100 )
            + q_impresora * vm['p_impresora'] * vm['dolar']
            * (( 1 - vr_impresora / 100 ) / 2 + vr_impresora / 100 )
            + q_troqueladora * vm['p_troqueladora'] * vm['dolar']
            * (( 1 - vr_troqueladora / 100 ) / 2 + vr_troqueladora / 100 )
            + q_descartonadora * vm['p_descartonadora'] * vm['dolar']
            * (( 1 - vr_descartonadora / 100 ) / 2 + vr_descartonadora / 100 )
            + q_pegadora * vm['p_pegadora'] * vm['dolar']
            * (( 1 - vr_pegadora / 100 ) / 2 + vr_pegadora / 100 ))
            * costo_oportunidad / 100 / 12 / q_produccion_mensual_efectiva )

iv00_maquinaria = ( iv01_energia + iv02_impuestos_energia
            + iv03_reposicion_plotter + iv04_reposicion_ctp
            + iv05_reposicion_guillotina + iv06_reposicion_impresora
            + iv07_reposicion_troqueladora + iv08_reposicion_descartonadora
            + iv09_reposicion_pegadora + iv10_reposicion_utilitario
            + iv11_repo_computadora_diseno + iv12_repo_computadora_admin
            + iv13_repo_softw_diseno + iv14_repo_softw_maquetacion
            + iv15_costo_oportunidad )

#Bloque V - Costos Fijos no Asociados a la produccion

v01_alquiler = ( q_galpon * vm['p_alquiler_fabricacion'] * vm['dolar']
            / q_produccion_mensual_efectiva )

v02_muebles = ( q_puestos_oficina * ( vm['p_escritorio'] + vm['p_silla'] )
            / q_amortizacion_muebles / 12 / q_produccion_mensual_efectiva )

v03_costo_financiero = ( i00_materia_prima * ( pow( 1 + vm['p_tasa_interes_diaria']
            / 100,( plazo_cobro - plazo_pago_insumos ))) - i00_materia_prima
            + ( ii00_mano_obra_directa + iii00_mano_obra_indirecta )
            * ( pow( 1 + vm['p_tasa_interes_diaria'] / 100,( plazo_cobro
            - plazo_pago_salarios ))) - ( ii00_mano_obra_directa
            + iii00_mano_obra_indirecta ))

v04_estudio_contable = ( vm['p_estudio_contable']
            / q_produccion_mensual_efectiva )

v05_beneficios = (( i00_materia_prima + ii00_mano_obra_directa
            + iii00_mano_obra_indirecta + iv00_maquinaria + v01_alquiler
            + v02_muebles + v03_costo_financiero + v04_estudio_contable)
            * mark_up / 100 )

v00_costos_fijos = ( v01_alquiler + v02_muebles + v03_costo_financiero
            + v04_estudio_contable + v05_beneficios )

# Bloque VI - Costos Impositivos

vi01_impuesto_ingresos_brutos = (( i00_materia_prima + ii00_mano_obra_directa
            + iii00_mano_obra_indirecta + iv00_maquinaria + v00_costos_fijos )
            * ( vm['t_ib_extjuris_pba'] * q_ventas_pba
            + vm['t_ib_extjuris_stafe'] * q_ventas_stafe
            + vm['t_ib_extjuris_mza'] * q_ventas_cuyo
            + vm['t_ib_extjuris_corrientes'] * q_ventas_mesopotamia
            + vm['t_ib_extjuris_salta'] * q_ventas_noa
            + vm['t_ib_extjuris_neuquen'] * q_ventas_nequen ) / 100 / 100 )

vi02_tasa_comercioeindustria = (( i00_materia_prima + ii00_mano_obra_directa
            + iii00_mano_obra_indirecta + iv00_maquinaria + v00_costos_fijos )
            * vm['t_comercioeindustria'] / 100 )

vi03_impuesto_ganancias = ( v05_beneficios * vm['t_ganancias'] / 100
            + v05_beneficios * ( 1 - reinversion_utilidades / 100 )
            * vm['t_dividendos'] / 100 )

vi04_impuesto_cheque = (( i00_materia_prima + ii00_mano_obra_directa
            + iii00_mano_obra_indirecta + iv00_maquinaria
            + v00_costos_fijos + vi01_impuesto_ingresos_brutos
            + vi02_tasa_comercioeindustria + vi03_impuesto_ganancias ) * 1.21
            * (vm['t_cheque'] - vm['t_cheque_cred_fiscal'] ) / 100 )

vi00_impuestos = ( vi01_impuesto_ingresos_brutos + vi02_tasa_comercioeindustria
            + vi03_impuesto_ganancias + vi04_impuesto_cheque )

# Bloque Indicadores de Costo

costo_gabinete_pesos = ( i00_materia_prima + ii00_mano_obra_directa
            + iii00_mano_obra_indirecta + iv00_maquinaria 
            + v00_costos_fijos  + vi00_impuestos )

costo_gabinete_dolares = ( costo_gabinete_pesos / vm['dolar'] )

#CONTROL

print (costo_gabinete_dolares)
