# Programa en Python  -  Sistema Estadistico de Costos Maquinaria Agrícola


# MÓDULO I  -  CARGA DE VARIABLES MONETARIAS

import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import seaborn as sns


# Importar base de datos de series de tiempo con variables monetarias:

vm  =  pd.read_excel('Variables Monetarias Costos Maquinaria Agrícola v02.xlsx')


# Convertir columna mes en variable indexadora temporal:

vm.mes  =  pd.to_datetime(vm.mes)
vm.set_index('mes', inplace = True)       

#COSTOS MAQUINARIA AGRÍCOLA
# MÓDULO II  -  DEFINICION DE PARÁMETROS  -  COSTOS MAQUINARIA AGRÍCOLA

q_cam = 20.00
km_pot = 5000.00
al_tasa_act = 100.00
km_efec = 5000.00
tramo = 627.00
tramo_extraord = 2.00
ITEM423 = 0.00800
ITEM424 = 0.00800
horas_extraord = 1.00
q_control_descarga = 7.97
control_descarga_coef = 4.16667
antig = 6.00
antig_coef = 1.00
q_fuera_residencia = 2.00
vestimenta_prenda = 4.00
vestimenta_casco = 2.00
vestimenta_guantes = 2.00
botiquin = 2.00
seg_vida = 0.03
cont_fed = 2.50
art_coef = 7.00
sac_coef = 8.33
q_vac = 21.00
vac_coef = 7.29
fondo_prev_despido = 4.00
medicina_laboral = 8.00
combustibles_coef = 0.4000
lubricante_motor = 0.001125
lubricante_diferencial = 0.000028
lubricante_caja = 0.000033
neumaticos_nuevos = 0.000062
neumaticos_recapados = 0.000060
filtro_aire = 0.000013
filtro_aceite = 0.000025
filtro_gasoil = 0.000033
trampa_agua = 0.000033
lavado_engrase = 4
amortizacion_porcent = 40.0
amortizacion = 8
reparaciones_repuestos_anual = 6.5
q_personal_admin_primera = 1
q_personal_admin_segunda = 1
q_personal_operativo = 1
q_personal_taller = 1
q_jefe_trafico = 1
q_viaticos_comida = 22
q_viaticos_especial = 26
a_comp = 5
a_muebles = 10
gastos_operativos_porcent = 50.0
costo_oportunidad = 5.0
tasa_beneficio = 10.0
utilidades_distribuidas = 50.0
imp_ganancias_empresariales = 35.0
imp_dividendos = 0.0
imp_cheque = 1.0
ing_brutos_cba = 1.5
ing_brutos_bsas = 1.5
ing_brutos_caba = 3.0
inci_ing_brutos_cba = 50.0
inci_ing_brutos_bsas = 25.0
inci_ing_brutos_caba = 25.0
alic_comercioeind  =  0.60

#Bloque I - Costos Asociados al Personal de Conducción

i01_w_basica = ( vm['w_conductor_primera_cat'] / km_efec )

i02_item423 = ( ITEM423 / 100 * vm['w_conductor_primera_cat'] )

i03_item424 = ( ITEM424 / 100 * vm['w_conductor_primera_cat'] )

i04_rem_ext = ( horas_extraord * tramo_extraord * tramo / km_efec
            * i01_w_basica )

i05_control_descarga = ( control_descarga_coef / 100
            * vm['w_conductor_primera_cat'] * q_control_descarga / km_efec )

i06_antig = ( antig_coef / 100 * antig * vm['w_conductor_primera_cat']
            / km_efec )

i07_fuera_resid_a = ( vm['fuera_residencia_a'] * q_fuera_residencia / km_efec )

i08_fuera_resid_b = ( vm['fuera_residencia_b'] * q_fuera_residencia / km_efec )

i09_sac = (( i01_w_basica + i02_item423 + i04_rem_ext + i06_antig
            + i08_fuera_resid_b ) * sac_coef / 100 )

i10_vac = (( i01_w_basica + i02_item423 + i04_rem_ext + i06_antig
            + i08_fuera_resid_b ) * vac_coef / 100 )

i11_uniforme_seg = (( vm['puniforme'] * vestimenta_prenda + vm['pcasco']
            * vestimenta_casco + vm['pguantes'] * vestimenta_guantes
            + vm['pbotiquin'] * botiquin ) / 12 / km_efec )

i12_cont_pat = (( i01_w_basica + i02_item423 + i04_rem_ext + i06_antig
            + i08_fuera_resid_b + i09_sac + i10_vac - vm['mni_contribuciones']
            / km_efec ) * vm['alic_contribuciones'] / 100 )

i13_cont_pat_iva = -(( i01_w_basica + i02_item423 + i04_rem_ext + i06_antig
            + i08_fuera_resid_b + i09_sac + i10_vac - vm['mni_contribuciones']
            / km_efec ) * vm['cf_contribuciones'] / 100 )

i14_cont_os = (( i01_w_basica + i02_item423 + i04_rem_ext + i06_antig
            + i08_fuera_resid_b + i09_sac + i10_vac )
            * vm['alic_contribuciones_osocial'] / 100 )

i15_seg_vida = (( i01_w_basica + i02_item423 + i04_rem_ext + i06_antig
            + i08_fuera_resid_b + i09_sac + i10_vac ) * seg_vida / 100 )

i16_cont_fed = (( i01_w_basica + i02_item423 + i04_rem_ext + i06_antig
            + i08_fuera_resid_b + i09_sac + i10_vac ) * cont_fed / 100 )

i17_art = (( i01_w_basica + i02_item423 + i04_rem_ext + i06_antig
            + i08_fuera_resid_b + i09_sac + i10_vac ) * art_coef / 100 )

i18_prevision_despido = (( i01_w_basica + i02_item423 + i03_item424
            + i04_rem_ext + i05_control_descarga + i06_antig
            + i07_fuera_resid_a + i08_fuera_resid_b + i09_sac + i10_vac )
            * fondo_prev_despido / 100 )

i19_ausentismo = (( i01_w_basica + i02_item423 + i03_item424
            + i04_rem_ext + i05_control_descarga + i06_antig
            + i07_fuera_resid_a + i08_fuera_resid_b + i09_sac + i10_vac )
            * medicina_laboral / 100 )

i120_fondo_adicional = ( vm['fondo_adicional_escolar'] / 12 / km_efec )

i21_licencia_habilitante = ( vm['licencia_nacional_chofer'] / 12 / km_efec )

i22_piscofisico = ( vm['p_psicofisico_chofer'] / 12 / km_efec )

i00_costos_conduccion = ( i01_w_basica + i02_item423 + i03_item424
            + i04_rem_ext + i05_control_descarga + i06_antig
            + i07_fuera_resid_a + i08_fuera_resid_b + i09_sac + i10_vac
            + i11_uniforme_seg + i12_cont_pat + i13_cont_pat_iva + i14_cont_os
            + i15_seg_vida + i16_cont_fed + i17_art + i18_prevision_despido
            + i19_ausentismo + i120_fondo_adicional + i21_licencia_habilitante
            + i22_piscofisico )

#Bloque II - Costos Variables Asociados al Vehículo

ii01_combustible = ( combustibles_coef * vm['p_gasaoil_surtidor'] )

ii02_combustible_impuesto = ( combustibles_coef * ( vm['p_IGO']
            + vm['imp_combustible_liquido'] - vm['imp_combustible_liquido']
            * vm['imp_combustible_liquido_iva'] / 100
            + vm['imp_dioxido_carbono'] ))

ii03_lubricante_motor = ( lubricante_motor * vm['p_lubricante_motor'] )

ii04_lubricante_diferencial = ( lubricante_diferencial
            * vm['p_lubricante_diferencial'] )

ii05_lubricante_caja = ( lubricante_caja * vm['p_lubricante_caja'] )

ii06_neumaticos_nuevos = ( neumaticos_nuevos * ( vm['p_neumaticos_nuevos_liso']
            * 14 + vm['p_neumaticos_nuevos_taco'] * 4 ) / 18 )

ii07_neumaticos_recapados = ( neumaticos_recapados
            * vm['p_neumaticos_recapados'] )

ii08_filtro_aire = ( filtro_aire * vm['p_filtro_aire'] )

ii09_filtro_aceite = ( filtro_aceite * vm['p_filtro_aceite'] )

ii10_filtro_gasoil = ( filtro_gasoil * vm['p_filtro_gasoil'] )

ii11_trampa_agua = ( trampa_agua * vm['p_trampa_agua'] )

ii12_lavado_engrase = ( lavado_engrase * vm['p_lavado_engrase'] / km_efec )

ii13_peajes = ( vm['p_peajes_bsas_oncativo'] / tramo )

ii00_costos_variables_vehiculo = ( ii01_combustible
            + ii02_combustible_impuesto + ii03_lubricante_motor
            + ii04_lubricante_diferencial + ii05_lubricante_caja
            + ii06_neumaticos_nuevos + ii07_neumaticos_recapados
            + ii08_filtro_aire + ii09_filtro_aceite + ii10_filtro_gasoil
            + ii11_trampa_agua + ii12_lavado_engrase + ii13_peajes )

#Bloque III - Costos Fijos Asociados al Vehículo

iii01_patente = (( vm['p_tractor_volvo'] + vm['p_valor_camion'] )
            * vm['p_patente'] / 100 / 12 / km_efec )

iii02_ruta = ( vm['p_ruta'] / 12 / km_efec )

iii03_inspeccion_tecnica = ( vm['p_inspeccion_tecnica'] / 12 / km_efec )

iii04_rentas = (( vm['p_tractor_volvo'] + vm['p_valor_camion'] )
            * vm['p_rentas_automotor'] / 100 * ( 1 - vm['p_rentas_desc_dia']
            / 100 ) / 12 / km_efec )
                
iii05_seg = ( vm['p_seg'] / 100 * ( vm['p_tractor_volvo']
            + vm['p_valor_camion'] ) / 12 / km_efec )

iii06_reparaciones_repuestos = (( vm['p_tractor_volvo'] + vm['p_valor_camion'] )
            * reparaciones_repuestos_anual / 100 / 12 / km_efec )

iii07_armotiazcion_unidades = (( vm['p_tractor_volvo'] + vm['p_valor_camion'] )
            * ( 1 - amortizacion_porcent / 100 ) / amortizacion / 12 / km_efec )

iii08_interes_cap_invertido = (( vm['p_tractor_volvo'] + vm['p_valor_camion'] )
            * ( amortizacion_porcent + ( 100 - amortizacion_porcent ) / 2 )
            / 100 * costo_oportunidad / 100 / 12 / km_efec )

iii00_costos_fijos_vehiculo = ( iii01_patente + iii02_ruta
            + iii03_inspeccion_tecnica + iii04_rentas + iii05_seg
            + iii06_reparaciones_repuestos + iii07_armotiazcion_unidades
            + iii08_interes_cap_invertido )

#Bloque IV - Costos Fijos No Asociados al Vehículo

iv01_personal_admin = (( vm['w_personal_admin_primera']
            * q_personal_admin_primera + vm['w_personal_admin_segunda']
            * q_personal_admin_segunda ) / q_cam / km_efec )

iv02_personal_operativo = ( vm['w_personal_op_oficial_planchada']
            * q_personal_operativo / q_cam / km_efec )

iv03_personal_taller = ( vm['w_personal_taller_primera']
            * q_personal_taller / q_cam / km_efec )

iv04_jefe_trafico = ( vm['w_jefe_trafico']
            * q_jefe_trafico / q_cam / km_efec )

iv05_viaticos = (( vm['p_viaticos_comida'] * q_viaticos_comida
            * ( q_personal_admin_primera + q_personal_admin_segunda
            + q_personal_operativo + q_personal_taller + q_jefe_trafico )
            + vm['p_viaticos_especial'] * q_viaticos_especial
            * ( q_personal_admin_primera + q_personal_admin_segunda
            + q_personal_operativo + q_personal_taller + q_jefe_trafico ))
            / q_cam / km_efec )

iv06_antig = (( iv01_personal_admin + iv02_personal_operativo
            + iv03_personal_taller + iv04_jefe_trafico ) * antig_coef / 100
            * antig )

iv07_sac = (( iv01_personal_admin + iv02_personal_operativo
            + iv03_personal_taller + iv04_jefe_trafico ) * sac_coef / 100 )

iv08_vac = (( iv01_personal_admin + iv02_personal_operativo
            + iv03_personal_taller + iv04_jefe_trafico ) * vac_coef / 100 )

iv09_cont_pat = (( iv01_personal_admin + iv02_personal_operativo
            + iv03_personal_taller + iv04_jefe_trafico + iv06_antig + iv07_sac
            + iv08_vac - vm['mni_contribuciones'] * ( q_personal_admin_primera
            + q_personal_admin_segunda + q_personal_operativo
            + q_personal_taller + q_jefe_trafico )
            / q_cam / km_efec ) * vm['alic_contribuciones'] / 100 )

iv10_cont_pat_iva = -(( iv01_personal_admin + iv02_personal_operativo
            + iv03_personal_taller + iv04_jefe_trafico + iv06_antig + iv07_sac
            + iv08_vac - vm['mni_contribuciones'] * ( q_personal_admin_primera
            + q_personal_admin_segunda + q_personal_operativo
            + q_personal_taller + q_jefe_trafico )
            / q_cam / km_efec ) * vm['cf_contribuciones'] / 100 )

iv11_cont_os = (( iv01_personal_admin + iv02_personal_operativo
            + iv03_personal_taller + iv04_jefe_trafico + iv06_antig + iv07_sac
            + iv08_vac ) * vm['alic_contribuciones_osocial'] / 100 )

iv12_seg_vida = (( iv01_personal_admin + iv02_personal_operativo
            + iv03_personal_taller + iv04_jefe_trafico + iv06_antig + iv07_sac
            + iv08_vac ) * seg_vida / 100 )

iv13_cont_fed = (( iv01_personal_admin + iv02_personal_operativo
            + iv03_personal_taller + iv04_jefe_trafico + iv06_antig + iv07_sac
            + iv08_vac ) * cont_fed / 100 )

iv14_ART = (( iv01_personal_admin + iv02_personal_operativo
            + iv03_personal_taller + iv04_jefe_trafico + iv06_antig + iv07_sac
            + iv08_vac ) * art_coef / 100 )

iv15_prev_despido = (( iv01_personal_admin + iv02_personal_operativo
            + iv03_personal_taller + iv04_jefe_trafico + iv05_viaticos
            + iv06_antig + iv07_sac + iv08_vac ) * fondo_prev_despido / 100 )

iv16_alquiler = ( vm['palquiler_empresa_transp'] / q_cam / km_efec )

iv17_energia_electrica = ( vm['energia_transporte'] / q_cam / km_efec )

iv18_muebles_utiles = ((( vm['pcomputadora'] / a_comp / 12 )
            * ( q_personal_admin_primera + q_personal_admin_segunda
            + q_personal_operativo + q_personal_taller + q_jefe_trafico )
            + (( vm['pescritorio'] + vm['psilla'] ) / a_muebles / 12 ))
            / q_cam / km_efec )
            
iv19_costos_financieros = ((( i01_w_basica + i02_item423 + i03_item424
            + i04_rem_ext + i05_control_descarga + i06_antig
            + i07_fuera_resid_a + i08_fuera_resid_b ) + ii01_combustible
            + ( iv01_personal_admin + iv02_personal_operativo
            + iv03_personal_taller + iv04_jefe_trafico + iv05_viaticos )
            + ii13_peajes ) * vm['tasa_interes_mens'] / 100
            * gastos_operativos_porcent / 100 )

iv20_estudio_contable = ( vm['pestudio_cont'] / q_cam / km_efec )

iv21_beneficios = (( i00_costos_conduccion + ii00_costos_variables_vehiculo
            + iii00_costos_fijos_vehiculo + ( iv01_personal_admin
            + iv02_personal_operativo + iv03_personal_taller + iv04_jefe_trafico
            + iv05_viaticos + iv06_antig + iv07_sac + iv08_vac + iv09_cont_pat
            + iv10_cont_pat_iva + iv11_cont_os + iv12_seg_vida + iv13_cont_fed
            + iv14_ART + iv15_prev_despido + iv16_alquiler
            + iv17_energia_electrica + iv18_muebles_utiles
            + iv19_costos_financieros + iv20_estudio_contable ))
            * tasa_beneficio / 100 )

iv00_costos_fijos_no_vehiculo = ( iv01_personal_admin + iv02_personal_operativo
            + iv03_personal_taller + iv04_jefe_trafico + iv05_viaticos
            + iv06_antig + iv07_sac + iv08_vac + iv09_cont_pat
            + iv10_cont_pat_iva + iv11_cont_os + iv12_seg_vida + iv13_cont_fed
            + iv14_ART + iv15_prev_despido + iv16_alquiler
            + iv17_energia_electrica + iv18_muebles_utiles
            + iv19_costos_financieros + iv20_estudio_contable + iv21_beneficios )

#Bloque V - Costos Impositivos

v01_imp_ingresos_brutos = (( i00_costos_conduccion
            + ii00_costos_variables_vehiculo + iii00_costos_fijos_vehiculo
            + iv00_costos_fijos_no_vehiculo ) * ( ing_brutos_cba
            * inci_ing_brutos_cba / 100 + ing_brutos_bsas
            * inci_ing_brutos_bsas / 100 + ing_brutos_caba
            * inci_ing_brutos_caba / 100 ) / 100 )

v02_alic_imp_comer_ind = (( i00_costos_conduccion
            + ii00_costos_variables_vehiculo + iii00_costos_fijos_vehiculo
            + iv00_costos_fijos_no_vehiculo ) * alic_comercioeind / 100 )

v03_alic_imp_ganancias = (( iv21_beneficios * imp_ganancias_empresariales / 100)
            + (iv21_beneficios * utilidades_distribuidas / 100 * imp_dividendos
            / 100 ))

v04_alic_imp_cheque = (( i00_costos_conduccion
            + ii00_costos_variables_vehiculo + iii00_costos_fijos_vehiculo
            + iv00_costos_fijos_no_vehiculo +  v01_imp_ingresos_brutos
            + v02_alic_imp_comer_ind + v03_alic_imp_ganancias ) * imp_cheque
            / 100 )

v00_impuestos = ( v01_imp_ingresos_brutos + v02_alic_imp_comer_ind
                  + v03_alic_imp_ganancias + v04_alic_imp_cheque )

# Bloque Indicadores de Costos

costo_transporte_pesos = ( i00_costos_conduccion
            + ii00_costos_variables_vehiculo + iii00_costos_fijos_vehiculo
            + iv00_costos_fijos_no_vehiculo + v00_impuestos )

costo_transporte_dolares = ( costo_transporte_pesos / vm['dolar'] )

#CONTROL

print (costo_transporte_dolares)
       
