# Programa en Python - Sistema Estadistico de Costos industria del Alimento


# MÓDULO I - CARGA DE VARIABLES MONETARIAS

import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import seaborn as sns

# importar base de datos de series de tiempo con variables monetarias:

vm = pd.read_excel('Alimentos variables monetarias v01.xlsx')


# Convertir columna mes en variable indexadora temporal:

vm.mes = pd.to_datetime(vm.mes)
vm.set_index('mes', inplace=True)       


# MÓDULO II - DEFINICION DE PARÁMETROS

prod_por_hora = 400
horas_funcionamiento_dia = 24
dias_funcionamiento = 30
prod_mensual_tn1 = 288
ocupacion = 80
prod_mensual_tn2 = 230
#Materias primas	
q_almidon_maiz = 0.27
q_harina_arroz = 0.27
q_fecula_mandioca = 0.27
q_minors = 0.16
q_micros = 0.03
#Operarios	
q_escuadras = 3
q_amasijo = 1
q_control_horno = 1
q_envasado = 2
q_deposito = 1
q_operador_montacarga = 1
q_operarios = 18
q_delegados_gremiales = 1
q_horas_mensuales = 192
#Mano obra indirecta	
q_jefe_planta = 1
q_lideres_horarios_sin_jefe = 2
q_compas_admin = 1
q_vendedores = 1
q_order_management = 1
q_gerente_general = 1
#Maquinaria	
q_amasadora = 1
q_formadora = 1
q_horno = 1
q_cinta_enfriamiento = 1
q_envasadora = 1
q_detector_metal = 1
q_cerradora_cajas = 1
q_impresora_etiquetas = 1
q_envolvedor_pallets = 1
q_autoelevadores = 1
q_silos_sist_transporte = 1
a_amasadora = 10
a_formadora = 10
a_horno = 10
a_cinta_enfriamiento = 10
a_envasadora = 10
a_detector_metal = 7
a_cerradora_cajas = 10
a_impresora_etiquetas = 10
a_envolvedor_pallets = 10
a_autoelevadores = 10
a_silos_sist_transporte = 10
vr_amasadora = 25
vr_formadora = 40
vr_horno = 40
vr_cinta_enfriamiento = 40
vr_envasadora = 40
vr_detector_metal = 15
vr_cerradora_cajas = 30
vr_impresora_etiquetas = 30
vr_envolvedor_pallets = 30
vr_autoelevadores = 30
vr_silos_sist_transporte = 30
costo_oportunidad = 4.0
mantenim_general = 12
limpieza = 24
potencia_contratada = 100.00
consumo_energia = 1000
horas_pico_pot = 5
horas_no_pico_pot = 19
horas_pico_consumo = 5
horas_valle_consumo = 6
horas_resto_consumo = 13
galpon = 500
antig = 10.00
antig_coef = 1.00
sac_coef = 8.33
vac = 28.00
fondo_prev = 4.00
ausentismo = 7.50
q_comp = 7.00
a_comp = 5
a_muebles = 10
plazo_pago = 60
plazo_cobro = 90
plazo_pago_salarios = 30
mark_up = 10.0
vtas_cba = 40.0
vtas_bsas = 30.0
vtas_stafe = 30.0
reinversion_ganancias = 50.0


#MÓDULO 3 - ESTIMACIONES DE COSTOS

#Bloque I - Materia Prima

i01_almidon_maiz = ( q_almidon_maiz * vm['p_almidon_maiz'] * vm['dolar'] )

i02_harina_arroz = ( q_harina_arroz * vm['p_harina_arroz'] * vm['dolar'] )

i03_fecula_mandioca = ( q_fecula_mandioca * vm['p_fecula_mandioca'] * vm['dolar'] )

i04_minors = ( q_minors * vm['p_minors'] * vm['dolar'] )

i05_micros = ( q_micros * vm['p_micros'] * vm['dolar'] )

i00_materia_prima = ( i01_almidon_maiz + i02_harina_arroz + i03_fecula_mandioca
            + i04_minors + i05_micros )

#Bloque II - Mano de Obra Directa

ii01_rem_operarios = (( q_amasijo * vm['p_especializades_maestro']
            + q_control_horno * vm['p_especializades_oficial']
            + q_envasado * vm['p_especializades_ayudante']
            + q_deposito * vm['p_especializades_ayudante'] )
            * q_escuadras / prod_mensual_tn2 / 1000 )

ii02_rem_operarios_norem = (0)

ii03_horas_extra15 = (0)

ii04_horas_extra2 = (0)

ii05_antig = (( ii01_rem_operarios + ii03_horas_extra15 + ii04_horas_extra2 )
            * antig_coef / 100 * antig )

ii06_sac= (( ii01_rem_operarios + ii03_horas_extra15 + ii04_horas_extra2
            + ii05_antig ) * sac_coef / 100 )

ii07_vac = (( ii01_rem_operarios + ii02_rem_operarios_norem + ii05_antig )
            / 30 * vac / 12 )

ii08_cont_pat = ((( ii01_rem_operarios + ii03_horas_extra15 + ii04_horas_extra2
            + ii05_antig + ii06_sac + ii07_vac ) - vm['contribuciones_mni']
            * ( q_operarios + q_delegados_gremiales ) / prod_mensual_tn2 )
            * vm['contribuciones_alic'] / 100 )

ii09_cont_pat_iva = (-(( ii01_rem_operarios + ii03_horas_extra15 + ii04_horas_extra2
            + ii05_antig + ii06_sac + ii07_vac ) - vm['contribuciones_mni']
            * ( q_operarios + q_delegados_gremiales ) / prod_mensual_tn2 )
            * vm['contribuciones_ctaiva_alic'] / 100 )

ii10_cont_os = (( ii01_rem_operarios + ii03_horas_extra15 + ii04_horas_extra2
            + ii05_antig + ii06_sac + ii07_vac ) * vm['contrib_obrasocial_alic']
            / 100 )
                
ii11_seg_vida = (( ii01_rem_operarios + ii03_horas_extra15 + ii04_horas_extra2
            + ii05_antig + ii06_sac + ii07_vac )
            * vm['seguro_vida_obligat_alic'] / 100 )

ii12_art = (( ii01_rem_operarios + ii03_horas_extra15 + ii04_horas_extra2
            + ii05_antig + ii06_sac + ii07_vac ) * vm['art_alic'] / 100 )

ii13_prev_despido = ((ii01_rem_operarios + ii02_rem_operarios_norem
            + ii03_horas_extra15 + ii04_horas_extra2 + ii05_antig + ii06_sac
            + ii07_vac ) * fondo_prev / 100 )

ii14_ausentismo = (( ii01_rem_operarios + ii05_antig + ii06_sac
            + ii07_vac + ii08_cont_pat + ii09_cont_pat_iva + ii10_cont_os
            + ii11_seg_vida + ii12_art + ii13_prev_despido ) * ausentismo
            / 100 )

ii00_mano_obra_directa = ( ii01_rem_operarios + ii02_rem_operarios_norem
            + ii03_horas_extra15 + ii04_horas_extra2 + ii05_antig + ii06_sac
            + ii07_vac + ii08_cont_pat + ii09_cont_pat_iva + ii10_cont_os
            + ii11_seg_vida + ii12_art + ii13_prev_despido + ii14_ausentismo )

#Bloque III - Mano de Obra Indirecta

iii01_rem_jefe_planta = ( q_jefe_planta * vm['p_jefe_planta']
            / prod_mensual_tn2 / 1000 )

iii02_rem_lideres = ( q_lideres_horarios_sin_jefe * vm['p_lider']
            / prod_mensual_tn2 / 1000 )

iii03_rem_compras_admin = ( q_compas_admin * vm['p_compras_admin']
            / prod_mensual_tn2 / 1000 )

iii04_vendedores = ( q_vendedores * vm['p_vendedor']
            / prod_mensual_tn2 / 1000 )

iii05_order_management = ( q_order_management * vm['p_order_management']
            / prod_mensual_tn2 / 1000 )

iii06_gerente_general = ( q_gerente_general * vm['p_gerente_general']
            / prod_mensual_tn2 / 1000 )

iii07_antig = (( iii01_rem_jefe_planta + iii02_rem_lideres
            + iii03_rem_compras_admin + iii04_vendedores
            + iii05_order_management + iii06_gerente_general )
            * antig_coef / 100 * antig )

iii08_sac = (( iii01_rem_jefe_planta + iii02_rem_lideres
            + iii03_rem_compras_admin + iii04_vendedores
            + iii05_order_management + iii06_gerente_general + iii07_antig )
            * sac_coef / 100 )
             
iii09_vac = (( iii01_rem_jefe_planta + iii02_rem_lideres
            + iii03_rem_compras_admin + iii04_vendedores
            + iii05_order_management + iii06_gerente_general + iii07_antig )
            / 30 * vac / 12 )

iii10_cont_pat = ((( iii01_rem_jefe_planta + iii02_rem_lideres
            + iii03_rem_compras_admin + iii04_vendedores
            + iii05_order_management + iii06_gerente_general + iii07_antig
            + iii08_sac + iii09_vac ) - vm['contribuciones_mni']
            * ( q_jefe_planta + q_lideres_horarios_sin_jefe + q_compas_admin
            + q_vendedores + q_order_management + q_gerente_general )
            / prod_mensual_tn2 ) * vm['contribuciones_alic'] / 100 )

iii11_cont_pat_iva = (-(( iii01_rem_jefe_planta + iii02_rem_lideres
            + iii03_rem_compras_admin + iii04_vendedores
            + iii05_order_management + iii06_gerente_general + iii07_antig
            + iii08_sac + iii09_vac ) - vm['contribuciones_mni']
            * ( q_jefe_planta + q_lideres_horarios_sin_jefe + q_compas_admin
            + q_vendedores + q_order_management + q_gerente_general )
            / prod_mensual_tn2 ) * vm['contribuciones_ctaiva_alic'] / 100 )

iii12_cont_os = (( iii01_rem_jefe_planta + iii02_rem_lideres
            + iii03_rem_compras_admin + iii04_vendedores
            + iii05_order_management + iii06_gerente_general + iii07_antig
            + iii08_sac + iii09_vac ) * vm['contrib_obrasocial_alic'] / 100 )

iii13_seg_vida = (( iii01_rem_jefe_planta + iii02_rem_lideres
            + iii03_rem_compras_admin + iii04_vendedores
            + iii05_order_management + iii06_gerente_general + iii07_antig
            + iii08_sac + iii09_vac ) * vm['seguro_vida_obligat_alic'] / 100 )

iii14_art = (( iii01_rem_jefe_planta + iii02_rem_lideres
            + iii03_rem_compras_admin + iii04_vendedores
            + iii05_order_management + iii06_gerente_general + iii07_antig
            + iii08_sac + iii09_vac ) * vm['art_alic'] / 100 )

iii15_prev_despido = (( iii01_rem_jefe_planta + iii02_rem_lideres
            + iii03_rem_compras_admin + iii04_vendedores
            + iii05_order_management + iii06_gerente_general + iii07_antig
            + iii08_sac + iii09_vac ) * fondo_prev / 100 )

iii00_mano_obra_indirecta = ( iii01_rem_jefe_planta + iii02_rem_lideres
            + iii03_rem_compras_admin + iii04_vendedores
            + iii05_order_management + iii06_gerente_general + iii07_antig
            + iii08_sac + iii09_vac + iii10_cont_pat + iii11_cont_pat_iva
            + iii12_cont_os + iii13_seg_vida + iii14_art + iii15_prev_despido )

#Bloque IV - Maquinaria

iv01_energia = (( potencia_contratada * vm['penergia_potencia_punta']
            + consumo_energia * vm['penergia_pico'] ) / prod_mensual_tn2 / 1000)

iv02_imp_tasas_energia = ( iv01_energia * ( vm['penergia_oim']
            + vm['penergia_dto2298'] + vm['penergia_ersep']
            + vm['penergia_ley9819'] ) / 100 )

iv03_rep_amasadora = ( q_amasadora * vm['p_amasadora'] * vm['dolar']
            * ( 1 - vr_amasadora / 100 ) / a_amasadora / 12 / prod_mensual_tn2
            / 1000 )

iv04_rep_formadora = ( q_formadora * vm['p_formadora'] * vm['dolar']
            * ( 1 - vr_formadora / 100 ) / a_formadora / 12 / prod_mensual_tn2
            / 1000 )

iv05_horno = ( q_horno * vm['p_horno'] * vm['dolar']
            * ( 1 - vr_horno / 100 ) / a_horno / 12 / prod_mensual_tn2
            / 1000 )

iv06_rep_cinta_enfriamiento = ( q_cinta_enfriamiento
            * vm['p_cinta_enfriamiento'] * vm['dolar']
            * ( 1 - vr_cinta_enfriamiento / 100 ) / a_cinta_enfriamiento
            / 12 / prod_mensual_tn2 / 1000 )

iv07_rep_envasadora = ( q_envasadora * vm['p_envasadora'] * vm['dolar']
            * ( 1 - vr_envasadora / 100 ) / a_envasadora / 12 / prod_mensual_tn2
            / 1000 )

iv08_rep_detector_metal = ( q_detector_metal * vm['p_detector_metal']
            * vm['dolar'] * ( 1 - vr_detector_metal / 100 )
            / a_detector_metal / 12 / prod_mensual_tn2 / 1000 )

iv09_rep_cerradora_cajas = ( q_cerradora_cajas * vm['p_cerradora_cajas']
            * vm['dolar'] * ( 1 - vr_cerradora_cajas / 100 )
            / a_cerradora_cajas / 12 / prod_mensual_tn2 / 1000 )

iv10_rep_impresora_etiquetas = ( q_impresora_etiquetas
            * vm['p_impresora_etiquetas'] * vm['dolar']
            * ( 1 - vr_impresora_etiquetas / 100 ) / a_impresora_etiquetas
            / 12 / prod_mensual_tn2 / 1000 )

iv11_rep_envolvedor_pallets = ( q_envolvedor_pallets
            * vm['p_envolvedor_pallets'] * vm['dolar']
            * ( 1 - vr_envolvedor_pallets / 100 )
            / a_envolvedor_pallets / 12 / prod_mensual_tn2 / 1000 )

iv12_rep_autoelevadores = ( q_autoelevadores * vm['p_autoelevador']
            * vm['dolar'] * ( 1 - vr_autoelevadores / 100 )
            / a_autoelevadores / 12 / prod_mensual_tn2 / 1000 )

iv13_rep_silos_sist_transporte = ( q_silos_sist_transporte
            * vm['p_silos_sist_transporte'] * vm['dolar']
            * ( 1 - vr_silos_sist_transporte / 100 )
            / a_silos_sist_transporte / 12 / prod_mensual_tn2 / 1000 )

iv14_costo_oportunidad = (( q_amasadora * vm['p_amasadora'] * vm['dolar']
            * (( 1 - vr_amasadora / 100 ) / 2 + vr_amasadora / 100 )
            + q_formadora * vm['p_formadora'] * vm['dolar']
            * (( 1 - vr_formadora / 100 ) / 2 + vr_formadora / 100 )
            + q_horno * vm['p_horno'] * vm['dolar']
            * (( 1 - vr_horno / 100 ) / 2 + vr_horno / 100 )
            + q_cinta_enfriamiento * vm['p_cinta_enfriamiento'] * vm['dolar']
            * (( 1 - vr_cinta_enfriamiento / 100 ) / 2 + vr_cinta_enfriamiento / 100 )
            + q_envasadora * vm['p_envasadora'] * vm['dolar']
            * (( 1 - vr_envasadora / 100 ) / 2 + vr_envasadora / 100 )
            + q_detector_metal * vm['p_detector_metal'] * vm['dolar']
            * (( 1 - vr_detector_metal / 100 ) / 2 + vr_detector_metal / 100 )
            + q_cerradora_cajas * vm['p_cerradora_cajas'] * vm['dolar']
            * (( 1 - vr_cerradora_cajas / 100 ) / 2 + vr_cerradora_cajas / 100 )
            + q_impresora_etiquetas * vm['p_impresora_etiquetas'] * vm['dolar']
            * (( 1 - vr_impresora_etiquetas / 100 ) / 2 + vr_impresora_etiquetas / 100 )
            + q_envolvedor_pallets * vm['p_envolvedor_pallets'] * vm['dolar']
            * (( 1 - vr_envolvedor_pallets / 100 ) / 2 + vr_envolvedor_pallets / 100 )
            + q_autoelevadores * vm['p_autoelevador'] * vm['dolar']
            * (( 1 - vr_autoelevadores / 100 ) / 2 + vr_autoelevadores / 100 )
            + q_silos_sist_transporte * vm['p_silos_sist_transporte'] * vm['dolar']
            * (( 1 - vr_silos_sist_transporte / 100 ) / 2 + vr_silos_sist_transporte / 100 ))
            * costo_oportunidad / 100 / prod_mensual_tn2 / 1000 )             

iv00_maquinaria = ( iv01_energia + iv02_imp_tasas_energia + iv03_rep_amasadora
            + iv04_rep_formadora + iv05_horno + iv06_rep_cinta_enfriamiento
            + iv07_rep_envasadora + iv08_rep_detector_metal
            + iv09_rep_cerradora_cajas + iv10_rep_impresora_etiquetas
            + iv11_rep_envolvedor_pallets + iv12_rep_autoelevadores
            + iv13_rep_silos_sist_transporte + iv14_costo_oportunidad )

#Bloque V - Costos Fijos No Asociados a la Producción

v01_alquiler = ( vm['palquiler'] * vm['dolar'] * galpon / prod_mensual_tn2
            / 1000 )

v02_muebles_utiles = (( vm['pcomputadora'] / a_comp + vm['pescritorio']
            / a_muebles + vm['psilla'] / a_muebles ) * q_comp / 12
            / prod_mensual_tn2 / 1000 )

v03_mantenim = ( mantenim_general * vm['p_especializades_peon'] * 2
            / prod_mensual_tn2 / 1000 )

v04_limpieza = ( limpieza * vm['sal_operario_general']* 2
            / prod_mensual_tn2 / 1000 )

v05_seguros = ( vm['pseguro_incendio'] / 12 / prod_mensual_tn2 / 1000 )

v06_costos_financieros = (( i00_materia_prima * 1.21 * ( pow ( 1 + vm['tasa_interes_mensual']
            / 100,( plazo_cobro - plazo_pago ) / 30 ))
            + ( ii00_mano_obra_directa + iii00_mano_obra_indirecta )
            * ( pow ( 1 + vm['tasa_interes_mensual'] / 100,( plazo_cobro
            - plazo_pago_salarios ) / 30 )) - i00_materia_prima * 1.21
            - ( ii00_mano_obra_directa + iii00_mano_obra_indirecta )))
                                                        
v07_estudio_contable = ( vm['pestudio_contable'] / prod_mensual_tn2 / 1000 )

v08_beneficios = (( i00_materia_prima + ii00_mano_obra_directa
            + iii00_mano_obra_indirecta + iv00_maquinaria + v01_alquiler
            + v02_muebles_utiles + v03_mantenim + v04_limpieza + v05_seguros
            + v06_costos_financieros + v07_estudio_contable )
            * mark_up / 100 )

v00_costos_fijos_no_prod = ( v01_alquiler + v02_muebles_utiles + v03_mantenim
            + v04_limpieza + v05_seguros + v06_costos_financieros
            + v07_estudio_contable + v08_beneficios )

#Bloque VI - Costos Impositivos

vi01_ingresos_brutos = (( i00_materia_prima + ii00_mano_obra_directa
            + iii00_mano_obra_indirecta + iv00_maquinaria
            + v00_costos_fijos_no_prod ) * (( vm['ib_cordoba_alic'] * vtas_cba / 100
            + vm['ib_buenosaires_extjuris_alic'] * vtas_bsas / 100
            + vm['ib_santfe_extjuris_alic'] * vtas_stafe / 100 )) / 100 )

vi02_comercioeindustria = (( i00_materia_prima + ii00_mano_obra_directa
            + iii00_mano_obra_indirecta + iv00_maquinaria
            + v00_costos_fijos_no_prod ) * vm['tasa_comeind_alic'] / 100 )

vi03_imp_ganancias = (( v08_beneficios + iv14_costo_oportunidad )
            * vm['impgcias_benef_alic'] / 100 + ( v08_beneficios
            + iv14_costo_oportunidad ) * ( 100 - reinversion_ganancias )
            / 100 * vm['impgcias_benef_dist_alic'] / 100 )

vi04_imp_cheque = (( i00_materia_prima + ii00_mano_obra_directa
            + iii00_mano_obra_indirecta + iv00_maquinaria
            + v00_costos_fijos_no_prod ) * 1.21 * ( vm['impcheque_alic']
            + vm['impcheque_ctagcias_alic'] ) / 100 )

vi00_impositivos = ( vi01_ingresos_brutos + vi02_comercioeindustria
            + vi03_imp_ganancias + vi04_imp_cheque )

#Bloque Indicadores de Costo

costo_kg_pesos = ( i00_materia_prima + ii00_mano_obra_directa
            + iii00_mano_obra_indirecta + iv00_maquinaria
            + v00_costos_fijos_no_prod + vi00_impositivos )

costo_kg_dolares = ( costo_kg_pesos / vm['dolar'] )

# CONTROL

print (ii08_cont_pat)
