# Programa en Python - Sistema Estadistico de Costos industria del Alimento


# MÓDULO I - CARGA DE VARIABLES MONETARIAS

import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import seaborn as sns

# importar base de datos de series de tiempo con variables monetarias:

vm = pd.read_excel('Alimentos variables monetarias v01.xlsx')


# Convertir columna mes en variable indexadora temporal:

vm.mes = pd.to_datetime(vm.mes)
vm.set_index('mes', inplace=True)       


# MÓDULO II - DEFINICION DE PARÁMETROS

prod_mensual = 15000
capacidad = 80
prod_mensual2 = 12000
clientes = 1000
#Materias primas	
cafe_crudo = 1.00
merma = 30.00
bobinas_papel = 90.00
tinta_fecha = 1.00
#Operarios	
q_op_tostadora = 2
q_op_envasadora = 2
q_operarios = 4
q_delegados_gremiales = 0
q_horas_mensuales = 192
presentismo = 3
polivalencia = 3
#Mano de obra indirecta	
q_supervisores = 1
q_vendedores_ciudad = 4
q_vendedores_provincia = 5
q_vendedores_otras_provincias = 7
q_administrativos = 2
q_gerente_general = 1
q_clientes_por_vendedor_ciudad = 120
q_clientes_por_vendedor_prov = 60
q_clientes_por_vendedor_otra_prov = 30
#Maquinaria	
q_tostadora = 1
q_envasadora = 1
q_autoelevador = 1
q_maquina_cafeymolino = 1000
q_utilitario_vta_prov = 1
q_utilitario_vta_fuera_prov = 1
a_tostadora = 20
a_envasadora = 10
a_autoelevador = 5
a_maquina_cafeymolino = 6
a_utilitario_vta_prov = 5
a_utilitario_vta_fuera_prov = 5
vr_tostadora = 10
vr_envasadora = 30
vr_autoelevador = 30
vr_maquina_cafeymolino = 0
vr_utilitario_vta_prov = 20
vr_utilitario_vta_fuera_prov = 20
km_utilitario_mes = 4000
litros_por_km = 0.1
costo_oportunidad = 4.0
mantenim_general = 12
limpieza = 24
potencia_contratada = 100.00
consumo_energia = 1500
horas_pico_pot = 5
horas_no_pico_pot = 19
horas_pico_consumo = 5
horas_valle_consumo = 6
horas_resto_consumo = 13
consumo_gas = 1200
galpon = 2500
antig = 15.00
antig_coef = 1.00
sac_coef = 8.33
vac = 35.00
fondo_prev = 4.00
ausentismo = 5.00
q_comp = 20.00
a_comp = 5
a_muebles = 10
plazo_pago = 0
plazo_cobro = 42
plazo_pago_salarios = 60
mark_up = 5.0
comisiones_vendedores_cba = 3.5
comisiones_vendedores_fueracba = 5.0
vtas_cba = 50.0
vtas_bsas = 30.0
vtas_stafe = 20.0
reinversion_ganancias = 50.0


#MÓDULO 3 - ESTIMACIONES DE COSTOS

#Bloque I - Materia Prima

i01_cafe_crudo = ( cafe_crudo * ( 1 + merma / 100 ) * vm['p_cafe_crudo1kg']
            * vm['dolar'] )

i02_bobinas_papel = ( 1 / bobinas_papel * vm['p_bobina_papel'] * vm['dolar'] )

i03_tinta_fecha = ( tinta_fecha / 12000 * vm['p_tinta_fecha'] * vm['dolar'] )

i00_materia_prima = ( i01_cafe_crudo + i02_bobinas_papel + i03_tinta_fecha )

#Bloque II - Mano de Obra Directa

ii01_rem_operarios = (( q_operarios + q_delegados_gremiales )
            * vm['sal_oficial_calificado'] * q_horas_mensuales * ( 1
            + ( presentismo + polivalencia ) / 100 ) / prod_mensual2 )

ii02_rem_operarios_norem = (0)

ii03_horas_extra15 = (0)

ii04_horas_extra2 = (0)

ii05_antig = (( ii01_rem_operarios + ii03_horas_extra15 + ii04_horas_extra2 )
            * antig_coef / 100 * antig )

ii06_sac= (( ii01_rem_operarios + ii03_horas_extra15 + ii04_horas_extra2
            + ii05_antig ) * sac_coef / 100 )

ii07_vac = (( ii01_rem_operarios + ii02_rem_operarios_norem + ii05_antig )
            / 30 * vac / 12 )

ii08_cont_pat = (( ii01_rem_operarios + ii03_horas_extra15 + ii04_horas_extra2
            + ii05_antig + ii06_sac + ii07_vac - vm['contribuciones_mni']
            * ( q_operarios + q_delegados_gremiales ) / prod_mensual2 )
            * vm['contribuciones_alic'] / 100 )

ii09_cont_pat_iva = (-( ii01_rem_operarios + ii03_horas_extra15 + ii04_horas_extra2
            + ii05_antig + ii06_sac + ii07_vac - vm['contribuciones_mni']
            * ( q_operarios + q_delegados_gremiales ) / prod_mensual2 )
            * vm['contribuciones_ctaiva_alic'] / 100 )

ii10_cont_os = (( ii01_rem_operarios + ii03_horas_extra15 + ii04_horas_extra2
            + ii05_antig + ii06_sac + ii07_vac ) * vm['contrib_obrasocial_alic']
            / 100 )
                
ii11_seg_vida = (( ii01_rem_operarios + ii03_horas_extra15 + ii04_horas_extra2
            + ii05_antig + ii06_sac + ii07_vac )
            * vm['seguro_vida_obligat_alic'] / 100 )

ii12_art = (( ii01_rem_operarios + ii03_horas_extra15 + ii04_horas_extra2
            + ii05_antig + ii06_sac + ii07_vac ) * vm['art_alic'] / 100 )

ii13_prev_despido = ((ii01_rem_operarios + ii02_rem_operarios_norem
            + ii03_horas_extra15 + ii04_horas_extra2 + ii05_antig + ii06_sac
            + ii07_vac ) * fondo_prev / 100 )

ii14_ausentismo = (( ii01_rem_operarios + ii05_antig + ii06_sac
            + ii07_vac + ii08_cont_pat + ii09_cont_pat_iva + ii10_cont_os
            + ii11_seg_vida + ii12_art + ii13_prev_despido ) * ausentismo
            / 100 )

ii00_mano_obra_directa = ( ii01_rem_operarios + ii02_rem_operarios_norem
            + ii03_horas_extra15 + ii04_horas_extra2 + ii05_antig + ii06_sac
            + ii07_vac + ii08_cont_pat + ii09_cont_pat_iva + ii10_cont_os
            + ii11_seg_vida + ii12_art + ii13_prev_despido + ii14_ausentismo )

#Bloque III - Mano de Obra Indirecta

iii01_rem_supervisores = ( q_supervisores * vm['rem_adminIII']
            / prod_mensual2 )

iii02_rem_vendedores_ciudad = ( q_vendedores_ciudad * vm['rem_adminIII']
            / prod_mensual2 )

iii03_rem_vendedores_provincia = ( q_vendedores_provincia
            * vm['rem_adminIII'] / prod_mensual2 )

iii04_rem_vendedores_otras_prov = ( q_vendedores_otras_provincias
            * vm['rem_adminIII'] / prod_mensual2 )

iii05_administrativos = ( q_administrativos * vm['rem_adminIII']
            / prod_mensual2 )

iii06_gerente_general = ( q_gerente_general * vm['rem_gerente_general']
            / prod_mensual2 )

iii07_antig = (( iii01_rem_supervisores + iii02_rem_vendedores_ciudad
            + iii03_rem_vendedores_provincia + iii04_rem_vendedores_otras_prov
            + iii05_administrativos + iii06_gerente_general )
            * antig_coef / 100 * antig )

iii08_sac = (( iii01_rem_supervisores + iii02_rem_vendedores_ciudad
            + iii03_rem_vendedores_provincia + iii04_rem_vendedores_otras_prov
            + iii05_administrativos + iii06_gerente_general + iii07_antig )
            * sac_coef / 100 )
             
iii09_vac = (( iii01_rem_supervisores + iii02_rem_vendedores_ciudad
            + iii03_rem_vendedores_provincia + iii04_rem_vendedores_otras_prov
            + iii05_administrativos + iii06_gerente_general + iii07_antig )
            / 30 * vac / 12 )

iii10_cont_pat = ((( iii01_rem_supervisores + iii02_rem_vendedores_ciudad
            + iii03_rem_vendedores_provincia + iii04_rem_vendedores_otras_prov
            + iii05_administrativos + iii06_gerente_general + iii07_antig
            + iii08_sac + iii09_vac ) - vm['contribuciones_mni']
            * ( q_supervisores + q_vendedores_ciudad + q_vendedores_provincia
            + q_vendedores_otras_provincias + q_administrativos
            + q_gerente_general ) / prod_mensual2 )
            * vm['contribuciones_alic'] / 100 )

iii11_cont_pat_iva = (-(( iii01_rem_supervisores + iii02_rem_vendedores_ciudad
            + iii03_rem_vendedores_provincia + iii04_rem_vendedores_otras_prov
            + iii05_administrativos + iii06_gerente_general + iii07_antig
            + iii08_sac + iii09_vac ) - vm['contribuciones_mni']
            * ( q_supervisores + q_vendedores_ciudad + q_vendedores_provincia
            + q_vendedores_otras_provincias + q_administrativos
            + q_gerente_general )
            / prod_mensual2 ) * vm['contribuciones_ctaiva_alic'] / 100 )

iii12_cont_os = (( iii01_rem_supervisores + iii02_rem_vendedores_ciudad
            + iii03_rem_vendedores_provincia + iii04_rem_vendedores_otras_prov
            + iii05_administrativos + iii06_gerente_general + iii07_antig
            + iii08_sac + iii09_vac ) * vm['contrib_obrasocial_alic'] / 100 )

iii13_seg_vida = (( iii01_rem_supervisores + iii02_rem_vendedores_ciudad
            + iii03_rem_vendedores_provincia + iii04_rem_vendedores_otras_prov
            + iii05_administrativos + iii06_gerente_general + iii07_antig
            + iii08_sac + iii09_vac ) * vm['seguro_vida_obligat_alic'] / 100 )

iii14_art = (( iii01_rem_supervisores + iii02_rem_vendedores_ciudad
            + iii03_rem_vendedores_provincia + iii04_rem_vendedores_otras_prov
            + iii05_administrativos + iii06_gerente_general + iii07_antig
            + iii08_sac + iii09_vac ) * vm['art_alic'] / 100 )

iii15_prev_despido = (( iii01_rem_supervisores + iii02_rem_vendedores_ciudad
            + iii03_rem_vendedores_provincia + iii04_rem_vendedores_otras_prov
            + iii05_administrativos + iii06_gerente_general + iii07_antig
            + iii08_sac + iii09_vac ) * fondo_prev / 100 )

iii00_mano_obra_indirecta = ( iii01_rem_supervisores + iii02_rem_vendedores_ciudad
            + iii03_rem_vendedores_provincia + iii04_rem_vendedores_otras_prov
            + iii05_administrativos + iii06_gerente_general + iii07_antig
            + iii08_sac + iii09_vac + iii10_cont_pat + iii11_cont_pat_iva
            + iii12_cont_os + iii13_seg_vida + iii14_art + iii15_prev_despido )

#Bloque IV - Maquinaria

iv01_energia = (( potencia_contratada * vm['penergia_potencia_punta']
            + consumo_energia * vm['penergia_pico'] ) / prod_mensual2 )

iv02_imp_tasas_energia = ( iv01_energia * ( vm['penergia_oim']
            + vm['penergia_dto2298'] + vm['penergia_ersep']
            + vm['penergia_ley9819'] ) / 100 )

iv03_gas_nat = ( consumo_gas * vm['gas_bocapozo'] / 1000 * vm['dolar']
            / prod_mensual2 + consumo_gas * vm['gas_cargo_transporte']
            * vm['dolar'] / prod_mensual2 )

iv04_imp_tasas_gas = ( consumo_gas * vm['gas_cargo_transporte'] * vm['dolar']
            * ( vm['gas_comeind'] + vm['gas_ley25413']
            + vm['gas_ingresosbrutos_transp'] + vm['gas_oim']
            + vm['gas_fideicomiso_n1'] + vm['gas_fideicomiso_n2'] ) / 100
            / prod_mensual2 )

iv05_rep_tostadora = ( q_tostadora * vm['p_tostadora'] * vm['dolar']
            * ( 1 - vr_tostadora / 100 ) / a_tostadora / 12 / prod_mensual2 )
                
iv06_rep_envasadora = ( q_envasadora * vm['p_envasadora_tostadero']
            * vm['dolar'] * ( 1 - vr_envasadora / 100 ) / a_envasadora / 12
            / prod_mensual2 )

iv07_rep_autoelevador = ( q_autoelevador * vm['p_autoelevador_tostadero']
            * vm['dolar'] * ( 1 - vr_autoelevador / 100 ) / a_autoelevador
            / 12 / prod_mensual2 )

iv08_rep_maquina_cafeymolino = ( q_maquina_cafeymolino
            * vm['p_maquina_cafeymolino'] * vm['dolar']
            * ( 1 - vr_maquina_cafeymolino / 100 ) / a_maquina_cafeymolino
            / 12 / prod_mensual2 )

iv09_rep_utilitarios = ( q_utilitario_vta_prov * vm['p_utilitario_vta_provincia']
            * vm['dolar'] * ( 1 - vr_utilitario_vta_prov / 100 )
            / a_utilitario_vta_prov / 12 / prod_mensual2
            + q_utilitario_vta_fuera_prov * vm['p_utilitario_vta_fueraprov']
            * vm['dolar'] * ( 1 - vr_utilitario_vta_fuera_prov / 100 )
            / a_utilitario_vta_fuera_prov / 12 / prod_mensual2 )

iv10_costo_oportunidad = (( q_tostadora * vm['p_tostadora'] * vm['dolar']
            * (( 1 - vr_tostadora / 100 ) / 2 + vr_tostadora / 100 )
            + q_envasadora * vm['p_envasadora_tostadero'] * vm['dolar']
            * (( 1 - vr_envasadora / 100 ) / 2 + vr_envasadora / 100 )
            + q_autoelevador * vm['p_autoelevador_tostadero'] * vm['dolar']
            * (( 1 - vr_autoelevador / 100 ) / 2 + vr_autoelevador / 100 )
            + q_maquina_cafeymolino * vm['p_maquina_cafeymolino'] * vm['dolar']
            * (( 1 - vr_maquina_cafeymolino / 100 ) / 2 + vr_maquina_cafeymolino / 100 )
            + q_utilitario_vta_prov * vm['p_utilitario_vta_provincia'] * vm['dolar']
            * (( 1 - vr_utilitario_vta_prov / 100 ) / 2 + vr_utilitario_vta_prov / 100 )
            + q_utilitario_vta_fuera_prov * vm['p_utilitario_vta_fueraprov'] * vm['dolar']
            * (( 1 - vr_utilitario_vta_fuera_prov / 100 ) / 2 + vr_utilitario_vta_fuera_prov / 100 ))
            * costo_oportunidad / 100 / 12 / prod_mensual2 )
             

iv00_maquinaria = ( iv01_energia + iv02_imp_tasas_energia + iv03_gas_nat
            + iv04_imp_tasas_gas + iv05_rep_tostadora + iv06_rep_envasadora
            + iv07_rep_autoelevador + iv08_rep_maquina_cafeymolino
            + iv09_rep_utilitarios + iv10_costo_oportunidad )

#Bloque V - Costos Fijos No Asociados a la Producción

v01_alquiler = ( vm['palquiler'] * vm['dolar'] * galpon / prod_mensual2 )

v02_muebles_utiles = (( vm['pcomputadora'] / a_comp + vm['pescritorio']
            / a_muebles + vm['psilla'] / a_muebles ) * q_comp / 12
            / prod_mensual2 )

v03_mantenim = ( mantenim_general * vm['sal_operario_general'] * 2
            / prod_mensual2 )

v04_limpieza = ( limpieza * vm['sal_operario_general']* 2
            / prod_mensual2 )

v05_seguros = ( vm['pseguro_incendio'] / 12 / prod_mensual2 )

v06_movilidad_vendedores = (( q_utilitario_vta_prov
            + q_utilitario_vta_fuera_prov ) * km_utilitario_mes
            * litros_por_km * vm['gasoil_grado2'] / prod_mensual2 )
            

v07_costos_financieros = (( i00_materia_prima * 1.21 * ( pow ( 1 + vm['tasa_interes_mensual']
            / 100,( plazo_cobro - plazo_pago ) / 30 ))
            + ( ii00_mano_obra_directa + iii00_mano_obra_indirecta )
            * ( pow ( 1 + vm['tasa_interes_mensual'] / 100,( plazo_cobro
            - plazo_pago_salarios ) / 30 )) - i00_materia_prima * 1.21
            - ( ii00_mano_obra_directa + iii00_mano_obra_indirecta )))
                                                        
v08_estudio_contable = ( vm['pestudio_contable'] / prod_mensual2 )

v09_comisiones_vta = (( i00_materia_prima + ii00_mano_obra_directa
            + iii00_mano_obra_indirecta + iv00_maquinaria + v01_alquiler
            + v02_muebles_utiles + v03_mantenim + v04_limpieza + v05_seguros
            + v06_movilidad_vendedores + v07_costos_financieros
            + v08_estudio_contable ) * ( comisiones_vendedores_cba
            * vtas_cba / 100 + comisiones_vendedores_fueracba
            * ( 1 - vtas_cba / 100 )) / 100 )

v10_beneficios = (( i00_materia_prima + ii00_mano_obra_directa
            + iii00_mano_obra_indirecta + iv00_maquinaria + v01_alquiler
            + v02_muebles_utiles + v03_mantenim + v04_limpieza + v05_seguros
            + v06_movilidad_vendedores + v07_costos_financieros
            + v08_estudio_contable + v09_comisiones_vta ) * mark_up / 100 )

v00_costos_fijos_no_prod = ( v01_alquiler + v02_muebles_utiles + v03_mantenim
            + v04_limpieza + v05_seguros + v06_movilidad_vendedores + v07_costos_financieros
            + v08_estudio_contable + v09_comisiones_vta + v10_beneficios )

#Bloque VI - Costos Impositivos

vi01_ingresos_brutos = (( i00_materia_prima + ii00_mano_obra_directa
            + iii00_mano_obra_indirecta + iv00_maquinaria
            + v00_costos_fijos_no_prod ) * (( vm['ib_cordoba_alic']
            * ( vtas_cba + vtas_bsas ) / 100 + vm['ib_buenosaires_extjuris_alic']
            * vtas_stafe / 100 )) / 100 )

vi02_comercioeindustria = (( i00_materia_prima + ii00_mano_obra_directa
            + iii00_mano_obra_indirecta + iv00_maquinaria
            + v00_costos_fijos_no_prod ) * vm['tasa_comeind_alic'] / 100 )

vi03_imp_ganancias = (( v10_beneficios + iv10_costo_oportunidad )
            * vm['impgcias_benef_alic'] / 100 + ( v10_beneficios
            + iv10_costo_oportunidad ) * ( 100 - reinversion_ganancias )
            / 100 * vm['impgcias_benef_dist_alic'] / 100 )

vi04_imp_cheque = (( i00_materia_prima + ii00_mano_obra_directa
            + iii00_mano_obra_indirecta + iv00_maquinaria
            + v00_costos_fijos_no_prod ) * 1.21 * ( vm['impcheque_alic']
            + vm['impcheque_ctagcias_alic'] ) / 100 )

vi00_impositivos = ( vi01_ingresos_brutos + vi02_comercioeindustria
            + vi03_imp_ganancias + vi04_imp_cheque )

#Bloque Indicadores de Costo

costo_kg_pesos = ( i00_materia_prima + ii00_mano_obra_directa
            + iii00_mano_obra_indirecta + iv00_maquinaria
            + v00_costos_fijos_no_prod + vi00_impositivos )

costo_kg_dolares = ( costo_kg_pesos / vm['dolar'] )



# CONTROL

print (costo_kg_dolares)
