# Programa en Python - Sistema Estadistico de Costos industria del Plástico


# MÓDULO I - CARGA DE VARIABLES MONETARIAS

import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import seaborn as sns

# importar base de datos de series de tiempo con variables monetarias:

vm = pd.read_excel('variables monetarias costos plásticos v01.xlsx')


# Convertir columna mes en variable indexadora temporal:

vm.mes = pd.to_datetime(vm.mes)
vm.set_index('mes', inplace=True)       


# MÓDULO II - DEFINICION DE PARÁMETROS - Fabricación Rollos Film

prod_hora = 50
hora_funcionamiento = 20
dia_funcionamiento = 20
prod_mensual_potencial_kg = 20000
ocupacion = 100
prod_mensual_kg = 20000
#Materias primas	
q_grumo = 1
q_pigmento_telas = 0.07
q_scrap	 = 5.00
q_recupero_scrap = 30.00
q_carton = 0.005
#Operarios	
q_op_extrusadora = 3
q_operarios = 3
q_delegados_gremiales = 0
q_horas_mensuales_convenio = 192
#Mano de obra indirecta	
q_encargado_planta = 1
q_admin = 1
q_gerente_general = 1
#Maquinaria	
q_extrusora = 1
q_impresora = 0
q_cortadora = 0
a_extrusora = 3
a_impresora = 3
a_cortadora = 3
vr_extrusora = 50
vr_impresora = 70
vr_cortadora = 50
costo_oportunidad = 4.0
mantenim_gral = 12
limpieza = 24
potencia_contratada = 210.00
consumo_energia = 5600
horas_pico_pot = 5
horas_no_pico_pot = 19
horas_pico_consumo = 5
horas_valle_consumo = 6
horas_resto_consumo = 13
galpon = 250
antig = 10.00
antig_coef = 1.00
sac_coef = 8.33
vac = 28.00
fondo_prev = 4.00
aporte_gremio = 11.00
ausentismo = 5.00
q_comp = 3.00
a_comp = 5
a_muebles = 10
plazo_pago = 60
plazo_cobro = 90
plazo_pago_salarios = 30
mark_up = 10.0
vtas_cba = 40.0
vtas_bsas = 30.0
vtas_stafe = 30.0
reinversion_ganancias = 50.0


#MÓDULO 3 - ESTIMACIONES DE COSTOS

#Bloque I - Materia Prima

i01_grumo = ( prod_mensual_kg * q_grumo * ( 1 + q_scrap / 100 * ( 1
            - q_recupero_scrap / 100 )) * vm['p_grumo'] * vm['dolar']
            / prod_mensual_kg )

i02_pigmentos_tela = ( prod_mensual_kg * q_pigmento_telas * ( 1 + q_scrap / 100
            * ( 1 - q_recupero_scrap / 100 )) * vm['p_pigmentos_telas']
            * vm['dolar'] / prod_mensual_kg )

i03_carton = ( prod_mensual_kg * q_carton * vm['p_carton'] / prod_mensual_kg )

i00_materia_prima = ( i01_grumo + i02_pigmentos_tela + i03_carton )

#Bloque II - Costos de Mano de Obra Directa

ii01_rem_operarios = ( q_operarios * vm['sal_operador_calif']
            * q_horas_mensuales_convenio / prod_mensual_kg )

ii02_rem_operarios_norem = (0)

ii03_horas_extra15 = (0)

ii04_horas_extra2 = (0)

ii05_antig = (( ii01_rem_operarios + ii03_horas_extra15 + ii04_horas_extra2 )
            * antig_coef / 100 * antig )

ii06_sac = (( ii01_rem_operarios + ii03_horas_extra15 + ii04_horas_extra2
            + ii05_antig ) * sac_coef / 100 )

ii07_vac = (( ii01_rem_operarios + ii02_rem_operarios_norem + ii05_antig )
            / 30 *  vac / 12 )

ii08_cont_pat = (( ii01_rem_operarios + ii03_horas_extra15 + ii04_horas_extra2
            + ii05_antig + ii06_sac + ii07_vac - vm['contribuciones_mni']
            * ( q_operarios + q_delegados_gremiales ) / prod_mensual_kg )
            * vm['contribuciones_alic'] / 100 )

ii09_cont_pat_iva = (-( ii01_rem_operarios + ii03_horas_extra15 + ii04_horas_extra2
            + ii05_antig + ii06_sac + ii07_vac - vm['contribuciones_mni']
            * ( q_operarios + q_delegados_gremiales ) / prod_mensual_kg )
            * vm['contribuciones_ctaiva_alic'] / 100 )

ii10_cont_os = (( ii01_rem_operarios + ii03_horas_extra15 + ii04_horas_extra2
            + ii05_antig + ii06_sac + ii07_vac ) * vm['contrib_obrasocial_alic']
            / 100 )

ii11_cont_gremio = ( aporte_gremio * vm['sal_oficial_especializado']
            / prod_mensual_kg ) 

ii12_seg_vida = (( ii01_rem_operarios + ii03_horas_extra15 + ii04_horas_extra2
            + ii05_antig + ii06_sac + ii07_vac )
            * vm['seguro_vida_obligat_alic'] / 100 )

ii13_art = (( ii01_rem_operarios + ii03_horas_extra15 + ii04_horas_extra2
            + ii05_antig + ii06_sac + ii07_vac ) * vm['art_alic']
            / 100 )

ii14_prev_despido = (( ii01_rem_operarios + ii02_rem_operarios_norem
            + ii03_horas_extra15 + ii04_horas_extra2 + ii05_antig + ii06_sac
            + ii07_vac ) * fondo_prev / 100 )

ii15_ausentismo = (( ii01_rem_operarios + ii05_antig + ii06_sac
            + ii07_vac + ii08_cont_pat + ii09_cont_pat_iva + ii10_cont_os
            + ii11_cont_gremio + ii12_seg_vida + ii13_art + ii14_prev_despido )
            * ausentismo / 100 )

ii00_mano_obra_directa = ( ii01_rem_operarios + ii02_rem_operarios_norem
            + ii03_horas_extra15 + ii04_horas_extra2 + ii05_antig + ii06_sac
            + ii07_vac + ii08_cont_pat + ii09_cont_pat_iva + ii10_cont_os
            + ii11_cont_gremio + ii12_seg_vida + ii13_art + ii14_prev_despido
            + ii15_ausentismo )

#Bloque III - Costos de Mano de Obra Indirecta

iii01_rem_encargado_planta = ( q_encargado_planta * vm['rem_capataz']
            / prod_mensual_kg )

iii02_rem_admin = ( q_admin * vm['rem_admin1'] / prod_mensual_kg )

iii03_rem_gerente_general = ( q_gerente_general * vm['rem_gerente_general']
            / prod_mensual_kg )

iii04_antig = (( iii01_rem_encargado_planta + iii02_rem_admin
            + iii03_rem_gerente_general ) * antig_coef / 100 * antig )

iii05_sac = (( iii01_rem_encargado_planta + iii02_rem_admin
            + iii03_rem_gerente_general + iii04_antig ) * sac_coef / 100 )

iii06_vac = (( iii01_rem_encargado_planta + iii02_rem_admin
            + iii03_rem_gerente_general + iii04_antig ) / 30 *  vac / 12 )
             
iii07_cont_pat = (( iii01_rem_encargado_planta + iii02_rem_admin
            + iii03_rem_gerente_general + iii04_antig + iii05_sac + iii06_vac
            - vm['contribuciones_mni'] * ( q_encargado_planta + q_admin
            + q_gerente_general ) / prod_mensual_kg )
            * vm['contribuciones_alic'] / 100 )

iii08_cont_pat_iva = (-( iii01_rem_encargado_planta + iii02_rem_admin
            + iii03_rem_gerente_general + iii04_antig + iii05_sac + iii06_vac
            - vm['contribuciones_mni'] * ( q_encargado_planta + q_admin
            + q_gerente_general ) / prod_mensual_kg )
            * vm['contribuciones_ctaiva_alic'] / 100 )

iii09_cont_os = (( iii01_rem_encargado_planta + iii02_rem_admin
            + iii03_rem_gerente_general + iii04_antig + iii05_sac + iii06_vac )
            * vm['contrib_obrasocial_alic'] / 100 )

iii10_seg_vida = (( iii01_rem_encargado_planta + iii02_rem_admin
            + iii03_rem_gerente_general + iii04_antig + iii05_sac + iii06_vac )
            * vm['seguro_vida_obligat_alic'] / 100 )

iii11_art = (( iii01_rem_encargado_planta + iii02_rem_admin
            + iii03_rem_gerente_general + iii04_antig + iii05_sac + iii06_vac )
            * vm['art_alic'] / 100 )

iii12_prev_despido = (( iii01_rem_encargado_planta + iii02_rem_admin
            + iii03_rem_gerente_general + iii04_antig + iii05_sac + iii06_vac )
            * fondo_prev / 100 )

iii00_mano_obra_indirecta = (iii01_rem_encargado_planta + iii02_rem_admin
            + iii03_rem_gerente_general + iii04_antig + iii05_sac + iii06_vac
            + iii07_cont_pat + iii08_cont_pat_iva + iii09_cont_os
            + iii10_seg_vida + iii11_art + iii12_prev_despido )

#Bloque IV - Maquinaria

iv01_energia = (( potencia_contratada * vm['penergia_potencia_punta']
            + consumo_energia * vm['penergia_pico'] ) / prod_mensual_kg )

iv02_imp_tasas_energia = ( iv01_energia * ( vm['penergia_oim']
            + vm['penergia_dto2298'] + vm['penergia_ersep']
            + vm['penergia_ley9819'] ) / 100 )

iv03_rep_extrusora = ( q_extrusora * vm['p_extrusora'] * vm['dolar']
            * ( 1 - vr_extrusora / 100 ) / a_extrusora / 12
            / prod_mensual_kg )

iv04_costo_oportunidad = (( q_extrusora * vm['p_extrusora'] * vm['dolar']
            * (( 1 - vr_extrusora / 100 ) / 2 + vr_extrusora / 100 )
            + q_impresora * vm['p_impresora'] * vm['dolar']
            * (( 1 - vr_impresora / 100 ) / 2 + vr_impresora / 100 )
            + q_cortadora * vm['p_cortadora'] * vm['dolar']
            * (( 1 - vr_cortadora / 100 ) / 2 + vr_cortadora / 100 ))
            * costo_oportunidad / 100 / 12 / prod_mensual_kg )

iv00_maquinaria = ( iv01_energia + iv02_imp_tasas_energia + iv03_rep_extrusora
            + iv04_costo_oportunidad )

#Bloque V - Costos Fijos No Asociados a la Producción

v01_alquiler = ( vm['palquiler'] * vm['dolar'] * galpon / prod_mensual_kg )

v02_muebles_utiles = (( vm['pcomputadora'] / a_comp + vm['pescritorio']
            / a_muebles + vm['psilla'] / a_muebles ) * q_comp / 12
            / prod_mensual_kg )

v03_mantenimiento = ( mantenim_gral * vm['sal_mantenimiento'] * 2
            / prod_mensual_kg )

v04_limpieza = ( limpieza * vm['sal_operario'] * 2 / prod_mensual_kg )

v05_seguros = ( vm['pseguro_incendio'] / 12 / prod_mensual_kg )

v06_costos_financieros = ( i00_materia_prima * 1.21 * ( pow ( 1 + vm['tasa_interes_mensual']
            / 100,( plazo_cobro - plazo_pago )/ 30 ))
            + ( ii00_mano_obra_directa + iii00_mano_obra_indirecta )
            * ( pow ( 1 + vm['tasa_interes_mensual'] / 100,( plazo_cobro
            - plazo_pago_salarios )/ 30 )) - i00_materia_prima * 1.21
            - ( ii00_mano_obra_directa + iii00_mano_obra_indirecta ))

v07_estudio_contable = ( vm['pestudio_contable'] / prod_mensual_kg )

v08_beneficios = (( i00_materia_prima + ii00_mano_obra_directa
            + iii00_mano_obra_indirecta + iv00_maquinaria + v01_alquiler
            + v02_muebles_utiles + v03_mantenimiento + v04_limpieza
            + v05_seguros + v06_costos_financieros + v07_estudio_contable )
            * mark_up / 100 )

v00_costos_fijos_no_prod = ( v01_alquiler + v02_muebles_utiles
            + v03_mantenimiento + v04_limpieza + v05_seguros
            + v06_costos_financieros + v07_estudio_contable + v08_beneficios )

#Bloque VI - Costos Impositivos

vi01_impuesto_ingresos_brutos = (( i00_materia_prima + ii00_mano_obra_directa
            + iii00_mano_obra_indirecta + iv00_maquinaria + v00_costos_fijos_no_prod )
            * (( vm['ib_cordoba_alic'] * vtas_cba
            / 100 + vm['ib_buenosaires_extjuris_alic'] * vtas_bsas / 100
            + vm['ib_santfe_extjuris_alic'] * vtas_stafe / 100 )) / 100 )

vi02_tasa_comercioeindustria = (( i00_materia_prima + ii00_mano_obra_directa
            + iii00_mano_obra_indirecta + iv00_maquinaria + v00_costos_fijos_no_prod )
            * vm['tasa_comeind_alic'] / 100 )

vi03_impuesto_ganancias = (( v08_beneficios + iv04_costo_oportunidad )
            * vm['impgcias_benef_alic'] / 100 + ( v08_beneficios
            + iv04_costo_oportunidad ) * ( 100 - reinversion_ganancias ) / 100
            * vm['impgcias_benef_dist_alic'] / 100 )

vi04_impuesto_cheque = (( i00_materia_prima + ii00_mano_obra_directa
            + iii00_mano_obra_indirecta + iv00_maquinaria + v00_costos_fijos_no_prod
            + vi01_impuesto_ingresos_brutos + vi02_tasa_comercioeindustria
            + vi03_impuesto_ganancias ) * 1.21 * ( vm['impcheque_alic']
            + vm['impcheque_ctagcias_alic'] ) / 100 )

vi00_impositivos = ( vi01_impuesto_ingresos_brutos + vi02_tasa_comercioeindustria
            + vi03_impuesto_ganancias + vi04_impuesto_cheque )

#Bloque Indicadores de Costo

costo_kg_pesos = ( i00_materia_prima + ii00_mano_obra_directa
            + iii00_mano_obra_indirecta + iv00_maquinaria + v00_costos_fijos_no_prod
            + vi00_impositivos )

costo_kg_dolares = ( costo_kg_pesos / vm['dolar'] )

#CONTROL

print(costo_kg_dolares)
