
# Programa en Python  -  Sistema Estadistico de Costos Metalurgicos


# MÓDULO I  -  CARGA DE VARIABLES MONETARIAS

import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import seaborn as sns


# Importar base de datos de series de tiempo con variables monetarias:

vm  =  pd.read_excel('Variables Monetarias Costos Industria Metalurgica.xlsx')


# Convertir columna mes en variable indexadora temporal:

vm.mes  =  pd.to_datetime(vm.mes)
vm.set_index('mes', inplace = True)       

#COSTOS MECANIZADOS
# MÓDULO II  -  DEFINICION DE PARÁMETROS  -  COSTOS MECANIZADOS

uci = 80
dias_mes = 22
horas_dia = 24.0
horas_disp = 20.0
horas_turno = 8.0
horas_extras = 0.0
horas_extras2 = 0.0
q_tornos = 2
q_centros_verticales = 4
q_centros_horizontales = 4
q_maquinas = 10
q_compresores = 1
q_maquinas_medir = 1
q_calibradores = 1
q_autoelevadores = 1
q_complementos_autoelevad = 1
a_tornos = 5.00
a_centros_verticales = 5.00
a_centros_horizontales = 5.00
a_compresores = 5.00
a_maquinas_medir = 5.00
a_calibradores = 5.00
a_autoelevadores = 5.00
a_complementos_autoelevad = 5.00
vr_tornos = 40.00
vr_centros_verticales = 40.00
vr_centros_horizontales = 40.00
vr_compresores = 30.00
vr_maquinas_medir = 30.00
vr_calibradores = 30.00
vr_autoelevadores = 30.00
vr_complementos_autoelevad = 30.00
costo_oportunidad = 4.00
potencia_tornos = 11.00
potencia_centros_verticales = 15.00
potencia_contratada = 50.00
ratio_consumo_potencia = 0.40
energia_consumo = 57
energia_potencia_pico = 5
energia_potencia_nopico = 19
energia_consumo_pico = 5
energia_consumo_valle = 6
energia_consumo_resto = 13
ratio_operarios_maquina = 3
q_jefe_planta = 1
q_supervisores = 3
q_jefe_calidad = 1
q_jefe_ingenieria = 1
q_jefe_logistica = 1
q_jefe_mantenimiento = 1
q_personal_admin = 2
galpon = 1000
a_antiguedad = 12.00
coef_antiguedad = 1.00
q_vestimenta = 4.00
q_casco = 2.00
q_guantes = 2.00
alic_art = 8.00
coef_sac = 8.33
q_vacaciones = 28.00
fondo_prevision_despido = 4.00
ausentismo = 12.00
a_computadoras = 5
a_muebles = 10
costos_erogables_financiables_coef = 50.0
q_descalce_financ = 40.0
mark_up = 10.0
ventas_cordoba = 70.0
ventas_pba = 30.0
reinversion_ganancias = 50.0

# Bloque I  -  Costos de Mano de Obra Directa

i01_w_basica_remun = (vm['w_r4l29_op_especializado'] *  horas_dia
            / horas_disp * 100 / uci)

i02_w_basica_no_remun = (0)

i03_horas_extras = (vm['w_r17_op_calif'] * 1.5 * horas_extras)

i04_horas_extras2 = (vm['w_r17_op_calif'] * 2 * horas_extras2)

i05_antig = ((i01_w_basica_remun + i03_horas_extras + i04_horas_extras2)
            *  coef_antiguedad / 100 *  a_antiguedad)

i06_sac = ((i01_w_basica_remun + i03_horas_extras + i04_horas_extras2
            + i05_antig) *  coef_sac / 100)

i07_vac = (i01_w_basica_remun / 30 *  q_vacaciones / 12)

i08_cont_pat = ((i01_w_basica_remun +  i03_horas_extras + i04_horas_extras2
            + i05_antig + i06_sac + i07_vac - vm['mni_contribuciones']
            /  dias_mes / horas_turno * 100 / uci) * vm['alic_contribuciones']
            / 100)

i09_cont_pat_iva = ( - (i01_w_basica_remun + i03_horas_extras
            + i04_horas_extras2 +  i05_antig + i06_sac + i07_vac
            - vm['mni_contribuciones'] /  dias_mes / horas_turno * 100 / uci)
            * vm['cf_contribuciones'] / 100)

i10_cont_os = ((i01_w_basica_remun + i03_horas_extras + i04_horas_extras2
            +  i05_antig + i06_sac + i07_vac)
            * vm['alic_contribuciones_osocial'] / 100)

i11_seg_vida = (( i01_w_basica_remun + i03_horas_extras + i04_horas_extras2
            + i05_antig + i06_sac + i07_vac ) * vm['seguro_vida_obligat_coef']
            / 100 )

i12_art = ((i01_w_basica_remun + i03_horas_extras + i04_horas_extras2
            + i05_antig + i06_sac + i07_vac) *  alic_art / 100)

i13_prev_desp = ((i01_w_basica_remun + i03_horas_extras + i04_horas_extras2
            + i05_antig + i06_sac + i07_vac) *  fondo_prevision_despido
            / 100)

i14_cont_admira = ((i01_w_basica_remun + i03_horas_extras + i04_horas_extras2
            + i05_antig + i06_sac + i07_vac)
            * vm['contribucion_adimra'] / 100)

i15_ausen = ((i01_w_basica_remun + i02_w_basica_no_remun + i05_antig + i06_sac
            + i07_vac + i08_cont_pat + i09_cont_pat_iva + i10_cont_os
            + i11_seg_vida + i12_art + i14_cont_admira) *  ausentismo / 100)

i00_mano_obra_directa = ( i01_w_basica_remun +  i02_w_basica_no_remun
            +  i03_horas_extras +  i04_horas_extras2 +  i05_antig +  i06_sac
            +  i07_vac +  i08_cont_pat +  i09_cont_pat_iva +  i10_cont_os
            +  i11_seg_vida +  i12_art +  i13_prev_desp +  i14_cont_admira
            +  i15_ausen)

# Bloque II  -  Costos de Mano de Obra Indirecta

ii01_w_jefe_planta = (vm['w_r4l29_tecnico5'] *  q_jefe_planta /  q_maquinas
            /  dias_mes /  horas_disp /  uci * 100)

ii02_w_supervisores = (vm['w_r4l29_tecnico5'] *  q_supervisores /  q_maquinas
            /  dias_mes /  horas_disp /  uci * 100)

ii03_w_jefe_calidad = (vm['w_r4l29_tecnico5'] *  q_jefe_calidad /  q_maquinas
            /  dias_mes /  horas_disp /  uci * 100)

ii04_w_jefe_ingenieria = (vm['w_r4l29_tecnico5'] *  q_jefe_ingenieria
            /  q_maquinas /  dias_mes /  horas_disp /  uci * 100)

ii05_w_jefe_logistica = (vm['w_r4l29_tecnico5'] *  q_jefe_logistica
            /  q_maquinas /  dias_mes /  horas_disp /  uci * 100)

ii06_w_jefe_mantenimiento = (vm['w_r4l29_tecnico5'] *  q_jefe_mantenimiento
            /  q_maquinas /  dias_mes /  horas_disp /  uci * 100)

ii07_antig = ((ii01_w_jefe_planta + ii02_w_supervisores + ii03_w_jefe_calidad
            + ii04_w_jefe_ingenieria + ii05_w_jefe_logistica
            + ii06_w_jefe_mantenimiento) * coef_antiguedad / 100
            * a_antiguedad)

ii08_sac = ((ii01_w_jefe_planta + ii02_w_supervisores + ii03_w_jefe_calidad
            + ii04_w_jefe_ingenieria + ii05_w_jefe_logistica
            + ii06_w_jefe_mantenimiento + ii07_antig) * coef_sac / q_maquinas
            / dias_mes / horas_disp / uci * 100)

ii09_vac = ((ii01_w_jefe_planta + ii02_w_supervisores + ii03_w_jefe_calidad
            + ii04_w_jefe_ingenieria + ii05_w_jefe_logistica
            + ii06_w_jefe_mantenimiento + ii07_antig) / 30 * q_vacaciones / 12)

ii10_cont_pat = (((ii01_w_jefe_planta + ii02_w_supervisores
            + ii03_w_jefe_calidad + ii04_w_jefe_ingenieria
            + ii05_w_jefe_logistica + ii06_w_jefe_mantenimiento
            + ii07_antig + ii08_sac + ii09_vac) - vm['mni_contribuciones']
            * (q_jefe_planta + q_supervisores + q_jefe_calidad
            + q_jefe_ingenieria + q_jefe_logistica + q_jefe_mantenimiento)
            / q_maquinas / dias_mes / horas_disp * 100 / uci)
            * vm['alic_contribuciones'] / 100)

ii11_cont_pat_iva = ( - ((ii01_w_jefe_planta + ii02_w_supervisores
            + ii03_w_jefe_calidad + ii04_w_jefe_ingenieria
            + ii05_w_jefe_logistica + ii06_w_jefe_mantenimiento + ii07_antig
            + ii08_sac + ii09_vac) - vm['mni_contribuciones'] * (q_jefe_planta
            + q_supervisores + q_jefe_calidad + q_jefe_ingenieria
            + q_jefe_logistica + q_jefe_mantenimiento) / q_maquinas / dias_mes
            / horas_disp * 100 / uci) * vm['cf_contribuciones'] / 100)

ii12_cont_os = ((ii01_w_jefe_planta + ii02_w_supervisores
            + ii03_w_jefe_calidad + ii04_w_jefe_ingenieria
            + ii05_w_jefe_logistica + ii06_w_jefe_mantenimiento + ii07_antig
            + ii08_sac + ii09_vac) * vm['alic_contribuciones_osocial'] / 100)

ii13_seg_vida = ((ii01_w_jefe_planta + ii02_w_supervisores
            + ii03_w_jefe_calidad + ii04_w_jefe_ingenieria
            + ii05_w_jefe_logistica + ii06_w_jefe_mantenimiento + ii07_antig
            + ii08_sac + ii09_vac) * vm['seguro_vida_obligat_coef'] / 100)

ii14_art = ((ii01_w_jefe_planta + ii02_w_supervisores + ii03_w_jefe_calidad
            + ii04_w_jefe_ingenieria + ii05_w_jefe_logistica
            + ii06_w_jefe_mantenimiento + ii07_antig + ii08_sac + ii09_vac)
            * alic_art / 100)

ii15_prev_desp = ((ii01_w_jefe_planta + ii02_w_supervisores
            + ii03_w_jefe_calidad + ii04_w_jefe_ingenieria
            + ii05_w_jefe_logistica + ii06_w_jefe_mantenimiento + ii07_antig
            + ii08_sac + ii09_vac) * fondo_prevision_despido / 100)

ii16_cont_admira = ((ii01_w_jefe_planta + ii02_w_supervisores
            + ii03_w_jefe_calidad + ii04_w_jefe_ingenieria
            + ii05_w_jefe_logistica + ii06_w_jefe_mantenimiento + ii07_antig
            + ii08_sac + ii09_vac) * vm['contribucion_adimra'] / 100)

ii00_mano_obra_indirecta = (ii01_w_jefe_planta + ii02_w_supervisores
            + ii03_w_jefe_calidad + ii04_w_jefe_ingenieria
            + ii05_w_jefe_logistica + ii06_w_jefe_mantenimiento + ii07_antig
            + ii08_sac + ii09_vac + ii10_cont_pat + ii11_cont_pat_iva
            + ii12_cont_os + ii13_seg_vida + ii14_art + ii15_prev_desp
            + ii16_cont_admira)

# BLoque III  -  Costos de Maquinaria

iii01_energia_electrica = (potencia_contratada * (vm['energia_pot_punta']
            * energia_potencia_pico + vm['energia_pot_nopunta']
            * energia_potencia_nopico) / 24 / horas_disp / dias_mes
            / q_maquinas / uci * 100 + energia_consumo * (vm['energia_pico']
            * energia_consumo_pico + vm['energia_ valle']
            * energia_consumo_valle + vm['energia_resto']
            * energia_consumo_resto) / 24 / q_maquinas)

iii02_alic_energia_electrica = (iii01_energia_electrica * (vm['energia_oim']
            + vm['energia_dto2298'] + vm['energia_ersep']
            + vm['energia_ley9819']) / 100)

iii03_lubricantes = ((vm['p_consumibles_lubricantes_tornos'] * vm['dolar']
            * q_tornos + vm['p_consumibles_lubricantes_cv'] * vm['dolar']
            * q_centros_verticales + vm['p_consumibles_lubricantes_ch']
            * vm['dolar'] * q_centros_horizontales) / q_maquinas)

iii04_consumibles = (((vm['p_consumibles_tornos']
            + vm['pconsumibles_portainsertos']) * vm['dolar'] * q_tornos
            + (vm['p_consumibles_insertos_cv']
            + vm['p_consumibles_portainsertos_cv']) * vm['dolar']
            * q_centros_verticales + (vm['p_consumibles_insertos_ch']
            + vm['p_consumibles_portainsertos_ch']) * vm['dolar']
            * q_centros_horizontales) / q_maquinas)

iii05_mantenimiento = ((vm['p_torno'] * q_tornos + vm['p_centro_vert']
            * q_centros_verticales + vm['p_centro_horiz']
            * q_centros_horizontales) * vm['dolar']
            * vm['mantenim_maq_mecaniz'] / 100 / 12 / q_maquinas / horas_disp
            / dias_mes / uci * 100)

iii06_seg = ((vm['p_torno'] * q_tornos + vm['p_centro_vert']
            * q_centros_verticales + vm['p_centro_horiz']
            * q_centros_horizontales) * vm['dolar'] * vm['seguro_maq_mecaniz']
            / 100 / 12 / q_maquinas / horas_disp / dias_mes / uci * 100)

iii07_a_tornos = (vm['p_torno'] * vm['dolar'] * q_tornos / q_maquinas
            * (1 - vr_tornos / 100) / a_tornos / 12 / dias_mes / horas_disp
            / uci * 100)

iii08_a_centros_verticales = (vm['p_centro_vert'] * vm['dolar']
            * q_centros_verticales / q_maquinas * (1 - vr_centros_verticales
            / 100) / a_centros_verticales / 12 / dias_mes / horas_disp
            / uci * 100)

iii09_a_centros_horizontales = (vm['p_centro_horiz'] * vm['dolar']
            * q_centros_horizontales / q_maquinas
            * (1 - vr_centros_horizontales / 100) / a_centros_horizontales
            / 12 / dias_mes / horas_disp / uci * 100)

iii10_a_compresores = (vm['p_compresor'] * vm['dolar'] * q_compresores
            * (1 - vr_compresores / 100) / a_compresores / 12
            / q_maquinas / dias_mes / horas_disp / uci * 100)

iii11_a_maquinas_medir = (vm['p_maq_medir'] * vm['dolar'] * q_maquinas_medir
            * (1 - vr_maquinas_medir / 100) / a_maquinas_medir
            / 12 / q_maquinas / dias_mes / horas_disp / uci * 100)

iii12_a_calibradores = (vm['p_calibres'] * vm['dolar'] * q_calibradores
            * (1 - vr_calibradores / 100) / a_calibradores
            / 12 / q_maquinas / dias_mes / horas_disp / uci * 100)

iii13_a_autoelevadores = (vm['p_autoelevador_mecaniz'] * vm['dolar']
            * q_autoelevadores * (1 - vr_autoelevadores / 100)
            / a_autoelevadores / 12 / q_maquinas / dias_mes / horas_disp
            / uci * 100)

iii14_a_complemento_autoelevad = (vm['p_autoelevador_comp'] * vm['dolar']
            * q_complementos_autoelevad * (1 - vr_complementos_autoelevad / 100)
            / a_complementos_autoelevad / 12 / q_maquinas / dias_mes
            / horas_disp / uci * 100)

iii15_interes_cap_invertido = ((vm['p_torno'] * vm['dolar'] * q_tornos
            * ((1 - vr_tornos / 100) / 2 + vr_tornos / 100)
            + vm['p_centro_vert'] * vm['dolar'] * q_centros_verticales
            * ((1 - vr_centros_verticales / 100) / 2 + vr_centros_verticales
            / 100) + vm['p_centro_horiz'] * vm['dolar']
            * q_centros_horizontales * ((1 - vr_centros_horizontales / 100)
            / 2 + vr_centros_horizontales / 100) + vm['p_compresor']
            * vm['dolar'] * q_compresores * ((1 - vr_compresores / 100)
            / 2 + vr_compresores / 100) + vm['p_maq_medir'] * vm['dolar']
            * q_maquinas_medir * ((1 - vr_maquinas_medir / 100) / 2
            + vr_maquinas_medir / 100) + vm['p_calibres'] * vm['dolar']
            * q_calibradores * ((1 - vr_calibradores / 100) / 2
            + vr_calibradores / 100) + vm['p_autoelevador_mecaniz']
            * vm['dolar'] * q_autoelevadores * ((1 - vr_autoelevadores / 100)
            / 2 + vr_autoelevadores / 100) + vm['p_autoelevador_comp']
            * vm['dolar'] * q_complementos_autoelevad
            * ((1 - vr_complementos_autoelevad / 100) / 2
            + vr_complementos_autoelevad / 100)) * costo_oportunidad / 100
            / 12 / q_maquinas / dias_mes / horas_disp / uci * 100)

iii00_maquinaria = (iii01_energia_electrica + iii02_alic_energia_electrica
            + iii03_lubricantes + iii04_consumibles + iii05_mantenimiento
            + iii06_seg + iii07_a_tornos + iii08_a_centros_verticales
            + iii09_a_centros_horizontales + iii10_a_compresores
            + iii11_a_maquinas_medir + iii12_a_calibradores
            + iii13_a_autoelevadores + iii14_a_complemento_autoelevad
            + iii15_interes_cap_invertido)

# Bloque IV  -  Costos Fijos no Asociados a la Produccion

iv01_w_admin = (vm['w_r17_adm1'] * q_personal_admin / q_maquinas
            / dias_mes / horas_disp / uci * 100)

iv02_antig = (iv01_w_admin * coef_antiguedad / 100 * a_antiguedad)

ivo3_sac = ((iv01_w_admin + iv02_antig) * coef_sac / 100)

ivo4_vac = ((iv01_w_admin + iv02_antig) / 30 * 28 / 12)

ivo5_cont_pat = (((iv01_w_admin + iv02_antig + ivo3_sac + ivo4_vac)
            - vm['mni_contribuciones'] * q_personal_admin / q_maquinas
            / dias_mes / horas_disp * 100 / uci) * vm['alic_contribuciones']
            / 100)

iv06_cont_pat_iva = ( - ((iv01_w_admin + iv02_antig + ivo3_sac + ivo4_vac)
            - vm['mni_contribuciones'] * q_personal_admin / q_maquinas
            / dias_mes / horas_disp * 100 / uci) * vm['cf_contribuciones']
            / 100)

iv07_cont_os = ((iv01_w_admin + iv02_antig + ivo3_sac + ivo4_vac)
            * vm['alic_contribuciones_osocial'] / 100)

iv08_seg_vida = ((iv01_w_admin + iv02_antig + ivo3_sac + ivo4_vac)
            * vm['seguro_vida_obligat_coef'] / 100)

iv09_art = ((iv01_w_admin + iv02_antig + ivo3_sac + ivo4_vac) * alic_art / 100)

iv10_prev_despido = ((iv01_w_admin + iv02_antig + ivo3_sac + ivo4_vac)
            * fondo_prevision_despido / 100)

iv11_cont_admira = ((iv01_w_admin + iv02_antig + ivo3_sac + ivo4_vac)
            * vm['contribucion_adimra'] / 100)

iv12_alquiler = (vm['palquiler'] * vm['dolar'] * galpon / q_maquinas
            / dias_mes / horas_disp / uci * 100)

iv13_energia_electrica = (0)

iv14_muebles_utiles = (vm['pcomputadora'] * q_personal_admin / a_computadoras
            / 12 / q_maquinas / dias_mes / horas_disp / uci * 100
            + (vm['pescritorio'] + vm['psilla']) * q_personal_admin
            / a_muebles / 12 / q_maquinas / dias_mes / horas_disp / uci * 100)

iv15_costos_financieros = (((i01_w_basica_remun + i02_w_basica_no_remun
            + i03_horas_extras + i04_horas_extras2 + i05_antig)
            + (i08_cont_pat + i09_cont_pat_iva + i10_cont_os + i11_seg_vida
            + i12_art) +  ( i14_cont_admira + ii01_w_jefe_planta
            + ii02_w_supervisores + ii03_w_jefe_calidad
            + ii04_w_jefe_ingenieria + ii05_w_jefe_logistica
            + ii06_w_jefe_mantenimiento + ii07_antig ) + ( ii10_cont_pat
            + ii11_cont_pat_iva + ii12_cont_os + ii13_seg_vida + ii14_art )
            + ii16_cont_admira
            + (iii01_energia_electrica + iii02_alic_energia_electrica
            + iii03_lubricantes + iii04_consumibles + iii05_mantenimiento
            + iii06_seg) + (iv01_w_admin + iv02_antig + ivo3_sac)
            + ( ivo5_cont_pat + iv06_cont_pat_iva + iv07_cont_os
            + iv08_seg_vida + iv09_art)
            + (iv11_cont_admira + iv12_alquiler + iv13_energia_electrica))
            * costos_erogables_financiables_coef / 100
            * vm['tasa_interes_mens'] / 100 * q_descalce_financ / 30 )

iv16_estudio_contable = (vm['pestudio_cont'] / q_maquinas
            / dias_mes / horas_disp / uci * 100)

iv17_estudio_juridico = (vm['pestudio_jur'] / q_maquinas
            / dias_mes / horas_disp / uci * 100)

iv18_beneficios = ((i00_mano_obra_directa + ii00_mano_obra_indirecta
            + iii00_maquinaria + iv01_w_admin + iv02_antig + ivo3_sac
            + ivo4_vac + ivo5_cont_pat + iv06_cont_pat_iva + iv07_cont_os
            + iv08_seg_vida + iv09_art + iv10_prev_despido + iv11_cont_admira
            + iv12_alquiler + iv13_energia_electrica + iv14_muebles_utiles
            + iv15_costos_financieros + iv16_estudio_contable
            + iv17_estudio_juridico) * 0.1)

iv00_costos_fijos_no_asociados = (iv01_w_admin + iv02_antig + ivo3_sac
            + ivo4_vac + ivo5_cont_pat + iv06_cont_pat_iva + iv07_cont_os
            + iv08_seg_vida + iv09_art + iv10_prev_despido + iv11_cont_admira
            + iv12_alquiler + iv13_energia_electrica + iv14_muebles_utiles
            + iv15_costos_financieros + iv16_estudio_contable
            + iv17_estudio_juridico + iv18_beneficios)

# Bloque V  -  Costos Impositivos

v01_imp_ingresos_brutos = ((i00_mano_obra_directa + ii00_mano_obra_indirecta
            + iii00_maquinaria + iv00_costos_fijos_no_asociados)
            * ( vm['IB_Cordoba_loc'] / 100 * ventas_cordoba / 100
            + vm['IB_PBA_ej'] / 100 * ventas_pba / 100))

v02_alic_imp_comer_ind = ((i00_mano_obra_directa + ii00_mano_obra_indirecta
            + iii00_maquinaria + iv00_costos_fijos_no_asociados)
            * vm['alic_comeind'] / 100)

v03_alic_imp_ganancias = ((iv18_beneficios + iii15_interes_cap_invertido)
            * vm['alic_imp_ganancias'] / 100 + (iv18_beneficios
            + iii15_interes_cap_invertido) * (100 - reinversion_ganancias)
            / 100 * vm['alic_imp_ganancias_dist'] / 100)

v04_alic_imp_cheque = ((i00_mano_obra_directa + ii00_mano_obra_indirecta
            + iii00_maquinaria + iv00_costos_fijos_no_asociados
            + v01_imp_ingresos_brutos + v02_alic_imp_comer_ind
            + v03_alic_imp_ganancias) * (vm['alic_imp_cheque']
            + vm['cf_imp_cheque']) / 100)

v00_costos_impositivos = (v01_imp_ingresos_brutos + v02_alic_imp_comer_ind
            + v03_alic_imp_ganancias + v04_alic_imp_cheque)

# Bloque Indicadores de Costos

costo_hora_pesos = (i00_mano_obra_directa + ii00_mano_obra_indirecta
            + iii00_maquinaria + iv00_costos_fijos_no_asociados
            + v00_costos_impositivos)

costo_hora_dolares = ((i00_mano_obra_directa + ii00_mano_obra_indirecta
            + iii00_maquinaria + iv00_costos_fijos_no_asociados
            + v00_costos_impositivos) / vm['dolar'])

# CONTROL

print (costo_hora_dolares)
